@@ -22,6 +22,7 @@
 #include "apt.h"
 #include "apt-utils.h"
 #include "matcher.h"
+#include "gstMatcher.h"
 #include "aptcc_show_broken.h"
 #include "acqprogress.h"
 #include "pkg_acqfile.h"
@@ -31,8 +32,10 @@
 #include <apt-pkg/tagfile.h>
 #include <apt-pkg/algorithms.h>
 #include <apt-pkg/init.h>
-
 #include <apt-pkg/sptr.h>
+#include <apt-pkg/pkgsystem.h>
+#include <apt-pkg/version.h>
+
 #include <sys/statvfs.h>
 #include <sys/statfs.h>
 #include <sys/wait.h>
@@ -44,9 +47,6 @@
 #include <dirent.h>
 #include <assert.h>
 
-// Gstreamer stuff
-// #include <gst/gst.h>
-
 aptcc::aptcc(PkBackend *backend, bool &cancel)
 	:
 	packageRecords(0),
@@ -66,8 +66,8 @@ aptcc::aptcc(PkBackend *backend, bool &cancel)
 bool aptcc::init()
 {
 	gchar *locale;
-	gchar *proxy_http;
-	gchar *proxy_ftp;
+	gchar *http_proxy;
+	gchar *ftp_proxy;
 
 	// Set PackageKit status
 	pk_backend_set_status(m_backend, PK_STATUS_ENUM_LOADING_CACHE);
@@ -84,18 +84,12 @@ bool aptcc::init()
 	}
 
 	// set http proxy
-	if (proxy_http = pk_backend_get_proxy_http(m_backend)) {
-		_config->Set("Acquire::http::Proxy", proxy_http);
-	} else {
-		_config->Set("Acquire::http::Proxy", "");
-	}
+	http_proxy = pk_backend_get_proxy_http(m_backend);
+	setenv("http_proxy", http_proxy, 1);
 
 	// set ftp proxy
-	if (proxy_ftp = pk_backend_get_proxy_ftp(m_backend)) {
-		_config->Set("Acquire::ftp::Proxy", proxy_ftp);
-	} else {
-		_config->Set("Acquire::ftp::Proxy", "");
-	}
+	ftp_proxy = pk_backend_get_proxy_ftp(m_backend);
+	setenv("ftp_proxy", ftp_proxy, 1);
 
 	packageSourceList = new pkgSourceList;
 	// Read the source list
@@ -143,25 +137,25 @@ aptcc::~aptcc()
 {
 	if (packageRecords)
 	{
-		egg_debug ("~apt_init packageRecords");
+		g_debug ("~apt_init packageRecords");
 		delete packageRecords;
 	}
 
 	if (packageCache)
 	{
-		egg_debug ("~apt_init packageCache");
+		g_debug ("~apt_init packageCache");
 		delete packageCache;
 	}
 
 	if (packageDepCache)
 	{
-		egg_debug ("~apt_init packageDepCache");
+		g_debug ("~apt_init packageDepCache");
 		delete packageDepCache;
 	}
 
 	if (Policy)
 	{
-		egg_debug ("~apt_init Policy");
+		g_debug ("~apt_init Policy");
 		delete Policy;
 	}
 
@@ -347,7 +341,7 @@ void aptcc::emit_package(const pkgCache::PkgIterator &pkg,
 	package_id = pk_package_id_build(pkg.Name(),
 					 ver.VerStr(),
 					 ver.Arch(),
-					 vf.File().Archive());
+					 vf.File().Archive() == NULL ? "" : vf.File().Archive());
 	pk_backend_package(m_backend,
 			   state,
 			   package_id,
@@ -376,8 +370,6 @@ void aptcc::emit_packages(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterat
 	}
 }
 
-
-
 void aptcc::emitUpdates(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > &output,
 			 PkBitfield filters)
 {
@@ -402,9 +394,9 @@ void aptcc::emitUpdates(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator
 
 		// let find what kind of upgrade this is
 		pkgCache::VerFileIterator vf = i->second.FileList();
-		std::string origin  = vf.File().Origin();
-		std::string archive = vf.File().Archive();
-		std::string label   = vf.File().Label();
+		std::string origin  = vf.File().Origin() == NULL ? "" : vf.File().Origin();
+		std::string archive = vf.File().Archive() == NULL ? "" : vf.File().Archive();
+		std::string label   = vf.File().Label() == NULL ? "" : vf.File().Label();
 		if (origin.compare("Debian") == 0 ||
 		    origin.compare("Ubuntu") == 0) {
 			if (ends_with(archive, "-security") ||
@@ -424,134 +416,46 @@ void aptcc::emitUpdates(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator
 	}
 }
 
-
 void aptcc::povidesCodec(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > &output,
-			 gchar **values)
+                         gchar **values)
 {
-	// The search term from PackageKit daemon:
-	// gstreamer0.10(urisource-foobar)
-	// gstreamer0.10(decoder-audio/x-wma)(wmaversion=3)
+    GstMatcher *matcher = new GstMatcher(values);
+    if (!matcher->hasMatches()) {
+        return;
+    }
 
-	// The optional field is more complicated, it can have
-	// types, like int, float...
-	// TODO use some GST helper :/
- 	regex_t pkre;
+    for (pkgCache::PkgIterator pkg = packageCache->PkgBegin(); !pkg.end(); ++pkg)
+    {
+        if (_cancel) {
+            delete matcher;
+            break;
+        }
+        // Ignore packages that exist only due to dependencies.
+        if (pkg.VersionList().end() && pkg.ProvidesList().end()) {
+            continue;
+        }
 
-	const char *pkreg = "^gstreamer\\([0-9\\.]\\+\\)"
-			    "(\\(encoder\\|decoder\\|urisource\\|urisink\\|element\\)-\\([^)]\\+\\))"
-			    "\\((.*)\\)\\?";
+        // TODO search in updates packages
+        // Ignore virtual packages
+        pkgCache::VerIterator ver = find_ver(pkg);
+        if (ver.end() == true) {
+            ver = find_candidate_ver(pkg);
+            if (ver.end() == true) {
+                continue;
+            }
+        }
 
-	if(regcomp(&pkre, pkreg, 0) != 0) {
-		egg_debug("Regex compilation error: ", pkreg);
-		return;
-	}
+        pkgCache::VerFileIterator vf = ver.FileList();
+        pkgRecords::Parser &rec = packageRecords->Lookup(vf);
+        const char *start, *stop;
+        rec.GetRec(start, stop);
+        string record(start, stop - start);
+        if (matcher->matches(record)) {
+            output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(pkg, ver));
+        }
+    }
 
-	gchar *value;
-	vector<pair<string, regex_t> > search;
-	for (uint i = 0; i < g_strv_length(values); i++) {
-		value = values[i];
-		regmatch_t matches[5];
-		if (regexec(&pkre, value, 5, matches, 0) == 0) {
-			string version, type, data, opt;
-			version = "\nGstreamer-Version: ";
-			version.append(string(value, matches[1].rm_so, matches[1].rm_eo - matches[1].rm_so));
-			type = string(value, matches[2].rm_so, matches[2].rm_eo - matches[2].rm_so);
-			data = string(value, matches[3].rm_so, matches[3].rm_eo - matches[3].rm_so);
-			if (matches[4].rm_so != -1) {
-				// remove the '(' ')' that the regex matched
-				opt = string(value, matches[4].rm_so + 1, matches[4].rm_eo - matches[4].rm_so - 2);
-			} else {
-				// if the 4th element did not match match everything
-				opt = ".*";
-			}
-
-			if (type.compare("encoder") == 0) {
-				type = "Gstreamer-Encoders";
-			} else if (type.compare("decoder") == 0) {
-				type = "Gstreamer-Decoders";
-			} else if (type.compare("urisource") == 0) {
-				type = "Gstreamer-Uri-Sources";
-			} else if (type.compare("urisink") == 0) {
-				type = "Gstreamer-Uri-Sinks";
-			} else if (type.compare("element") == 0) {
-				type = "Gstreamer-Elements";
-			}
-			cout << version << endl;
-			cout << type << endl;
-			cout << data << endl;
-			cout << opt << endl;
-			regex_t sre;
-			gchar *itemreg;
-// 			GstCaps *caps;
-// 			caps = gst_caps_new_simple(data.c_str(), opt.c_str());
-			itemreg = g_strdup_printf("^%s:.* %s\\(, %s\\(,.*\\|;.*\\|$\\)\\|;\\|$\\)",
-						  type.c_str(),
-						  data.c_str(),
-						  opt.c_str());
-			if(regcomp(&sre, itemreg, REG_NEWLINE | REG_NOSUB) == 0) {
-				search.push_back(pair<string, regex_t>(version, sre));
-			} else {
-				egg_debug("Search regex compilation error: ", itemreg);
-			}
-			g_free(itemreg);
-		} else {
-			egg_debug("Did not match: %s", value);
-		}
-	}
-	regfree(&pkre);
-
-	// If nothing matched just return
-	if (search.size() == 0) {
-		return;
-	}
-
-	for (pkgCache::PkgIterator pkg = packageCache->PkgBegin(); !pkg.end(); ++pkg)
-	{
-		if (_cancel) {
-			break;
-		}
-		// Ignore packages that exist only due to dependencies.
-		if (pkg.VersionList().end() && pkg.ProvidesList().end()) {
-			continue;
-		}
-
-		// TODO search in updates packages
-		// Ignore virtual packages
-		pkgCache::VerIterator ver = find_ver(pkg);
-		if (ver.end() == true) {
-			ver = find_candidate_ver(pkg);
-			if (ver.end() == true) {
-				continue;
-			}
-		}
-		pkgCache::VerFileIterator vf = ver.FileList();
-		pkgRecords::Parser &rec = packageRecords->Lookup(vf);
-		const char *start, *stop;
-		rec.GetRec(start, stop);
-		string record(start, stop - start);
-		for (vector<pair<string, regex_t> >::iterator i=search.begin();
-		     i != search.end();
-		++i) {
-			if (_cancel) {
-				break;
-			}
-
-			// if Gstreamer-version: xxx is found try to match the regex
-			if (record.find(i->first) != string::npos) {
-				if (regexec(&i->second, record.c_str(), 0, NULL, 0) == 0) {
-					cout << record << endl;
-					output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(pkg, ver));
-				}
-			}
-		}
-	}
-
-	// frees ours regexs
-	for (vector<pair<string, regex_t> >::iterator i=search.begin();
-		     i != search.end();
-		++i) {
-		regfree(&i->second);
-	}
+    delete matcher;
 }
 
 // used to emit packages it collects all the needed info
@@ -571,7 +475,7 @@ void aptcc::emit_details(const pkgCache::PkgIterator &pkg)
 	package_id = pk_package_id_build(pkg.Name(),
 					 ver.VerStr(),
 					 ver.Arch(),
-					 vf.File().Archive());
+					 vf.File().Archive() == NULL ? "" : vf.File().Archive());
 	pk_backend_details(m_backend,
 			   package_id,
 			   "unknown",
@@ -584,49 +488,260 @@ void aptcc::emit_details(const pkgCache::PkgIterator &pkg)
 // used to emit packages it collects all the needed info
 void aptcc::emit_update_detail(const pkgCache::PkgIterator &pkg)
 {
-	pkgCache::VerIterator candver = find_candidate_ver(pkg);
+    // Get the version of the current package
+    pkgCache::VerIterator     currver = find_ver(pkg);
+    pkgCache::VerFileIterator currvf  = currver.FileList();
+    // Build a package_id from the current version
+    gchar *current_package_id;
+    current_package_id = pk_package_id_build(pkg.Name(),
+                                             currver.VerStr(),
+                                             currver.Arch(),
+                                             currvf.File().Archive() == NULL ? "" : currvf.File().Archive());
 
-	pkgCache::VerFileIterator vf = candver.FileList();
-	pkgRecords::Parser &rec = packageRecords->Lookup(vf);
-	string archive(vf.File().Archive());
-	gchar *package_id;
-	package_id = pk_package_id_build(pkg.Name(),
-					candver.VerStr(),
-					candver.Arch(),
-					archive.c_str());
+    // Get the update version
+    pkgCache::VerIterator candver = find_candidate_ver(pkg);
 
-	pkgCache::VerIterator currver = find_ver(pkg);
-	pkgCache::VerFileIterator currvf = currver.FileList();
-	gchar *current_package_id;
-	current_package_id = pk_package_id_build(pkg.Name(),
-						currver.VerStr(),
-						currver.Arch(),
-						currvf.File().Archive());
+    pkgCache::VerFileIterator vf = candver.FileList();
+    string origin = vf.File().Origin() == NULL ? "" : vf.File().Origin();
+    pkgRecords::Parser &rec = packageRecords->Lookup(candver.FileList());
 
-	PkUpdateStateEnum updateState = PK_UPDATE_STATE_ENUM_UNKNOWN;
-	if (archive.compare("stable") == 0) {
-		updateState = PK_UPDATE_STATE_ENUM_STABLE;
-	} else if (archive.compare("testing") == 0) {
-		updateState = PK_UPDATE_STATE_ENUM_TESTING;
-	} else if (archive.compare("unstable")  == 0 ||
-		archive.compare("experimental") == 0)
-	{
-		updateState = PK_UPDATE_STATE_ENUM_UNSTABLE;
-	}
-	pk_backend_update_detail(m_backend,
-				 package_id,
-				 current_package_id,//const gchar *updates
-				 "",//const gchar *obsoletes
-				 "",//const gchar *vendor_url
-				 "",//const gchar *bugzilla_url
-				 "",//const gchar *cve_url
-				 PK_RESTART_ENUM_NONE,//PkRestartEnum restart
-				 "",//const gchar *update_text
-				 "",//const gchar *changelog
-				 updateState,//PkUpdateStateEnum state
-				 "",//const gchar *issued_text
-				 ""//const gchar *updated_text
-				 );
+    // Build the changelogURI
+    char uri[512];
+    string srcpkg;
+    string verstr;
+
+    if (rec.SourcePkg().empty()) {
+        srcpkg = pkg.Name();
+    } else {
+        srcpkg = rec.SourcePkg();
+    }
+    if (origin.compare("Debian") == 0 || origin.compare("Ubuntu") == 0) {
+        string prefix;
+
+        string src_section = candver.Section();
+        if(src_section.find('/') != src_section.npos) {
+            src_section = string(src_section, 0, src_section.find('/'));
+        } else {
+            src_section = "main";
+        }
+
+        prefix += srcpkg[0];
+        if(srcpkg.size() > 3 && srcpkg[0] == 'l' && srcpkg[1] == 'i' && srcpkg[2] == 'b') {
+            prefix = string("lib") + srcpkg[3];
+        }
+
+        if(candver.VerStr() != NULL) {
+            verstr = candver.VerStr();
+        }
+
+        if(verstr.find(':') != verstr.npos) {
+            verstr = string(verstr, verstr.find(':') + 1);
+        }
+
+        if (origin.compare("Debian") == 0) {
+            snprintf(uri,
+                        512,
+                        "http://packages.debian.org/changelogs/pool/%s/%s/%s/%s_%s/changelog",                                    src_section.c_str(),
+                        prefix.c_str(),
+                        srcpkg.c_str(),
+                        srcpkg.c_str(),
+                        verstr.c_str());
+        } else {
+            snprintf(uri,
+                        512,
+                        "http://changelogs.ubuntu.com/changelogs/pool/%s/%s/%s/%s_%s/changelog",                                    src_section.c_str(),
+                        prefix.c_str(),
+                        srcpkg.c_str(),
+                        srcpkg.c_str(),
+                        verstr.c_str());
+        }
+    } else {
+        string pkgfilename;
+        const char *start, *stop;
+        pkgTagSection sec;
+        unsigned long len;
+
+        rec.GetRec(start, stop);
+        len = stop - start;
+        // add +1 to ensure we have the double lineline in the buffer
+        if (start && sec.Scan(start, len + 1)) {
+            pkgfilename = sec.FindS("Filename");
+        }
+
+        string cadidateOriginSiteUrl;
+        if(!vf.end() && vf.File() && vf.File().Site()) {
+            cadidateOriginSiteUrl = vf.File().Site();
+        }
+
+        pkgfilename = pkgfilename.substr(0, pkgfilename.find_last_of('.')) + ".changelog";
+        snprintf(uri,512,"http://%s/%s",
+                cadidateOriginSiteUrl.c_str(),
+                pkgfilename.c_str());
+    }
+    // Create the download object
+    AcqPackageKitStatus Stat(this, m_backend, _cancel);
+
+    // get a fetcher
+    pkgAcquire fetcher;
+    fetcher.Setup(&Stat);
+
+    // fetch the changelog
+    pk_backend_set_status(m_backend, PK_STATUS_ENUM_DOWNLOAD_CHANGELOG);
+    string filename = getChangelogFile(pkg.Name(), origin, verstr, srcpkg, uri, &fetcher);
+
+    string changelog;
+    string update_text;
+    ifstream in(filename.c_str());
+    string line;
+    GRegex *regexVer;
+    regexVer = g_regex_new("(?'source'.+) \\((?'version'.*)\\) "
+                           "(?'dist'.+); urgency=(?'urgency'.+)",
+                           G_REGEX_CASELESS,
+                           G_REGEX_MATCH_ANCHORED,
+                           0);
+    GRegex *regexDate;
+    regexDate = g_regex_new("^ -- (?'maintainer'.+) (?'mail'<.+>)  (?'dayname'\\w+,) "
+"(?'d'\\d+) (?'m'\\w+) (?'y'\\d+) (?'H'\\d+):(?'M'\\d+):(?'s'\\d+) (?'offset'[-\\+]\\d+)$",
+                            G_REGEX_CASELESS,
+                            G_REGEX_MATCH_ANCHORED,
+                            0);
+    string updated;
+    string issued;
+    while (getline(in, line)) {
+        // no need to free str later, it is allocated in a static buffer
+        const char *str = utf8(line.c_str());
+        if (strcmp(str, "") == 0) {
+            changelog.append("\n");
+            continue;
+        } else {
+            changelog.append(str);
+            changelog.append("\n");
+        }
+
+        if (starts_with(str, srcpkg.c_str())) {
+            // Check to see if the the text isn't about the current package,
+            // otherwise add a == version ==
+            GMatchInfo *match_info;
+            if (g_regex_match(regexVer, str, G_REGEX_MATCH_ANCHORED, &match_info)) {
+                gchar *version;
+                version = g_match_info_fetch_named(match_info, "version");
+
+                // Compare if the current version is shown in the changelog, to not
+                // display old changelog information
+                if (_system != 0  &&
+                    _system->VS->DoCmpVersion(version, version + strlen(version),
+                                              currver.VerStr(), currver.VerStr() + strlen(currver.VerStr())) <= 0) {
+                    g_free (version);
+                    break;
+                } else {
+                    if (!update_text.empty()) {
+                        update_text.append("\n\n");
+                    }
+                    update_text.append(" == ");
+                    update_text.append(version);
+                    update_text.append(" ==");
+                    g_free (version);
+                }
+            }
+            g_match_info_free (match_info);
+        } else if (starts_with(str, "  ")) {
+            // update descritption
+            update_text.append("\n");
+            update_text.append(str);
+        } else if (starts_with(str, " --")) {
+            // Parse the text to know when the update was issued,
+            // and when it got updated
+            GMatchInfo *match_info;
+            if (g_regex_match(regexDate, str, G_REGEX_MATCH_ANCHORED, &match_info)) {
+                gchar *tz;
+                gchar *year;
+                gchar *month;
+                gchar *day;
+                gchar *hour;
+                gchar *minute;
+                gchar *seconds;
+                tz = g_match_info_fetch_named(match_info, "offset");
+                year = g_match_info_fetch_named(match_info, "y");
+                month = g_match_info_fetch_named(match_info, "m");
+                day = g_match_info_fetch_named(match_info, "d");
+                hour = g_match_info_fetch_named(match_info, "H");
+                minute = g_match_info_fetch_named(match_info, "M");
+                seconds = g_match_info_fetch_named(match_info, "s");
+                GDateTime *dateTime;
+                dateTime = dateFromString(tz,
+                                          year,
+                                          month,
+                                          day,
+                                          hour,
+                                          minute,
+                                          seconds);
+                g_free(tz);
+                g_free(year);
+                g_free(month);
+                g_free(day);
+                g_free(hour);
+                g_free(minute);
+                g_free(seconds);
+
+                issued = g_date_time_format(dateTime, "%FT%R:%S");
+                if (updated.empty()) {
+                    updated = g_date_time_format(dateTime, "%FT%R:%S");
+                }
+            }
+            g_match_info_free(match_info);
+        }
+    }
+    // Clean structures
+    g_regex_unref(regexVer);
+    g_regex_unref(regexDate);
+    unlink(filename.c_str());
+
+    // Check if the update was updates since it was issued
+    if (issued.compare(updated) == 0) {
+        updated = "";
+    }
+
+    // Build a package_id from the update version
+    string archive = vf.File().Archive() == NULL ? "" : vf.File().Archive();
+    gchar *package_id;
+    package_id = pk_package_id_build(pkg.Name(),
+                    candver.VerStr(),
+                    candver.Arch(),
+                    archive.c_str());
+
+    PkUpdateStateEnum updateState = PK_UPDATE_STATE_ENUM_UNKNOWN;
+    if (archive.compare("stable") == 0) {
+        updateState = PK_UPDATE_STATE_ENUM_STABLE;
+    } else if (archive.compare("testing") == 0) {
+        updateState = PK_UPDATE_STATE_ENUM_TESTING;
+    } else if (archive.compare("unstable")  == 0 ||
+        archive.compare("experimental") == 0)
+    {
+        updateState = PK_UPDATE_STATE_ENUM_UNSTABLE;
+    }
+
+    PkRestartEnum restart = PK_RESTART_ENUM_NONE;
+    if (starts_with(pkg.Name(), "linux-image-") ||
+        starts_with(pkg.Name(), "nvidia-") ||
+        strcmp(pkg.Name(), "libc6") == 0 ||
+        strcmp(pkg.Name(), "dbus") == 0) {
+        restart = PK_RESTART_ENUM_SYSTEM;
+    }
+
+    pk_backend_update_detail(m_backend,
+                             package_id,
+                             current_package_id,//const gchar *updates
+                             "",//const gchar *obsoletes
+                             "",//const gchar *vendor_url
+                             getBugzillaUrls(changelog).c_str(),//const gchar *bugzilla_url
+                             getCVEUrls(changelog).c_str(),//const gchar *cve_url
+                             restart,//PkRestartEnum restart
+                             update_text.c_str(),//const gchar *update_text
+                             changelog.c_str(),//const gchar *changelog
+                             updateState,//PkUpdateStateEnum state
+                             issued.c_str(), //const gchar *issued_text
+                             updated.c_str() //const gchar *updated_text
+                             );
 }
 
 void aptcc::get_depends(vector<pair<pkgCache::PkgIterator, pkgCache::VerIterator> > &output,
@@ -708,7 +823,7 @@ vector<string> search_files (PkBackend *backend, gchar **values, bool &_cancel)
 				 values_str);
 	g_free(values_str);
 	if(regcomp(&re, search, REG_NOSUB) != 0) {
-		egg_debug("Regex compilation error");
+		g_debug("Regex compilation error");
 		g_free(search);
 		return vector<string>();
 	}
@@ -717,7 +832,7 @@ vector<string> search_files (PkBackend *backend, gchar **values, bool &_cancel)
 	DIR *dp;
 	struct dirent *dirp;
 	if (!(dp = opendir("/var/lib/dpkg/info/"))) {
-		egg_debug ("Error opening /var/lib/dpkg/info/\n");
+		g_debug ("Error opening /var/lib/dpkg/info/\n");
 		regfree(&re);
 		return vector<string>();
 	}
@@ -762,7 +877,7 @@ vector<string> searchMimeType (PkBackend *backend, gchar **values, bool &error,
 	g_free(values_str);
 
 	if(regcomp(&re, value, REG_NOSUB) != 0) {
-		egg_debug("Regex compilation error");
+		g_debug("Regex compilation error");
 		g_free(value);
 		return vector<string>();
 	}
@@ -771,7 +886,7 @@ vector<string> searchMimeType (PkBackend *backend, gchar **values, bool &error,
 	DIR *dp;
 	struct dirent *dirp;
 	if (!(dp = opendir("/usr/share/app-install/desktop/"))) {
-		egg_debug ("Error opening /usr/share/app-install/desktop/\n");
+		g_debug ("Error opening /usr/share/app-install/desktop/\n");
 		regfree(&re);
 		error = true;
 		return vector<string>();
@@ -812,71 +927,6 @@ vector<string> searchMimeType (PkBackend *backend, gchar **values, bool &error,
 	return packageList;
 }
 
-// TODO this was replaced with data in the cache
-// used to return files it reads, using the info from the files in /var/lib/dpkg/info/
-// vector<string> searchCodec (PkBackend *backend, gchar **values, bool &error, bool &_cancel)
-// {
-// 	vector<string> packageList;
-// 	regex_t re;
-// 	gchar *value;
-// 	gchar *values_str;
-//
-// 	values_str = g_strjoinv("|", values);
-// 	value = g_strdup_printf("^X-AppInstall-Codecs=\\(.*;\\)\\?\\(%s\\)\\(;.*\\)\\?$",
-// 				values_str);
-// 	g_free(values_str);
-//
-// 	if(regcomp(&re, value, REG_NOSUB) != 0) {
-// 		egg_debug("Regex compilation error");
-// 		g_free(value);
-// 		return vector<string>();
-// 	}
-// 	g_free(value);
-//
-// 	DIR *dp;
-// 	struct dirent *dirp;
-// 	if (!(dp = opendir("/usr/share/app-install/desktop/"))) {
-// 		egg_debug ("Error opening /usr/share/app-install/desktop/\n");
-// 		regfree(&re);
-// 		error = true;
-// 		return vector<string>();
-// 	}
-//
-// 	string line;
-// 	while ((dirp = readdir(dp)) != NULL) {
-// 		if (_cancel) {
-// 			break;
-// 		}
-// 		if (ends_with(dirp->d_name, ".desktop")) {
-// 			string f = "/usr/share/app-install/desktop/" + string(dirp->d_name);
-// 			ifstream in(f.c_str());
-// 			if (!in != 0) {
-// 				continue;
-// 			}
-// 			bool getName = false;
-// 			while (!in.eof()) {
-// 				getline(in, line);
-// 				if (getName) {
-// 					if (starts_with(line, "X-AppInstall-Package=")) {
-// 						// Remove the X-AppInstall-Package=
-// 						packageList.push_back(line.substr(21));
-// 						break;
-// 					}
-// 				} else {
-// 				    if (regexec(&re, line.c_str(), (size_t)0, NULL, 0) == 0) {
-// 						in.seekg(ios_base::beg);
-// 						getName = true;
-// 					}
-// 				}
-// 			}
-// 		}
-// 	}
-//
-// 	closedir(dp);
-// 	regfree(&re);
-// 	return packageList;
-// }
-
 // used to emit files it reads the info directly from the files
 void emit_files (PkBackend *backend, const gchar *pi)
 {
@@ -933,7 +983,7 @@ static bool checkTrusted(pkgAcquire &fetcher, PkBackend *backend)
 	if (pk_backend_get_bool(backend, "only_trusted") == false ||
 	    _config->FindB("APT::Get::AllowUnauthenticated", false) == true)
 	{
-		egg_debug ("Authentication warning overridden.\n");
+		g_debug ("Authentication warning overridden.\n");
 		return true;
 	}
 
@@ -1253,7 +1303,7 @@ void aptcc::updateInterface(int fd, int writeFd)
 						   confmsg);
 				if (write(writeFd, "N\n", 2) != 2) {
 					// TODO we need a DPKG patch to use debconf
-					egg_debug("Failed to write");
+					g_debug("Failed to write");
 				}
 			} else if (strstr(status, "pmstatus") != NULL) {
 				// INSTALL & UPDATE
@@ -1286,34 +1336,34 @@ void aptcc::updateInterface(int fd, int writeFd)
 				// Let's start parsing the status:
 				if (starts_with(str, "Preparing to configure")) {
 					// Preparing to Install/configure
-					cout << "Found Preparing to configure! " << line << endl;
+// 					cout << "Found Preparing to configure! " << line << endl;
 					// The next item might be Configuring so better it be 100
 					m_lastSubProgress = 100;
 					emitTransactionPackage(pkg, PK_INFO_ENUM_PREPARING);
 					pk_backend_set_sub_percentage(m_backend, 75);
 				} else if (starts_with(str, "Preparing for removal")) {
 					// Preparing to Install/configure
-					cout << "Found Preparing for removal! " << line << endl;
+// 					cout << "Found Preparing for removal! " << line << endl;
 					m_lastSubProgress = 50;
 					emitTransactionPackage(pkg, PK_INFO_ENUM_REMOVING);
 					pk_backend_set_sub_percentage(m_backend, m_lastSubProgress);
 				} else if (starts_with(str, "Preparing")) {
 					// Preparing to Install/configure
-					cout << "Found Preparing! " << line << endl;
+// 					cout << "Found Preparing! " << line << endl;
 					// if last package is different then finish it
 					if (!m_lastPackage.empty() && m_lastPackage.compare(pkg) != 0) {
-						cout << "FINISH the last package: " << m_lastPackage << endl;
+// 						cout << "FINISH the last package: " << m_lastPackage << endl;
 						emitTransactionPackage(m_lastPackage, PK_INFO_ENUM_FINISHED);
 					}
 					emitTransactionPackage(pkg, PK_INFO_ENUM_PREPARING);
 					pk_backend_set_sub_percentage(m_backend, 25);
 				} else if (starts_with(str, "Unpacking")) {
-					cout << "Found Unpacking! " << line << endl;
+// 					cout << "Found Unpacking! " << line << endl;
 					emitTransactionPackage(pkg, PK_INFO_ENUM_DECOMPRESSING);
 					pk_backend_set_sub_percentage(m_backend, 50);
 				} else if (starts_with(str, "Configuring")) {
 					// Installing Package
-					cout << "Found Configuring! " << line << endl;
+// 					cout << "Found Configuring! " << line << endl;
 					if (m_lastSubProgress >= 100 && !m_lastPackage.empty()) {
 						cout << "FINISH the last package: " << m_lastPackage << endl;
 						emitTransactionPackage(m_lastPackage, PK_INFO_ENUM_FINISHED);
@@ -1323,24 +1373,24 @@ void aptcc::updateInterface(int fd, int writeFd)
 					pk_backend_set_sub_percentage(m_backend, m_lastSubProgress);
 					m_lastSubProgress += 25;
 				} else if (starts_with(str, "Running dpkg")) {
-					cout << "Found Running dpkg! " << line << endl;
+// 					cout << "Found Running dpkg! " << line << endl;
 				} else if (starts_with(str, "Running")) {
-					cout << "Found Running! " << line << endl;
+// 					cout << "Found Running! " << line << endl;
 					pk_backend_set_status (m_backend, PK_STATUS_ENUM_COMMIT);
 				} else if (starts_with(str, "Installing")) {
-					cout << "Found Installing! " << line << endl;
+// 					cout << "Found Installing! " << line << endl;
 					// FINISH the last package
 					if (!m_lastPackage.empty()) {
-						cout << "FINISH the last package: " << m_lastPackage << endl;
+// 						cout << "FINISH the last package: " << m_lastPackage << endl;
 						emitTransactionPackage(m_lastPackage, PK_INFO_ENUM_FINISHED);
 					}
 					m_lastSubProgress = 0;
 					emitTransactionPackage(pkg, PK_INFO_ENUM_INSTALLING);
 					pk_backend_set_sub_percentage(m_backend, 0);
 				} else if (starts_with(str, "Removing")) {
-					cout << "Found Removing! " << line << endl;
+// 					cout << "Found Removing! " << line << endl;
 					if (m_lastSubProgress >= 100 && !m_lastPackage.empty()) {
-						cout << "FINISH the last package: " << m_lastPackage << endl;
+// 						cout << "FINISH the last package: " << m_lastPackage << endl;
 						emitTransactionPackage(m_lastPackage, PK_INFO_ENUM_FINISHED);
 					}
 					m_lastSubProgress += 25;
@@ -1348,7 +1398,7 @@ void aptcc::updateInterface(int fd, int writeFd)
 					pk_backend_set_sub_percentage(m_backend, m_lastSubProgress);
 				} else if (starts_with(str, "Installed") ||
 					       starts_with(str, "Removed")) {
-					cout << "Found FINISHED! " << line << endl;
+// 					cout << "Found FINISHED! " << line << endl;
 					m_lastSubProgress = 100;
 					emitTransactionPackage(pkg, PK_INFO_ENUM_FINISHED);
 				} else {
@@ -1450,7 +1500,7 @@ bool aptcc::runTransaction(vector<pair<pkgCache::PkgIterator, pkgCache::VerItera
 	OpTextProgress Prog(*_config);
 	int timeout = 10;
 	// TODO test this
-	while (Cache.Open(Prog, WithLock) == false) {
+	while (Cache.Open(&Prog, WithLock) == false) {
 		// failed to open cache, try checkDeps then..
 		// || Cache.CheckDeps(CmdL.FileSize() != 1) == false
 		if (WithLock == false || (timeout <= 0)) {
@@ -1601,7 +1651,8 @@ bool aptcc::installPackages(pkgCacheFile &Cache)
 	AcqPackageKitStatus Stat(this, m_backend, _cancel);
 
 	// get a fetcher
-	pkgAcquire fetcher(&Stat);
+	pkgAcquire fetcher;
+	fetcher.Setup(&Stat);
 
 	// Create the package manager and prepare to download
 	SPtr<pkgPackageManager> PM= _system->CreatePM(Cache);
@@ -1729,7 +1780,7 @@ cout << "How odd.. The sizes didn't match, email apt@packages.debian.org";
 	pkgPackageManager::OrderResult res;
 	res = PM->DoInstallPreFork();
 	if (res == pkgPackageManager::Failed) {
-		egg_warning ("Failed to prepare installation");
+		g_warning ("Failed to prepare installation");
 		show_errors(m_backend, PK_ERROR_ENUM_PACKAGE_DOWNLOAD_FAILED);
 		return false;
 	}
