@@ -42,17 +42,35 @@ static bool _cancel = false;
 static PkBackendSpawn *spawn;
 
 /**
- * backend_initialize:
+ * pk_backend_get_description:
  */
-static void
-backend_initialize (PkBackend *backend)
+gchar *
+pk_backend_get_description (PkBackend *backend)
 {
-	egg_debug ("APTcc Initializing");
+	return g_strdup ("APTcc");
+}
+
+/**
+ * pk_backend_get_author:
+ */
+gchar *
+pk_backend_get_author (PkBackend *backend)
+{
+	return g_strdup ("Daniel Nicoletti <dantti85-pk@yahoo.com.br>");
+}
+
+/**
+ * pk_backend_initialize:
+ */
+void
+pk_backend_initialize (PkBackend *backend)
+{
+	g_debug ("APTcc Initializing");
 
 	if (pkgInitConfig(*_config) == false ||
 	    pkgInitSystem(*_config, _system) == false)
 	{
-		egg_debug ("ERROR initializing backend");
+		g_debug ("ERROR initializing backend");
 	}
 
 	spawn = pk_backend_spawn_new ();
@@ -60,19 +78,19 @@ backend_initialize (PkBackend *backend)
 }
 
 /**
- * backend_destroy:
+ * pk_backend_destroy:
  */
-static void
-backend_destroy (PkBackend *backend)
+void
+pk_backend_destroy (PkBackend *backend)
 {
-	egg_debug ("APTcc being destroyed");
+	g_debug ("APTcc being destroyed");
 }
 
 /**
- * backend_get_groups:
+ * pk_backend_get_groups:
  */
-static PkBitfield
-backend_get_groups (PkBackend *backend)
+PkBitfield
+pk_backend_get_groups (PkBackend *backend)
 {
 	return pk_bitfield_from_enums (
 		PK_GROUP_ENUM_ACCESSORIES,
@@ -83,6 +101,7 @@ backend_get_groups (PkBackend *backend)
 		PK_GROUP_ENUM_DESKTOP_KDE,
 		PK_GROUP_ENUM_DESKTOP_OTHER,
 		PK_GROUP_ENUM_ELECTRONICS,
+		PK_GROUP_ENUM_FONTS,
 		PK_GROUP_ENUM_GAMES,
 		PK_GROUP_ENUM_GRAPHICS,
 		PK_GROUP_ENUM_INTERNET,
@@ -99,10 +118,10 @@ backend_get_groups (PkBackend *backend)
 }
 
 /**
- * backend_get_filters:
+ * pk_backend_get_filters:
  */
-static PkBitfield
-backend_get_filters (PkBackend *backend)
+PkBitfield
+pk_backend_get_filters (PkBackend *backend)
 {
 	return pk_bitfield_from_enums (
 		PK_FILTER_ENUM_GUI,
@@ -113,19 +132,19 @@ backend_get_filters (PkBackend *backend)
 }
 
 /**
- * backend_get_mime_types:
+ * pk_backend_get_mime_types:
  */
-static gchar *
-backend_get_mime_types (PkBackend *backend)
+gchar *
+pk_backend_get_mime_types (PkBackend *backend)
 {
 	return g_strdup ("application/x-deb");
 }
 
 /**
- * backend_cancel:
+ * pk_backend_cancel:
  */
-static void
-backend_cancel (PkBackend *backend)
+void
+pk_backend_cancel (PkBackend *backend)
 {
 	aptcc *m_apt = (aptcc*) pk_backend_get_pointer(backend, "aptcc_obj");
 	if (m_apt) {
@@ -150,7 +169,7 @@ backend_get_depends_or_requires_thread (PkBackend *backend)
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
@@ -202,10 +221,10 @@ backend_get_depends_or_requires_thread (PkBackend *backend)
 }
 
 /**
- * backend_get_depends:
+ * pk_backend_get_depends:
  */
-static void
-backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
+void
+pk_backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_set_bool (backend, "get_depends", true);
 	pk_backend_set_bool (backend, "recursive", recursive);
@@ -213,10 +232,10 @@ backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids
 }
 
 /**
- * backend_get_requires:
+ * pk_backend_get_requires:
  */
-static void
-backend_get_requires (PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
+void
+pk_backend_get_requires (PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_set_bool (backend, "get_depends", false);
 	pk_backend_set_bool (backend, "recursive", recursive);
@@ -224,10 +243,10 @@ backend_get_requires (PkBackend *backend, PkBitfield filters, gchar **package_id
 }
 
 /**
- * backend_get_distro_upgrades:
+ * pk_backend_get_distro_upgrades:
  */
-static void
-backend_get_distro_upgrades (PkBackend *backend)
+void
+pk_backend_get_distro_upgrades (PkBackend *backend)
 {
 	pk_backend_spawn_helper (spawn, "get-distro-upgrade.py", "get-distro-upgrades", NULL);
 }
@@ -250,7 +269,7 @@ backend_get_files_thread (PkBackend *backend)
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
@@ -287,10 +306,10 @@ backend_get_files_thread (PkBackend *backend)
 }
 
 /**
- * backend_get_files:
+ * pk_backend_get_files:
  */
-static void
-backend_get_files (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_get_files (PkBackend *backend, gchar **package_ids)
 {
 	pk_backend_thread_create (backend, backend_get_files_thread);
 }
@@ -314,12 +333,18 @@ backend_get_details_thread (PkBackend *backend)
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
 	}
 
+    if (updateDetail) {
+        // this is needed to compare the changelog verstion to
+        // current package using DoCmpVersion()
+        pkgInitSystem(*_config, _system);
+    }
+
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	for (uint i = 0; i < g_strv_length(package_ids); i++) {
 		pi = package_ids[i];
@@ -358,20 +383,20 @@ backend_get_details_thread (PkBackend *backend)
 }
 
 /**
- * backend_get_update_detail:
+ * pk_backend_get_update_detail:
  */
-static void
-backend_get_update_detail (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_get_update_detail (PkBackend *backend, gchar **package_ids)
 {
 	pk_backend_set_bool (backend, "updateDetail", true);
 	pk_backend_thread_create (backend, backend_get_details_thread);
 }
 
 /**
- * backend_get_details:
+ * pk_backend_get_details:
  */
-static void
-backend_get_details (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_get_details (PkBackend *backend, gchar **package_ids)
 {
 	pk_backend_set_bool (backend, "updateDetail", false);
 	pk_backend_thread_create (backend, backend_get_details_thread);
@@ -389,7 +414,7 @@ backend_get_or_update_system_thread (PkBackend *backend)
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
@@ -401,7 +426,7 @@ backend_get_or_update_system_thread (PkBackend *backend)
 	OpTextProgress Prog(*_config);
 	int timeout = 10;
 	// TODO test this
-	while (Cache.Open(Prog, !getUpdates) == false) {
+	while (Cache.Open(&Prog, !getUpdates) == false) {
 		// failed to open cache, try checkDeps then..
 		// || Cache.CheckDeps(CmdL.FileSize() != 1) == false
 		if (getUpdates == true || (timeout <= 0)) {
@@ -420,7 +445,7 @@ backend_get_or_update_system_thread (PkBackend *backend)
 	if (pkgDistUpgrade(*Cache) == false)
 	{
 		show_broken(backend, Cache, false);
-		egg_debug ("Internal error, DistUpgrade broke stuff");
+		g_debug ("Internal error, DistUpgrade broke stuff");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
@@ -459,20 +484,20 @@ backend_get_or_update_system_thread (PkBackend *backend)
 }
 
 /**
- * backend_get_updates:
+ * pk_backend_get_updates:
  */
-static void
-backend_get_updates (PkBackend *backend, PkBitfield filters)
+void
+pk_backend_get_updates (PkBackend *backend, PkBitfield filters)
 {
 	pk_backend_set_bool (backend, "getUpdates", true);
 	pk_backend_thread_create (backend, backend_get_or_update_system_thread);
 }
 
 /**
- * backend_update_system:
+ * pk_backend_update_system:
  */
-static void
-backend_update_system (PkBackend *backend, gboolean only_trusted)
+void
+pk_backend_update_system (PkBackend *backend, gboolean only_trusted)
 {
 	pk_backend_set_bool (backend, "getUpdates", false);
 	pk_backend_thread_create (backend, backend_get_or_update_system_thread);
@@ -483,15 +508,13 @@ backend_what_provides_thread (PkBackend *backend)
 {
 	PkProvidesEnum provides;
 	PkBitfield filters;
-	const gchar *search;
 	const gchar *provides_text;
 	gchar **values;
 	bool error = false;
 
 	filters  = (PkBitfield)     pk_backend_get_uint (backend, "filters");
 	provides = (PkProvidesEnum) pk_backend_get_uint (backend, "provides");
-	search   = pk_backend_get_string (backend, "search");
-	values   = g_strsplit (search, "&", 0);
+	values   = pk_backend_get_strv (backend, "search");
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
@@ -501,7 +524,7 @@ backend_what_provides_thread (PkBackend *backend)
 		aptcc *m_apt = new aptcc(backend, _cancel);
 		pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 		if (m_apt->init()) {
-			egg_debug ("Failed to create apt cache");
+			g_debug ("Failed to create apt cache");
 			g_strfreev (values);
 			delete m_apt;
 			pk_backend_finished (backend);
@@ -529,6 +552,9 @@ backend_what_provides_thread (PkBackend *backend)
 			    break;
 			}
 			pkgCache::PkgIterator pkg = m_apt->packageCache->FindPkg(i->c_str());
+            if (pkg.end() == true) {
+                continue;
+            }
 			pkgCache::VerIterator ver = m_apt->find_ver(pkg);
 			if (ver.end() == true) {
 				continue;
@@ -536,7 +562,7 @@ backend_what_provides_thread (PkBackend *backend)
 			output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(pkg, ver));
 		}
 
-		if (error) {
+		if (error && provides == PK_PROVIDES_ENUM_MIMETYPE) {
 			// check if app-install-data is installed
 			pkgCache::PkgIterator pkg;
 			pkg = m_apt->packageCache->FindPkg("app-install-data");
@@ -562,16 +588,15 @@ backend_what_provides_thread (PkBackend *backend)
 				       provides_text);
 	}
 
-	g_strfreev (values);
 	pk_backend_finished (backend);
 	return true;
 }
 
 /**
-  * backend_what_provides
+  * pk_backend_what_provides
   */
-static void
-backend_what_provides (PkBackend *backend,
+void
+pk_backend_what_provides (PkBackend *backend,
 		       PkBitfield filters,
 		       PkProvidesEnum provide,
 		       gchar **values)
@@ -580,10 +605,10 @@ backend_what_provides (PkBackend *backend,
 }
 
 /**
- * backend_download_packages_thread:
+ * pk_backend_download_packages_thread:
  */
 static gboolean
-backend_download_packages_thread (PkBackend *backend)
+pk_backend_download_packages_thread (PkBackend *backend)
 {
 	gchar **package_ids;
 	string directory;
@@ -595,7 +620,7 @@ backend_download_packages_thread (PkBackend *backend)
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
@@ -606,7 +631,8 @@ backend_download_packages_thread (PkBackend *backend)
 	AcqPackageKitStatus Stat(m_apt, backend, _cancel);
 
 	// get a fetcher
-	pkgAcquire fetcher(&Stat);
+	pkgAcquire fetcher;
+	fetcher.Setup(&Stat);
 	string filelist;
 	gchar *pi;
 
@@ -698,26 +724,26 @@ backend_download_packages_thread (PkBackend *backend)
 }
 
 /**
- * backend_download_packages:
+ * pk_backend_download_packages:
  */
-static void
-backend_download_packages (PkBackend *backend, gchar **package_ids, const gchar *directory)
+void
+pk_backend_download_packages (PkBackend *backend, gchar **package_ids, const gchar *directory)
 {
-	pk_backend_thread_create (backend, backend_download_packages_thread);
+	pk_backend_thread_create (backend, pk_backend_download_packages_thread);
 }
 
 /**
- * backend_refresh_cache_thread:
+ * pk_backend_refresh_cache_thread:
  */
 static gboolean
-backend_refresh_cache_thread (PkBackend *backend)
+pk_backend_refresh_cache_thread (PkBackend *backend)
 {
 	pk_backend_set_allow_cancel (backend, true);
 
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
@@ -746,9 +772,9 @@ backend_refresh_cache_thread (PkBackend *backend)
 	// Rebuild the cache.
 	pkgCacheFile Cache;
 	OpTextProgress Prog(*_config);
-	if (Cache.BuildCaches(Prog, true) == false) {
+	if (Cache.BuildCaches(&Prog, true) == false) {
 		if (_error->PendingError() == true) {
-			show_errors(backend, PK_ERROR_ENUM_CANNOT_GET_LOCK);
+			show_errors(backend, PK_ERROR_ENUM_CANNOT_FETCH_SOURCES);
 		}
 		delete m_apt;
 		pk_backend_finished (backend);
@@ -767,17 +793,17 @@ backend_refresh_cache_thread (PkBackend *backend)
 }
 
 /**
- * backend_refresh_cache:
+ * pk_backend_refresh_cache:
  */
-static void
-backend_refresh_cache (PkBackend *backend, gboolean force)
+void
+pk_backend_refresh_cache (PkBackend *backend, gboolean force)
 {
-	pk_backend_thread_create (backend, backend_refresh_cache_thread);
+	pk_backend_thread_create (backend, pk_backend_refresh_cache_thread);
 }
 
 
 static gboolean
-backend_resolve_thread (PkBackend *backend)
+pk_backend_resolve_thread (PkBackend *backend)
 {
 	gchar **package_ids;
 	PkBitfield filters;
@@ -789,7 +815,7 @@ backend_resolve_thread (PkBackend *backend)
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
@@ -846,16 +872,16 @@ backend_resolve_thread (PkBackend *backend)
 }
 
 /**
- * backend_resolve:
+ * pk_backend_resolve:
  */
-static void
-backend_resolve (PkBackend *backend, PkBitfield filters, gchar **packages)
+void
+pk_backend_resolve (PkBackend *backend, PkBitfield filters, gchar **packages)
 {
-	pk_backend_thread_create (backend, backend_resolve_thread);
+	pk_backend_thread_create (backend, pk_backend_resolve_thread);
 }
 
 static gboolean
-backend_search_files_thread (PkBackend *backend)
+pk_backend_search_files_thread (PkBackend *backend)
 {
 	gchar **values;
 	PkBitfield filters;
@@ -870,7 +896,7 @@ backend_search_files_thread (PkBackend *backend)
 		aptcc *m_apt = new aptcc(backend, _cancel);
 		pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 		if (m_apt->init()) {
-			egg_debug ("Failed to create apt cache");
+			g_debug ("Failed to create apt cache");
 			delete m_apt;
 			pk_backend_finished (backend);
 			return false;
@@ -886,6 +912,9 @@ backend_search_files_thread (PkBackend *backend)
 			    break;
 			}
 			pkgCache::PkgIterator pkg = m_apt->packageCache->FindPkg(i->c_str());
+            if (pkg.end() == true) {
+                continue;
+            }
 			pkgCache::VerIterator ver = m_apt->find_ver(pkg);
 			if (ver.end() == true)
 			{
@@ -904,12 +933,12 @@ backend_search_files_thread (PkBackend *backend)
 }
 
 /**
- * backend_search_files:
+ * pk_backend_search_files:
  */
-static void
-backend_search_files (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_files (PkBackend *backend, PkBitfield filters, gchar **values)
 {
-	pk_backend_thread_create (backend, backend_search_files_thread);
+	pk_backend_thread_create (backend, pk_backend_search_files_thread);
 }
 
 static gboolean
@@ -939,7 +968,7 @@ backend_search_groups_thread (PkBackend *backend)
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
@@ -988,10 +1017,10 @@ backend_search_groups_thread (PkBackend *backend)
 }
 
 /**
- * backend_search_groups:
+ * pk_backend_search_groups:
  */
-static void
-backend_search_groups (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_groups (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_thread_create (backend, backend_search_groups_thread);
 }
@@ -1013,7 +1042,7 @@ backend_search_package_thread (PkBackend *backend)
 	matcher *m_matcher = new matcher(search);
 	g_free(search);
 	if (m_matcher->hasError()) {
-		egg_debug("Regex compilation error");
+		g_debug("Regex compilation error");
 		delete m_matcher;
 		pk_backend_finished (backend);
 		return false;
@@ -1022,7 +1051,7 @@ backend_search_package_thread (PkBackend *backend)
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_matcher;
 		delete m_apt;
 		pk_backend_finished (backend);
@@ -1050,9 +1079,9 @@ backend_search_package_thread (PkBackend *backend)
 				continue;
 			}
 
+			pkgCache::VerIterator ver = m_apt->find_ver(pkg);
 			if (m_matcher->matches(pkg.Name())) {
 				// Don't insert virtual packages instead add what it provides
-				pkgCache::VerIterator ver = m_apt->find_ver(pkg);
 				if (ver.end() == false) {
 					output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(pkg, ver));
 				} else {
@@ -1071,12 +1100,9 @@ backend_search_package_thread (PkBackend *backend)
 				}
 			} else {
 				// Don't insert virtual packages instead add what it provides
-				pkgCache::VerIterator ver = m_apt->find_ver(pkg);
 				if (ver.end() == false) {
-					if (m_matcher->matches(get_default_short_description(ver, m_apt->packageRecords))
-					    || m_matcher->matches(get_default_long_description(ver, m_apt->packageRecords))
-					    || m_matcher->matches(get_short_description(ver, m_apt->packageRecords))
-					    || m_matcher->matches(get_long_description(ver, m_apt->packageRecords)))
+					if (m_matcher->matches(get_short_description(ver, m_apt->packageRecords))
+					 || m_matcher->matches(get_long_description(ver, m_apt->packageRecords)))
 					{
 						output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(pkg, ver));
 					}
@@ -1090,11 +1116,8 @@ backend_search_package_thread (PkBackend *backend)
 						{
 							// we add the package now because we will need to
 							// remove duplicates later anyway
-							if (m_matcher->matches(Prv.OwnerPkg().Name())
-							    || m_matcher->matches(get_default_short_description(ver, m_apt->packageRecords))
-							    || m_matcher->matches(get_default_long_description(ver, m_apt->packageRecords))
-							    || m_matcher->matches(get_short_description(ver, m_apt->packageRecords))
-							    || m_matcher->matches(get_long_description(ver, m_apt->packageRecords)))
+							if (m_matcher->matches(get_short_description(ver, m_apt->packageRecords))
+							 || m_matcher->matches(get_long_description(ver, m_apt->packageRecords)))
 							{
 								output.push_back(pair<pkgCache::PkgIterator, pkgCache::VerIterator>(Prv.OwnerPkg(), ver));
 							}
@@ -1148,20 +1171,20 @@ backend_search_package_thread (PkBackend *backend)
 }
 
 /**
- * backend_search_names:
+ * pk_backend_search_names:
  */
-static void
-backend_search_names (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_names (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_set_bool(backend, "search_details", false);
 	pk_backend_thread_create(backend, backend_search_package_thread);
 }
 
 /**
- * backend_search_details:
+ * pk_backend_search_details:
  */
-static void
-backend_search_details (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_details (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_set_bool(backend, "search_details", true);
 	pk_backend_thread_create(backend, backend_search_package_thread);
@@ -1184,7 +1207,7 @@ backend_manage_packages_thread (PkBackend *backend)
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
@@ -1238,10 +1261,10 @@ backend_manage_packages_thread (PkBackend *backend)
 }
 
 /**
- * backend_install_update_packages:
+ * pk_backend_install_packages:
  */
-static void
-backend_install_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
+void
+pk_backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	pk_backend_set_bool(backend, "simulate", false);
 	pk_backend_set_bool(backend, "remove", false);
@@ -1249,10 +1272,21 @@ backend_install_update_packages (PkBackend *backend, gboolean only_trusted, gcha
 }
 
 /**
- * backend_simulate_install_update_packages:
+ * pk_backend_update_packages:
  */
-static void
-backend_simulate_install_update_packages (PkBackend *backend, gchar **packages)
+void
+pk_backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
+{
+	pk_backend_set_bool(backend, "simulate", false);
+	pk_backend_set_bool(backend, "remove", false);
+	pk_backend_thread_create (backend, backend_manage_packages_thread);
+}
+
+/**
+ * pk_backend_simulate_install_packages:
+ */
+void
+pk_backend_simulate_install_packages (PkBackend *backend, gchar **packages)
 {
 	pk_backend_set_bool(backend, "simulate", true);
 	pk_backend_set_bool(backend, "remove", false);
@@ -1260,10 +1294,21 @@ backend_simulate_install_update_packages (PkBackend *backend, gchar **packages)
 }
 
 /**
- * backend_remove_packages:
+ * pk_backend_simulate_update_packages:
  */
-static void
-backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow_deps, gboolean autoremove)
+void
+pk_backend_simulate_update_packages (PkBackend *backend, gchar **packages)
+{
+	pk_backend_set_bool(backend, "simulate", true);
+	pk_backend_set_bool(backend, "remove", false);
+	pk_backend_thread_create (backend, backend_manage_packages_thread);
+}
+
+/**
+ * pk_backend_remove_packages:
+ */
+void
+pk_backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow_deps, gboolean autoremove)
 {
 	pk_backend_set_bool(backend, "simulate", false);
 	pk_backend_set_bool(backend, "remove", true);
@@ -1271,10 +1316,10 @@ backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow
 }
 
 /**
- * backend_simulate_remove_packages:
+ * pk_backend_simulate_remove_packages:
  */
-static void
-backend_simulate_remove_packages (PkBackend *backend, gchar **packages, gboolean autoremove)
+void
+pk_backend_simulate_remove_packages (PkBackend *backend, gchar **packages, gboolean autoremove)
 {
 	pk_backend_set_bool(backend, "simulate", true);
 	pk_backend_set_bool(backend, "remove", true);
@@ -1386,20 +1431,20 @@ backend_repo_manager_thread (PkBackend *backend)
 }
 
 /**
- * backend_get_repo_list:
+ * pk_backend_get_repo_list:
  */
-static void
-backend_get_repo_list (PkBackend *backend, PkBitfield filters)
+void
+pk_backend_get_repo_list (PkBackend *backend, PkBitfield filters)
 {
 	pk_backend_set_bool(backend, "list", true);
 	pk_backend_thread_create(backend, backend_repo_manager_thread);
 }
 
 /**
- * backend_repo_enable:
+ * pk_backend_repo_enable:
  */
-static void
-backend_repo_enable (PkBackend *backend, const gchar *rid, gboolean enabled)
+void
+pk_backend_repo_enable (PkBackend *backend, const gchar *rid, gboolean enabled)
 {
 	pk_backend_set_bool(backend, "list", false);
 	pk_backend_thread_create(backend, backend_repo_manager_thread);
@@ -1415,7 +1460,7 @@ backend_get_packages_thread (PkBackend *backend)
 	aptcc *m_apt = new aptcc(backend, _cancel);
 	pk_backend_set_pointer(backend, "aptcc_obj", m_apt);
 	if (m_apt->init()) {
-		egg_debug ("Failed to create apt cache");
+		g_debug ("Failed to create apt cache");
 		delete m_apt;
 		pk_backend_finished (backend);
 		return false;
@@ -1451,53 +1496,10 @@ backend_get_packages_thread (PkBackend *backend)
 }
 
 /**
- * backend_get_packages:
+ * pk_backend_get_packages:
  */
-static void
-backend_get_packages (PkBackend *backend, PkBitfield filter)
+void
+pk_backend_get_packages (PkBackend *backend, PkBitfield filter)
 {
 	pk_backend_thread_create (backend, backend_get_packages_thread);
 }
-
-extern "C" PK_BACKEND_OPTIONS (
-	"APTcc",					/* description */
-	"Daniel Nicoletti <dantti85-pk@yahoo.com.br>",	/* author */
-	backend_initialize,	        		/* initalize */
-	backend_destroy,				/* destroy */
-	backend_get_groups,				/* get_groups */
-	backend_get_filters,				/* get_filters */
-	NULL,						/* get_roles */
-	backend_get_mime_types,				/* get_mime_types */
-	backend_cancel,					/* cancel */
-	backend_download_packages,			/* download_packages */
-	NULL,						/* get_categories */
-	backend_get_depends,				/* get_depends */
-	backend_get_details,				/* get_details */
-	backend_get_distro_upgrades,			/* get_distro_upgrades */
-	backend_get_files,				/* get_files */
-	backend_get_packages,				/* get_packages */
-	backend_get_repo_list,				/* get_repo_list */
-	backend_get_requires,				/* get_requires */
-	backend_get_update_detail,			/* get_update_detail */
-	backend_get_updates,				/* get_updates */
-	NULL,						/* install_files */
-	backend_install_update_packages,		/* install_packages */
-	NULL,						/* install_signature */
-	backend_refresh_cache,				/* refresh_cache */
-	backend_remove_packages,			/* remove_packages */
-	backend_repo_enable,				/* repo_enable */
-	NULL,						/* repo_set_data */
-	backend_resolve,				/* resolve */
-	NULL,						/* rollback */
-	backend_search_details,				/* search_details */
-	backend_search_files,				/* search_files */
-	backend_search_groups,				/* search_groups */
-	backend_search_names,				/* search_names */
-	backend_install_update_packages,		/* update_packages */
-	backend_update_system,				/* update_system */
-	backend_what_provides,				/* what_provides */
-	NULL,						/* simulate_install_files */
-	backend_simulate_install_update_packages,	/* simulate_install_packages */
-	backend_simulate_remove_packages,		/* simulate_remove_packages */
-	backend_simulate_install_update_packages	/* simulate_update_packages */
-);
