@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2007-2008 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2007-2010 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -23,6 +23,8 @@
 #include <glib.h>
 #include <string.h>
 #include <stdlib.h>
+#include <gio/gio.h>
+#include <gio/gunixsocketaddress.h>
 
 #include <pk-backend.h>
 
@@ -47,29 +49,31 @@ static gboolean _use_gpg = FALSE;
 static gboolean _use_trusted = TRUE;
 static gboolean _use_distro_upgrade = FALSE;
 static PkBitfield _filters = 0;
+static GSocket *_socket = NULL;
+static guint _socket_listen_id = 0;
 
 /**
- * backend_initialize:
+ * pk_backend_initialize:
  */
-static void
-backend_initialize (PkBackend *backend)
+void
+pk_backend_initialize (PkBackend *backend)
 {
 	_progress_percentage = 0;
 }
 
 /**
- * backend_destroy:
+ * pk_backend_destroy:
  */
-static void
-backend_destroy (PkBackend *backend)
+void
+pk_backend_destroy (PkBackend *backend)
 {
 }
 
 /**
- * backend_get_groups:
+ * pk_backend_get_groups:
  */
-static PkBitfield
-backend_get_groups (PkBackend *backend)
+PkBitfield
+pk_backend_get_groups (PkBackend *backend)
 {
 	return pk_bitfield_from_enums (PK_GROUP_ENUM_ACCESSIBILITY,
 		PK_GROUP_ENUM_GAMES,
@@ -78,10 +82,10 @@ backend_get_groups (PkBackend *backend)
 }
 
 /**
- * backend_get_filters:
+ * pk_backend_get_filters:
  */
-static PkBitfield
-backend_get_filters (PkBackend *backend)
+PkBitfield
+pk_backend_get_filters (PkBackend *backend)
 {
 	return pk_bitfield_from_enums (PK_FILTER_ENUM_GUI,
 		PK_FILTER_ENUM_INSTALLED,
@@ -90,19 +94,19 @@ backend_get_filters (PkBackend *backend)
 }
 
 /**
- * backend_get_mime_types:
+ * pk_backend_get_mime_types:
  */
-static gchar *
-backend_get_mime_types (PkBackend *backend)
+gchar *
+pk_backend_get_mime_types (PkBackend *backend)
 {
 	return g_strdup ("application/x-rpm;application/x-deb");
 }
 
 /**
- * backend_cancel_timeout:
+ * pk_backend_cancel_timeout:
  */
 static gboolean
-backend_cancel_timeout (gpointer data)
+pk_backend_cancel_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 
@@ -117,25 +121,25 @@ backend_cancel_timeout (gpointer data)
 }
 
 /**
- * backend_cancel:
+ * pk_backend_cancel:
  */
-static void
-backend_cancel (PkBackend *backend)
+void
+pk_backend_cancel (PkBackend *backend)
 {
 	/* cancel the timeout */
 	if (_signal_timeout != 0) {
 		g_source_remove (_signal_timeout);
 
 		/* emulate that it takes us a few ms to cancel */
-		g_timeout_add (1500, backend_cancel_timeout, backend);
+		g_timeout_add (1500, pk_backend_cancel_timeout, backend);
 	}
 }
 
 /**
- * backend_get_depends:
+ * pk_backend_get_depends:
  */
-static void
-backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
+void
+pk_backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
@@ -152,10 +156,10 @@ backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids
 }
 
 /**
- * backend_get_details:
+ * pk_backend_get_details:
  */
-static void
-backend_get_details (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_get_details (PkBackend *backend, gchar **package_ids)
 {
 	guint i;
 	guint len;
@@ -210,10 +214,10 @@ backend_get_details (PkBackend *backend, gchar **package_ids)
 }
 
 /**
- * backend_get_distro_upgrades:
+ * pk_backend_get_distro_upgrades:
  */
-static void
-backend_get_distro_upgrades (PkBackend *backend)
+void
+pk_backend_get_distro_upgrades (PkBackend *backend)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	if (!_use_distro_upgrade)
@@ -227,10 +231,10 @@ out:
 }
 
 /**
- * backend_get_files:
+ * pk_backend_get_files:
  */
-static void
-backend_get_files (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_get_files (PkBackend *backend, gchar **package_ids)
 {
 	guint i;
 	guint len;
@@ -254,10 +258,10 @@ backend_get_files (PkBackend *backend, gchar **package_ids)
 }
 
 /**
- * backend_get_requires:
+ * pk_backend_get_requires:
  */
-static void
-backend_get_requires (PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
+void
+pk_backend_get_requires (PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
@@ -268,10 +272,10 @@ backend_get_requires (PkBackend *backend, PkBitfield filters, gchar **package_id
 }
 
 /**
- * backend_get_update_detail_timeout:
+ * pk_backend_get_update_detail_timeout:
  **/
 static gboolean
-backend_get_update_detail_timeout (gpointer data)
+pk_backend_get_update_detail_timeout (gpointer data)
 {
 	guint i;
 	guint len;
@@ -354,21 +358,21 @@ backend_get_update_detail_timeout (gpointer data)
 }
 
 /**
- * backend_get_update_detail:
+ * pk_backend_get_update_detail:
  */
-static void
-backend_get_update_detail (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_get_update_detail (PkBackend *backend, gchar **package_ids)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	_package_ids = package_ids;
-	_signal_timeout = g_timeout_add (500, backend_get_update_detail_timeout, backend);
+	_signal_timeout = g_timeout_add (500, pk_backend_get_update_detail_timeout, backend);
 }
 
 /**
- * backend_get_updates_timeout:
+ * pk_backend_get_updates_timeout:
  **/
 static gboolean
-backend_get_updates_timeout (gpointer data)
+pk_backend_get_updates_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 
@@ -400,10 +404,10 @@ backend_get_updates_timeout (gpointer data)
 }
 
 /**
- * backend_get_updates:
+ * pk_backend_get_updates:
  */
-static void
-backend_get_updates (PkBackend *backend, PkBitfield filters)
+void
+pk_backend_get_updates (PkBackend *backend, PkBitfield filters)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_set_percentage (backend, PK_BACKEND_PERCENTAGE_INVALID);
@@ -413,11 +417,11 @@ backend_get_updates (PkBackend *backend, PkBitfield filters)
 		pk_backend_finished (backend);
 		return;
 	}
-	_signal_timeout = g_timeout_add (1000, backend_get_updates_timeout, backend);
+	_signal_timeout = g_timeout_add (1000, pk_backend_get_updates_timeout, backend);
 }
 
 static gboolean
-backend_install_timeout (gpointer data)
+pk_backend_install_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 	guint sub_percent;
@@ -454,10 +458,10 @@ backend_install_timeout (gpointer data)
 }
 
 /**
- * backend_install_packages:
+ * pk_backend_install_packages:
  */
-static void
-backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
+void
+pk_backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	const gchar *license_agreement;
 	const gchar *eula_id;
@@ -528,21 +532,21 @@ backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **pac
 	pk_backend_package (backend, PK_INFO_ENUM_DOWNLOADING,
 			    "gtkhtml2;2.19.1-4.fc8;i386;fedora",
 			    "An HTML widget for GTK+ 2.0");
-	_signal_timeout = g_timeout_add (100, backend_install_timeout, backend);
+	_signal_timeout = g_timeout_add (100, pk_backend_install_timeout, backend);
 }
 
 /**
- * backend_install_signature:
+ * pk_backend_install_signature:
  */
-static void
-backend_install_signature (PkBackend *backend, PkSigTypeEnum type,
+void
+pk_backend_install_signature (PkBackend *backend, PkSigTypeEnum type,
 			   const gchar *key_id, const gchar *package_id)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_INSTALL);
 	if (type == PK_SIGTYPE_ENUM_GPG &&
 	    /* egg_strequal (package_id, "vips-doc;7.12.4-2.fc8;noarch;linva") && */
 	    g_strcmp0 (key_id, "BB7576AC") == 0) {
-		egg_debug ("installed signature %s for %s", key_id, package_id);
+		g_debug ("installed signature %s for %s", key_id, package_id);
 		_has_signature = TRUE;
 	} else {
 		pk_backend_error_code (backend, PK_ERROR_ENUM_GPG_FAILURE,
@@ -553,10 +557,10 @@ backend_install_signature (PkBackend *backend, PkSigTypeEnum type,
 }
 
 /**
- * backend_refresh_cache_timeout:
+ * pk_backend_refresh_cache_timeout:
  */
 static gboolean
-backend_install_files_timeout (gpointer data)
+pk_backend_install_files_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 	pk_backend_finished (backend);
@@ -564,21 +568,21 @@ backend_install_files_timeout (gpointer data)
 }
 
 /**
- * backend_install_files:
+ * pk_backend_install_files:
  */
-static void
-backend_install_files (PkBackend *backend, gboolean only_trusted, gchar **full_paths)
+void
+pk_backend_install_files (PkBackend *backend, gboolean only_trusted, gchar **full_paths)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_INSTALL);
 	pk_backend_set_percentage (backend, 101);
-	_signal_timeout = g_timeout_add (2000, backend_install_files_timeout, backend);
+	_signal_timeout = g_timeout_add (2000, pk_backend_install_files_timeout, backend);
 }
 
 /**
- * backend_refresh_cache_timeout:
+ * pk_backend_refresh_cache_timeout:
  */
 static gboolean
-backend_refresh_cache_timeout (gpointer data)
+pk_backend_refresh_cache_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 	if (_progress_percentage == 100) {
@@ -593,10 +597,10 @@ backend_refresh_cache_timeout (gpointer data)
 }
 
 /**
- * backend_refresh_cache:
+ * pk_backend_refresh_cache:
  */
-static void
-backend_refresh_cache (PkBackend *backend, gboolean force)
+void
+pk_backend_refresh_cache (PkBackend *backend, gboolean force)
 {
 	_progress_percentage = 0;
 
@@ -607,14 +611,14 @@ backend_refresh_cache (PkBackend *backend, gboolean force)
 
 	pk_backend_set_allow_cancel (backend, TRUE);
 	pk_backend_set_status (backend, PK_STATUS_ENUM_REFRESH_CACHE);
-	_signal_timeout = g_timeout_add (500, backend_refresh_cache_timeout, backend);
+	_signal_timeout = g_timeout_add (500, pk_backend_refresh_cache_timeout, backend);
 }
 
 /**
- * backend_resolve_timeout:
+ * pk_backend_resolve_timeout:
  */
 static gboolean
-backend_resolve_timeout (gpointer data)
+pk_backend_resolve_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 	guint i;
@@ -655,21 +659,21 @@ backend_resolve_timeout (gpointer data)
 }
 
 /**
- * backend_resolve:
+ * pk_backend_resolve:
  */
-static void
-backend_resolve (PkBackend *backend, PkBitfield filters, gchar **packages)
+void
+pk_backend_resolve (PkBackend *backend, PkBitfield filters, gchar **packages)
 {
 	_filters = filters;
 	_package_ids = packages;
-	_signal_timeout = g_timeout_add (20, backend_resolve_timeout, backend);
+	_signal_timeout = g_timeout_add (20, pk_backend_resolve_timeout, backend);
 }
 
 /**
- * backend_rollback_timeout:
+ * pk_backend_rollback_timeout:
  */
 static gboolean
-backend_rollback_timeout (gpointer data)
+pk_backend_rollback_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 	if (_progress_percentage == 0) {
@@ -691,10 +695,10 @@ backend_rollback_timeout (gpointer data)
 
 
 /**
- * backend_rollback:
+ * pk_backend_rollback:
  */
-static void
-backend_rollback (PkBackend *backend, const gchar *transaction_id)
+void
+pk_backend_rollback (PkBackend *backend, const gchar *transaction_id)
 {
 	/* allow testing error condition */
 	if (g_strcmp0 (transaction_id, "/397_eeecadad_data") == 0) {
@@ -706,14 +710,14 @@ backend_rollback (PkBackend *backend, const gchar *transaction_id)
 	pk_backend_set_percentage (backend, PK_BACKEND_PERCENTAGE_INVALID);
 	pk_backend_set_allow_cancel (backend, TRUE);
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-	_signal_timeout = g_timeout_add (2000, backend_rollback_timeout, backend);
+	_signal_timeout = g_timeout_add (2000, pk_backend_rollback_timeout, backend);
 }
 
 /**
- * backend_remove_packages:
+ * pk_backend_remove_packages:
  */
-static void
-backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow_deps, gboolean autoremove)
+void
+pk_backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow_deps, gboolean autoremove)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_REMOVE);
 	pk_backend_error_code (backend, PK_ERROR_ENUM_NO_NETWORK, "No network connection available");
@@ -721,10 +725,10 @@ backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow
 }
 
 /**
- * backend_search_details:
+ * pk_backend_search_details:
  */
-static void
-backend_search_details (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_details (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_set_allow_cancel (backend, TRUE);
@@ -735,10 +739,10 @@ backend_search_details (PkBackend *backend, PkBitfield filters, gchar **values)
 }
 
 /**
- * backend_search_files:
+ * pk_backend_search_files:
  */
-static void
-backend_search_files (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_files (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_set_allow_cancel (backend, TRUE);
@@ -754,10 +758,10 @@ backend_search_files (PkBackend *backend, PkBitfield filters, gchar **values)
 }
 
 /**
- * backend_search_groups:
+ * pk_backend_search_groups:
  */
-static void
-backend_search_groups (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_groups (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_set_allow_cancel (backend, TRUE);
@@ -771,16 +775,16 @@ backend_search_groups (PkBackend *backend, PkBitfield filters, gchar **values)
 }
 
 /**
- * backend_search_name_timeout:
+ * pk_backend_search_name_timeout:
  **/
 static gboolean
-backend_search_name_timeout (gpointer data)
+pk_backend_search_name_timeout (gpointer data)
 {
 	gchar *locale;
 	PkBackend *backend = (PkBackend *) data;
 	locale = pk_backend_get_locale (backend);
 
-	egg_debug ("locale is %s", locale);
+	g_debug ("locale is %s", locale);
 	if (g_strcmp0 (locale, "en_GB.utf8") != 0) {
 		pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
 				    "evince;0.9.3-5.fc8;i386;installed",
@@ -804,22 +808,22 @@ backend_search_name_timeout (gpointer data)
 }
 
 /**
- * backend_search_names:
+ * pk_backend_search_names:
  */
-static void
-backend_search_names (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_names (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_set_percentage (backend, PK_BACKEND_PERCENTAGE_INVALID);
 	pk_backend_set_allow_cancel (backend, TRUE);
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
-	_signal_timeout = g_timeout_add (2000, backend_search_name_timeout, backend);
+	_signal_timeout = g_timeout_add (2000, pk_backend_search_name_timeout, backend);
 }
 
 /**
- * backend_update_packages_download_timeout:
+ * pk_backend_update_packages_download_timeout:
  **/
 static gboolean
-backend_update_packages_download_timeout (gpointer data)
+pk_backend_update_packages_download_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 	guint sub;
@@ -897,10 +901,10 @@ backend_update_packages_download_timeout (gpointer data)
 }
 
 /**
- * backend_update_packages:
+ * pk_backend_update_packages:
  */
-static void
-backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
+void
+pk_backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	const gchar *eula_id;
 	const gchar *license_agreement;
@@ -955,14 +959,21 @@ backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **pack
 	pk_backend_set_allow_cancel (backend, TRUE);
 	pk_backend_set_percentage (backend, 0);
 	pk_backend_set_status (backend, PK_STATUS_ENUM_DOWNLOAD);
-	_signal_timeout = g_timeout_add (200, backend_update_packages_download_timeout, backend);
+	_signal_timeout = g_timeout_add (200, pk_backend_update_packages_download_timeout, backend);
 }
 
 static gboolean
-backend_update_system_timeout (gpointer data)
+pk_backend_update_system_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 	if (_progress_percentage == 100) {
+
+		/* cleanup socket stuff */
+		if (_socket != NULL)
+			g_object_unref (_socket);
+		if (_socket_listen_id != 0)
+			g_source_remove (_socket_listen_id);
+
 		pk_backend_finished (backend);
 		return FALSE;
 	}
@@ -1019,27 +1030,155 @@ backend_update_system_timeout (gpointer data)
 	return TRUE;
 }
 
+
 /**
- * backend_update_system:
- */
-static void
-backend_update_system (PkBackend *backend, gboolean only_trusted)
+ * pk_backend_socket_has_data_cb:
+ **/
+static gboolean
+pk_backend_socket_has_data_cb (GSocket *socket, GIOCondition condition, PkBackend *backend)
 {
+	GError *error = NULL;
+	gsize len;
+	gchar buffer[1024];
+	gboolean ret = TRUE;
+	gint wrote = 0;
+
+	/* the helper process exited */
+	if ((condition & G_IO_HUP) > 0) {
+		pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR,
+				       "socket was disconnected");
+		pk_backend_finished (backend);
+		ret = FALSE;
+		goto out;
+	}
+
+	/* there is data */
+	if ((condition & G_IO_IN) > 0) {
+		len = g_socket_receive (socket, buffer, 1024, NULL, &error);
+		if (error != NULL) {
+			pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR,
+					       "failed to read: %s", error->message);
+			pk_backend_finished (backend);
+			g_error_free (error);
+			ret = FALSE;
+			goto out;
+		}
+		if (len == 0)
+			goto out;
+		buffer[len] = '\0';
+		if (g_strcmp0 (buffer, "pong\n") == 0) {
+			/* send a message so we can verify in the self checks */
+			pk_backend_message (backend, PK_MESSAGE_ENUM_PARAMETER_INVALID, buffer);
+
+			/* verify we can write into the socket */
+			wrote = g_socket_send (_socket, "invalid\n", 8, NULL, &error);
+			if (error != NULL) {
+				pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR,
+						       "failed to write to socket: %s", error->message);
+				pk_backend_finished (backend);
+				g_error_free (error);
+				goto out;
+			}
+			if (wrote != 8) {
+				pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR,
+						       "failed to write, only %i bytes", wrote);
+				pk_backend_finished (backend);
+				goto out;
+			}
+		} else if (g_strcmp0 (buffer, "you said to me: invalid\n") == 0) {
+			g_debug ("ignoring invalid data (one is good)");
+		} else {
+			pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR,
+					       "unexpected data: %s", buffer);
+			g_source_remove (_signal_timeout);
+			pk_backend_finished (backend);
+			goto out;
+		}
+	}
+out:
+	return ret;
+}
+
+/**
+ * pk_backend_update_system:
+ */
+void
+pk_backend_update_system (PkBackend *backend, gboolean only_trusted)
+{
+	gchar *frontend_socket = NULL;
+	GError *error = NULL;
+	gboolean ret;
+	GSocketAddress *address = NULL;
+	gsize wrote;
+	GSource *source;
+
 	pk_backend_set_status (backend, PK_STATUS_ENUM_DOWNLOAD);
 	pk_backend_set_allow_cancel (backend, TRUE);
 	_progress_percentage = 0;
 
-	/* FIXME: support only_trusted */
+	_socket = NULL;
+	_socket_listen_id = 0;
 
+	/* make sure we can contact the frontend */
+	frontend_socket = pk_backend_get_frontend_socket (backend);
+	if (frontend_socket == NULL) {
+		pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR,
+				       "failed to get frontend socket");
+		pk_backend_finished (backend);
+		goto out;
+	}
+
+	/* create socket */
+	_socket = g_socket_new (G_SOCKET_FAMILY_UNIX, G_SOCKET_TYPE_STREAM, G_SOCKET_PROTOCOL_DEFAULT, &error);
+	if (_socket == NULL) {
+		pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR,
+				       "failed to create socket: %s", error->message);
+		pk_backend_finished (backend);
+		g_error_free (error);
+		goto out;
+	}
+	g_socket_set_blocking (_socket, FALSE);
+	g_socket_set_keepalive (_socket, TRUE);
+
+	/* connect to it */
+	address = g_unix_socket_address_new_with_type (frontend_socket, -1, G_UNIX_SOCKET_ADDRESS_PATH);
+	ret = g_socket_connect (_socket, address, NULL, &error);
+	if (!ret) {
+		pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR,
+				       "failed to open socket: %s", error->message);
+		pk_backend_finished (backend);
+		g_error_free (error);
+		goto out;
+	}
+
+	/* socket has data */
+	source = g_socket_create_source (_socket, G_IO_IN | G_IO_ERR | G_IO_HUP | G_IO_NVAL, NULL);
+	g_source_set_callback (source, (GSourceFunc) pk_backend_socket_has_data_cb, backend, NULL);
+	_socket_listen_id = g_source_attach (source, NULL);
+
+	/* send some data */
+	wrote = g_socket_send (_socket, "ping\n", 5, NULL, &error);
+	if (wrote != 5) {
+		pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR,
+				       "failed to write, only %i bytes", wrote);
+		pk_backend_finished (backend);
+		goto out;
+	}
+
+	/* FIXME: support only_trusted */
 	pk_backend_require_restart (backend, PK_RESTART_ENUM_SYSTEM, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed");
-	_signal_timeout = g_timeout_add (100, backend_update_system_timeout, backend);
+	_signal_timeout = g_timeout_add (100, pk_backend_update_system_timeout, backend);
+out:
+	if (address != NULL)
+		g_object_unref (address);
+	g_free (frontend_socket);
 }
 
 /**
- * backend_get_repo_list:
+ * pk_backend_get_repo_list:
  */
-static void
-backend_get_repo_list (PkBackend *backend, PkBitfield filters)
+void
+pk_backend_get_repo_list (PkBackend *backend, PkBitfield filters)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_repo_detail (backend, "fedora",
@@ -1054,39 +1193,39 @@ backend_get_repo_list (PkBackend *backend, PkBitfield filters)
 }
 
 /**
- * backend_repo_enable:
+ * pk_backend_repo_enable:
  */
-static void
-backend_repo_enable (PkBackend *backend, const gchar *rid, gboolean enabled)
+void
+pk_backend_repo_enable (PkBackend *backend, const gchar *rid, gboolean enabled)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_REQUEST);
 
 	if (g_strcmp0 (rid, "local") == 0) {
-		egg_debug ("local repo: %i", enabled);
+		g_debug ("local repo: %i", enabled);
 		_repo_enabled_local = enabled;
 	} else if (g_strcmp0 (rid, "development") == 0) {
-		egg_debug ("devel repo: %i", enabled);
+		g_debug ("devel repo: %i", enabled);
 		_repo_enabled_devel = enabled;
 	} else if (g_strcmp0 (rid, "fedora") == 0) {
-		egg_debug ("fedora repo: %i", enabled);
+		g_debug ("fedora repo: %i", enabled);
 		_repo_enabled_fedora = enabled;
 	} else if (g_strcmp0 (rid, "livna-development") == 0) {
-		egg_debug ("livna repo: %i", enabled);
+		g_debug ("livna repo: %i", enabled);
 		_repo_enabled_livna = enabled;
 	} else {
-		egg_warning ("unknown repo: %s", rid);
+		g_warning ("unknown repo: %s", rid);
 	}
 	pk_backend_finished (backend);
 }
 
 /**
- * backend_repo_set_data:
+ * pk_backend_repo_set_data:
  */
-static void
-backend_repo_set_data (PkBackend *backend, const gchar *rid, const gchar *parameter, const gchar *value)
+void
+pk_backend_repo_set_data (PkBackend *backend, const gchar *rid, const gchar *parameter, const gchar *value)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_REQUEST);
-	egg_warning ("REPO '%s' PARAMETER '%s' TO '%s'", rid, parameter, value);
+	g_warning ("REPO '%s' PARAMETER '%s' TO '%s'", rid, parameter, value);
 
 	if (g_strcmp0 (parameter, "use-blocked") == 0)
 		_use_blocked = atoi (value);
@@ -1106,10 +1245,10 @@ backend_repo_set_data (PkBackend *backend, const gchar *rid, const gchar *parame
 }
 
 /**
- * backend_what_provides_timeout:
+ * pk_backend_what_provides_timeout:
  */
 static gboolean
-backend_what_provides_timeout (gpointer data)
+pk_backend_what_provides_timeout (gpointer data)
 {
 	PkBackend *backend = (PkBackend *) data;
 	if (_progress_percentage == 100) {
@@ -1145,14 +1284,14 @@ backend_what_provides_timeout (gpointer data)
 }
 
 /**
- * backend_what_provides:
+ * pk_backend_what_provides:
  */
-static void
-backend_what_provides (PkBackend *backend, PkBitfield filters, PkProvidesEnum provides, gchar **values)
+void
+pk_backend_what_provides (PkBackend *backend, PkBitfield filters, PkProvidesEnum provides, gchar **values)
 {
 	_progress_percentage = 0;
 	_values = values;
-	_signal_timeout = g_timeout_add (200, backend_what_provides_timeout, backend);
+	_signal_timeout = g_timeout_add (200, pk_backend_what_provides_timeout, backend);
 	_filters = filters;
 	pk_backend_set_status (backend, PK_STATUS_ENUM_REQUEST);
 	pk_backend_set_allow_cancel (backend, TRUE);
@@ -1160,10 +1299,10 @@ backend_what_provides (PkBackend *backend, PkBitfield filters, PkProvidesEnum pr
 }
 
 /**
- * backend_get_packages:
+ * pk_backend_get_packages:
  */
-static void
-backend_get_packages (PkBackend *backend, PkBitfield filters)
+void
+pk_backend_get_packages (PkBackend *backend, PkBitfield filters)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_REQUEST);
 	pk_backend_package (backend, PK_INFO_ENUM_INSTALLED,
@@ -1173,10 +1312,10 @@ backend_get_packages (PkBackend *backend, PkBitfield filters)
 }
 
 /**
- * backend_download_packages:
+ * pk_backend_download_packages:
  */
-static void
-backend_download_packages (PkBackend *backend, gchar **package_ids, const gchar *directory)
+void
+pk_backend_download_packages (PkBackend *backend, gchar **package_ids, const gchar *directory)
 {
 	gchar *filename;
 
@@ -1202,10 +1341,10 @@ backend_download_packages (PkBackend *backend, gchar **package_ids, const gchar
 }
 
 /**
- * backend_simulate_install_packages:
+ * pk_backend_simulate_install_packages:
  */
-static void
-backend_simulate_install_packages (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_simulate_install_packages (PkBackend *backend, gchar **package_ids)
 {
 	pk_backend_set_status (backend, PK_STATUS_ENUM_DEP_RESOLVE);
 
@@ -1236,46 +1375,107 @@ backend_simulate_install_packages (PkBackend *backend, gchar **package_ids)
 	pk_backend_finished (backend);
 }
 
-PK_BACKEND_OPTIONS (
-	"Dummy",				/* description */
-	"Richard Hughes <richard@hughsie.com>",	/* author */
-	backend_initialize,			/* initalize */
-	backend_destroy,			/* destroy */
-	backend_get_groups,			/* get_groups */
-	backend_get_filters,			/* get_filters */
-	NULL,					/* get_roles */
-	backend_get_mime_types,			/* get_mime_types */
-	backend_cancel,				/* cancel */
-	backend_download_packages,		/* download_packages */
-	NULL,					/* get_categories */
-	backend_get_depends,			/* get_depends */
-	backend_get_details,			/* get_details */
-	backend_get_distro_upgrades,		/* get_distro_upgrades */
-	backend_get_files,			/* get_files */
-	backend_get_packages,			/* get_packages */
-	backend_get_repo_list,			/* get_repo_list */
-	backend_get_requires,			/* get_requires */
-	backend_get_update_detail,		/* get_update_detail */
-	backend_get_updates,			/* get_updates */
-	backend_install_files,			/* install_files */
-	backend_install_packages,		/* install_packages */
-	backend_install_signature,		/* install_signature */
-	backend_refresh_cache,			/* refresh_cache */
-	backend_remove_packages,		/* remove_packages */
-	backend_repo_enable,			/* repo_enable */
-	backend_repo_set_data,			/* repo_set_data */
-	backend_resolve,			/* resolve */
-	backend_rollback,			/* rollback */
-	backend_search_details,			/* search_details */
-	backend_search_files,			/* search_files */
-	backend_search_groups,			/* search_groups */
-	backend_search_names,			/* search_names */
-	backend_update_packages,		/* update_packages */
-	backend_update_system,			/* update_system */
-	backend_what_provides,			/* what_provides */
-	NULL,					/* simulate_install_files */
-	backend_simulate_install_packages,	/* simulate_install_packages */
-	NULL,					/* simulate_remove_packages */
-	NULL					/* simulate_update_packages */
-);
 
+static gboolean
+pk_backend_upgrade_system_timeout (gpointer data)
+{
+	PkBackend *backend = (PkBackend *) data;
+	if (_progress_percentage == 100) {
+		pk_backend_require_restart (backend, PK_RESTART_ENUM_SYSTEM, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed");
+		pk_backend_finished (backend);
+		return FALSE;
+	}
+	if (_progress_percentage == 0) {
+		pk_backend_set_status (backend, PK_STATUS_ENUM_DOWNLOAD_UPDATEINFO);
+	}
+	if (_progress_percentage == 20) {
+		pk_backend_package (backend, PK_INFO_ENUM_DOWNLOADING,
+				    "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed",
+				    "The Linux kernel (the core of the Linux operating system)");
+	}
+	if (_progress_percentage == 30) {
+		pk_backend_package (backend, PK_INFO_ENUM_DOWNLOADING,
+				    "gtkhtml2;2.19.1-4.fc8;i386;fedora",
+				    "An HTML widget for GTK+ 2.0");
+	}
+	if (_progress_percentage == 40) {
+		pk_backend_set_allow_cancel (backend, FALSE);
+		pk_backend_package (backend, PK_INFO_ENUM_DOWNLOADING,
+				    "powertop;1.8-1.fc8;i386;fedora",
+				    "Power consumption monitor");
+	}
+	if (_progress_percentage == 60) {
+		pk_backend_set_allow_cancel (backend, TRUE);
+		pk_backend_package (backend, PK_INFO_ENUM_DOWNLOADING,
+				    "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed",
+				    "The Linux kernel (the core of the Linux operating system)");
+	}
+	if (_progress_percentage == 80) {
+		pk_backend_package (backend, PK_INFO_ENUM_DOWNLOADING,
+				    "powertop;1.8-1.fc8;i386;fedora",
+				    "Power consumption monitor");
+	}
+	_progress_percentage += 1;
+	pk_backend_set_percentage (backend, _progress_percentage);
+	pk_backend_set_sub_percentage (backend, (_progress_percentage % 10) * 10);
+	return TRUE;
+}
+
+/**
+ * pk_backend_upgrade_system:
+ */
+void
+pk_backend_upgrade_system (PkBackend *backend, const gchar *distro_id, PkUpgradeKindEnum upgrade_kind)
+{
+	pk_backend_set_status (backend, PK_STATUS_ENUM_DOWNLOAD);
+	pk_backend_set_allow_cancel (backend, TRUE);
+	_progress_percentage = 0;
+	_signal_timeout = g_timeout_add (100, pk_backend_upgrade_system_timeout, backend);
+}
+
+/**
+ * pk_backend_transaction_start:
+ */
+void
+pk_backend_transaction_start (PkBackend *backend)
+{
+	/* here you would lock the backend */
+	pk_backend_message (backend, PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED, "backend is crap");
+
+	/* you can use pk_backend_error_code() here too */
+}
+
+/**
+ * pk_backend_transaction_stop:
+ */
+void
+pk_backend_transaction_stop (PkBackend *backend)
+{
+	/* here you would unlock the backend */
+	pk_backend_message (backend, PK_MESSAGE_ENUM_CONFIG_FILES_CHANGED, "backend is crap");
+
+	/* you *cannot* use pk_backend_error_code() here,
+	 * unless pk_backend_get_is_error_set() returns FALSE, and
+	 * even then it's probably just best to clean up silently */
+
+	/* you cannot do pk_backend_finished() here as well as this is
+	 * needed to fire the transaction_stop() vfunc */
+}
+
+/**
+ * pk_backend_get_description:
+ */
+gchar *
+pk_backend_get_description (PkBackend *backend)
+{
+	return g_strdup ("Dummy");
+}
+
+/**
+ * pk_backend_get_author:
+ */
+gchar *
+pk_backend_get_author (PkBackend *backend)
+{
+	return g_strdup ("Richard Hughes <richard@hughsie.com>");
+}
