@@ -22,8 +22,8 @@
 #include <gmodule.h>
 #include <glib.h>
 #include <pk-backend.h>
+#include <pk-backend-spawn.h>
 #include <unistd.h>
-#include <egg-debug.h>
 #include <string>
 #include <set>
 #include <glib/gi18n.h>
@@ -76,15 +76,36 @@ static std::map<PkBackend *, EventDirector *> _eventDirectors;
 std::map<PkBackend *, std::vector<std::string> *> _signatures;
 
 /**
- * backend_initialize:
+ * pk_backend_get_description:
+ */
+gchar *
+pk_backend_get_description (PkBackend *backend)
+{
+	return g_strdup ("ZYpp package manager");
+}
+
+/**
+ * pk_backend_get_author:
+ */
+gchar *
+pk_backend_get_author (PkBackend *backend)
+{
+	return g_strdup ("Boyd Timothy <btimothy@gmail.com>, "
+			 "Scott Reeves <sreeves@novell.com>, "
+			 "Stefan Haas <shaas@suse.de>"
+			 "ZYpp developers <zypp-devel@opensuse.org>");
+}
+
+/**
+ * pk_backend_initialize:
  * This should only be run once per backend load, i.e. not every transaction
  */
-static void
-backend_initialize (PkBackend *backend)
+void
+pk_backend_initialize (PkBackend *backend)
 {
 	zypp_logging ();
 //	disabled get_zypp() - too slow for a dbus timeout after zypper clean -a
-	egg_debug ("zypp_backend_initialize");
+	g_debug ("zypp_backend_initialize");
 	EventDirector *eventDirector = new EventDirector (backend);
 	_eventDirectors [backend] = eventDirector;
 	std::vector<std::string> *signature = new std::vector<std::string> ();
@@ -93,13 +114,13 @@ backend_initialize (PkBackend *backend)
 }
 
 /**
- * backend_destroy:
+ * pk_backend_destroy:
  * This should only be run once per backend load, i.e. not every transaction
  */
-static void
-backend_destroy (PkBackend *backend)
+void
+pk_backend_destroy (PkBackend *backend)
 {
-	egg_debug ("zypp_backend_destroy");
+	g_debug ("zypp_backend_destroy");
 
 	delete (_eventDirectors [backend]);
 	_eventDirectors.erase (backend);
@@ -118,6 +139,13 @@ backend_get_requires_thread (PkBackend *backend)
 {
 	gchar **package_ids;
 	PkBitfield _filters = (PkBitfield) pk_backend_get_uint (backend, "filters");
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 	if (!pk_package_ids_check (package_ids)) {
@@ -179,7 +207,7 @@ backend_get_requires_thread (PkBackend *backend)
 		if (!solver.resolvePool ()) {
 			std::list<zypp::ResolverProblem_Ptr> problems = solver.problems ();
 			for (std::list<zypp::ResolverProblem_Ptr>::iterator it = problems.begin (); it != problems.end (); it++){
-				egg_warning("Solver problem (This should never happen): '%s'", (*it)->description ().c_str ());
+				g_warning("Solver problem (This should never happen): '%s'", (*it)->description ().c_str ());
 			}
 			return zypp_backend_finished_error (
 				backend, PK_ERROR_ENUM_DEP_RESOLUTION_FAILED,
@@ -207,19 +235,19 @@ backend_get_requires_thread (PkBackend *backend)
 }
 
 /**
-  * backend_get_requires:
+  * pk_backend_get_requires:
   */
-static void
-backend_get_requires(PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
+void
+pk_backend_get_requires(PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_thread_create (backend, backend_get_requires_thread);
 }
 
 /**
- * backend_get_groups:
+ * pk_backend_get_groups:
  */
-static PkBitfield
-backend_get_groups (PkBackend *backend)
+PkBitfield
+pk_backend_get_groups (PkBackend *backend)
 {
 	return pk_bitfield_from_enums (
 		PK_GROUP_ENUM_ADMIN_TOOLS,
@@ -243,10 +271,10 @@ backend_get_groups (PkBackend *backend)
 }
 
 /**
- * backend_get_filters:
+ * pk_backend_get_filters:
  */
-static PkBitfield
-backend_get_filters (PkBackend *backend)
+PkBitfield
+pk_backend_get_filters (PkBackend *backend)
 {
 	return pk_bitfield_from_enums (
 		PK_FILTER_ENUM_INSTALLED,
@@ -286,8 +314,12 @@ backend_get_depends_thread (PkBackend *backend)
 
 	zypp::ZYpp::Ptr zypp;
 	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
-	egg_debug ("get_depends with filter '%s'", pk_filter_bitfield_to_string (_filters));
+	g_debug ("get_depends with filter '%s'", pk_filter_bitfield_to_string (_filters));
 
 	try
 	{
@@ -342,10 +374,10 @@ backend_get_depends_thread (PkBackend *backend)
 		std::vector<std::string> pkg_names;
 
 		for (zypp::Capabilities::const_iterator cap = req.begin (); cap != req.end (); ++cap) {
-			egg_debug ("get_depends - capability '%s'", cap->asString().c_str());
+			g_debug ("get_depends - capability '%s'", cap->asString().c_str());
 
 			if (caps.find (cap->asString ()) != caps.end()) {
-				egg_debug ("Interesting ! already have capability '%s'", cap->asString().c_str());
+				g_debug ("Interesting ! already have capability '%s'", cap->asString().c_str());
 				continue;
 			}
 
@@ -357,13 +389,12 @@ backend_get_depends_thread (PkBackend *backend)
 			for (zypp::sat::WhatProvides::const_iterator provider = prov_list.begin ();
 			     provider != prov_list.end (); provider++) {
 
-				egg_debug ("provider: '%s'", provider->asString().c_str());
+				g_debug ("provider: '%s'", provider->asString().c_str());
 
 				// filter out caps like "rpmlib(PayloadFilesHavePrefix) <= 4.0-1" (bnc#372429)
 				if (zypp_is_no_solvable (*provider))
 					continue;
 
-
 				// Is this capability provided by a package we already have listed ?
 				if (std::find (pkg_names.begin (), pkg_names.end(),
 					       provider->name ()) != pkg_names.end()) {
@@ -406,9 +437,9 @@ backend_get_depends_thread (PkBackend *backend)
 			zypp::PoolItem item = zypp::ResPool::instance ().find (it->second);
 			PkInfoEnum info = it->second.isSystem () ? PK_INFO_ENUM_INSTALLED : PK_INFO_ENUM_AVAILABLE;
 
-			egg_debug ("add dep - '%s' '%s' %d [%s]", it->second.name().c_str(),
+			g_debug ("add dep - '%s' '%s' %d [%s]", it->second.name().c_str(),
 				   info == PK_INFO_ENUM_INSTALLED ? "installed" : "available",
-				   it->second.isSystem(), 
+				   it->second.isSystem(),
 				   zypp_filter_solvable (_filters, it->second) ? "don't add" : "add" );
 
 			if (!zypp_filter_solvable (_filters, it->second)) {
@@ -431,10 +462,10 @@ backend_get_depends_thread (PkBackend *backend)
 }
 
 /**
- * backend_get_depends:
+ * pk_backend_get_depends:
  */
-static void
-backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
+void
+pk_backend_get_depends (PkBackend *backend, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_thread_create (backend, backend_get_depends_thread);
 }
@@ -443,6 +474,13 @@ static gboolean
 backend_get_details_thread (PkBackend *backend)
 {
 	gchar **package_ids;
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 	if (!pk_package_ids_check (package_ids)) {
@@ -457,9 +495,9 @@ backend_get_details_thread (PkBackend *backend)
 		std::vector<zypp::sat::Solvable> *v;
 		std::vector<zypp::sat::Solvable> *v2;
 		std::vector<zypp::sat::Solvable> *v3;
-		v = zypp_get_packages_by_name (backend, (const gchar *)id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::package, TRUE);
-		v2 = zypp_get_packages_by_name (backend, (const gchar *)id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::patch, TRUE);
-		v3 = zypp_get_packages_by_name (backend, (const gchar *)id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::srcpackage, TRUE);
+		v = zypp_get_packages_by_name (backend, (const gchar *)id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::package);
+		v2 = zypp_get_packages_by_name (backend, (const gchar *)id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::patch);
+		v3 = zypp_get_packages_by_name (backend, (const gchar *)id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::srcpackage);
 
 		v->insert (v->end (), v2->begin (), v2->end ());
 		v->insert (v->end (), v3->begin (), v3->end ());
@@ -498,13 +536,25 @@ backend_get_details_thread (PkBackend *backend)
 					(gulong)rpmHeader->tag_archivesize ());	// gulong size
 
 			} else {
+				gulong size = 0;
+
+				if (zypp::isKind<zypp::Patch>(package)) {
+					zypp::PoolItem item = zypp::ResPool::instance ().find (package);
+					zypp::Patch::constPtr patch = zypp::asKind<zypp::Patch>(item);
+
+					zypp::sat::SolvableSet content = patch->contents ();
+					for (zypp::sat::SolvableSet::const_iterator it = content.begin (); it != content.end (); it++)
+						size += it->lookupNumAttribute (zypp::sat::SolvAttr::downloadsize);
+				} else
+					size = package.lookupNumAttribute (zypp::sat::SolvAttr::downloadsize);
+
 				pk_backend_details (backend,
-					package_ids[i],
-					package.lookupStrAttribute (zypp::sat::SolvAttr::license).c_str (), //pkg->license ().c_str (),
-					group,
-					package.lookupStrAttribute (zypp::sat::SolvAttr::description).c_str (), //pkg->description ().c_str (),
-					"TODO", //pkg->url ().c_str (),
-					((gulong)package.lookupNumAttribute (zypp::sat::SolvAttr::downloadsize) * 1024)); //pkg->size ());
+						    package_ids[i],
+						    package.lookupStrAttribute (zypp::sat::SolvAttr::license).c_str (),
+						    group,
+						    package.lookupStrAttribute (zypp::sat::SolvAttr::description).c_str (),
+						    "TODO", // pkg->url ().c_str (),
+						    size * 1024);
 			}
 
 		} catch (const zypp::target::rpm::RpmException &ex) {
@@ -521,10 +571,10 @@ backend_get_details_thread (PkBackend *backend)
 }
 
 /**
- * backend_get_details:
+ * pk_backend_get_details:
  */
-static void
-backend_get_details (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_get_details (PkBackend *backend, gchar **package_ids)
 {
 	pk_backend_thread_create (backend, backend_get_details_thread);
 }
@@ -532,8 +582,21 @@ backend_get_details (PkBackend *backend, gchar **package_ids)
 static gboolean
 backend_get_distro_upgrades_thread(PkBackend *backend)
 {
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
+	// refresh the repos before checking for updates
+	if (!zypp_refresh_cache (backend, FALSE)) {
+		pk_backend_finished (backend);
+		return FALSE;
+	}
+
 	std::vector<zypp::parser::ProductFileData> result;
 	if (!zypp::parser::ProductFileReader::scanDir (zypp::functor::getAll (std::back_inserter (result)), "/etc/products.d")) {
 		return zypp_backend_finished_error (
@@ -563,10 +626,10 @@ backend_get_distro_upgrades_thread(PkBackend *backend)
 }
 
 /**
- * backend_get_distro_upgrades:
+ * pk_backend_get_distro_upgrades:
  */
-static void
-backend_get_distro_upgrades (PkBackend *backend)
+void
+pk_backend_get_distro_upgrades (PkBackend *backend)
 {
 	pk_backend_thread_create (backend, backend_get_distro_upgrades_thread);
 }
@@ -581,10 +644,10 @@ backend_refresh_cache_thread (PkBackend *backend)
 }
 
 /**
- * backend_refresh_cache
+ * pk_backend_refresh_cache
  */
-static void
-backend_refresh_cache (PkBackend *backend, gboolean force)
+void
+pk_backend_refresh_cache (PkBackend *backend, gboolean force)
 {
 	pk_backend_thread_create (backend, backend_refresh_cache_thread);
 }
@@ -601,7 +664,7 @@ check_for_self_update (PkBackend *backend, std::set<zypp::PoolItem> *candidates)
 		zypp::ResObject::constPtr res = ci->resolvable();
 		if (zypp::isKind<zypp::Patch>(res)) {
 			zypp::Patch::constPtr patch = zypp::asKind<zypp::Patch>(res);
-			//egg_debug ("restart_suggested is %d",(int)patch->restartSuggested());
+			//g_debug ("restart_suggested is %d",(int)patch->restartSuggested());
 			if (patch->restartSuggested ()) {
 				if (!strcmp (PACKAGEKIT_RPM_NAME, res->satSolvable ().name ().c_str ()) ||
 						!strcmp (GNOME_PACKAGKEKIT_RPM_NAME, res->satSolvable ().name ().c_str ())) {
@@ -619,6 +682,13 @@ static gboolean
 backend_get_updates_thread (PkBackend *backend)
 {
 	PkBitfield _filters = (PkBitfield) pk_backend_get_uint (backend, "filters");
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	typedef std::set<zypp::PoolItem>::iterator pi_it_t;
 
@@ -679,10 +749,10 @@ backend_get_updates_thread (PkBackend *backend)
 }
 
 /**
- * backend_get_updates
+ * pk_backend_get_updates
  */
-static void
-backend_get_updates (PkBackend *backend, PkBitfield filters)
+void
+pk_backend_get_updates (PkBackend *backend, PkBitfield filters)
 {
 	pk_backend_thread_create (backend, backend_get_updates_thread);
 }
@@ -691,6 +761,13 @@ static gboolean
 backend_install_files_thread (PkBackend *backend)
 {
 	gchar **full_paths;
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	full_paths = pk_backend_get_strv (backend, "full_paths");
 
@@ -762,6 +839,7 @@ backend_install_files_thread (PkBackend *backend)
 		std::vector<zypp::sat::Solvable> *solvables = 0;
 		solvables = zypp_get_packages_by_name (backend, rpmHeader->tag_name ().c_str (), zypp::ResKind::package, FALSE);
 		zypp::PoolItem *item = NULL;
+
 		gboolean found = FALSE;
 
 		for (std::vector<zypp::sat::Solvable>::iterator it = solvables->begin (); it != solvables->end (); it ++) {
@@ -801,19 +879,19 @@ backend_install_files_thread (PkBackend *backend)
 }
 
 /**
-  * backend_install_files
+  * pk_backend_install_files
   */
-static void
-backend_install_files (PkBackend *backend, gboolean only_trusted, gchar **full_paths)
+void
+pk_backend_install_files (PkBackend *backend, gboolean only_trusted, gchar **full_paths)
 {
 	pk_backend_thread_create (backend, backend_install_files_thread);
 }
 
 /**
-  * backend_simulate_install_files
+  * pk_backend_simulate_install_files
   */
-static void
-backend_simulate_install_files (PkBackend *backend, gchar **full_paths)
+void
+pk_backend_simulate_install_files (PkBackend *backend, gchar **full_paths)
 {
 	pk_backend_thread_create (backend, backend_install_files_thread);
 }
@@ -822,6 +900,13 @@ static gboolean
 backend_get_update_detail_thread (PkBackend *backend)
 {
 	gchar **package_ids;
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 	if (package_ids == NULL) {
@@ -846,7 +931,7 @@ backend_get_update_detail_thread (PkBackend *backend)
 
 		if (zypp::isKind<zypp::Patch>(solvable)) {
 			zypp::Patch::constPtr patch = zypp::asKind<zypp::Patch>(item);
-			zypp_get_restart (restart, patch);
+			zypp_check_restart (&restart, patch);
 
 			// Building links like "http://www.distro-update.org/page?moo;Bugfix release for kernel;http://www.test.de/bgz;test domain"
 			for (zypp::Patch::ReferenceIterator it = patch->referencesBegin (); it != patch->referencesEnd (); it ++) {
@@ -901,10 +986,10 @@ backend_get_update_detail_thread (PkBackend *backend)
 }
 
 /**
-  * backend_get_update_detail
+  * pk_backend_get_update_detail
   */
-static void
-backend_get_update_detail (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_get_update_detail (PkBackend *backend, gchar **package_ids)
 {
 	pk_backend_thread_create (backend, backend_get_update_detail_thread);
 }
@@ -912,6 +997,13 @@ backend_get_update_detail (PkBackend *backend, gchar **package_ids)
 static gboolean
 backend_update_system_thread (PkBackend *backend)
 {
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_set_percentage (backend, 0);
 
@@ -922,9 +1014,8 @@ backend_update_system_thread (PkBackend *backend)
 
 	std::set<zypp::PoolItem> *candidates = zypp_get_updates (backend);
 
-	if (_updating_self) {
+	if (_updating_self)
 		_updating_self = FALSE;
-	}
 
 	pk_backend_set_percentage (backend, 80);
 	std::set<zypp::PoolItem>::iterator cb = candidates->begin (), ce = candidates->end (), ci;
@@ -933,7 +1024,7 @@ backend_update_system_thread (PkBackend *backend)
 		zypp::ResStatus &status = ci->status ();
 		status.setToBeInstalled (zypp::ResStatus::USER);
 		if (zypp::isKind<zypp::Patch>(ci->resolvable ())) {
-			zypp_get_restart (restart, zypp::asKind<zypp::Patch>(ci->resolvable ()));
+			zypp_check_restart (&restart, zypp::asKind<zypp::Patch>(ci->resolvable ()));
 		}
 	}
 
@@ -953,10 +1044,10 @@ backend_update_system_thread (PkBackend *backend)
 }
 
 /**
- * backend_update_system
+ * pk_backend_update_system
  */
-static void
-backend_update_system (PkBackend *backend, gboolean only_trusted)
+void
+pk_backend_update_system (PkBackend *backend, gboolean only_trusted)
 {
 	pk_backend_thread_create (backend, backend_update_system_thread);
 }
@@ -966,11 +1057,21 @@ backend_install_packages_thread (PkBackend *backend)
 {
 	gchar **package_ids;
 
+	// refresh the repos before installing packages
+	if (!zypp_refresh_cache (backend, FALSE)) {
+		pk_backend_finished (backend);
+		return FALSE;
+	}
+
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	pk_backend_set_percentage (backend, 0);
 
 	zypp::ZYpp::Ptr zypp;
 	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 	if (!pk_package_ids_check (package_ids)) {
@@ -998,7 +1099,7 @@ backend_install_packages_thread (PkBackend *backend)
 			for (zypp::ResPool::byName_iterator it = pool.byNameBegin (name);
 			     it != pool.byNameEnd (name); it++) {
 
-				egg_debug ("PoolItem '%s'", it->satSolvable().asString().c_str());
+				g_debug ("PoolItem '%s'", it->satSolvable().asString().c_str());
 
 				if (!it->satSolvable().isSystem())
 					continue;
@@ -1009,7 +1110,7 @@ backend_install_packages_thread (PkBackend *backend)
 					break;
 				}
 			}
-			
+
 			if (!system) {
 				gboolean hit = false;
 
@@ -1071,10 +1172,10 @@ backend_install_packages_thread (PkBackend *backend)
 }
 
 /**
- * backend_install_packages:
+ * pk_backend_install_packages:
  */
-static void
-backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
+void
+pk_backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	// For now, don't let the user cancel the install once it's started
 	pk_backend_set_allow_cancel (backend, FALSE);
@@ -1082,10 +1183,10 @@ backend_install_packages (PkBackend *backend, gboolean only_trusted, gchar **pac
 }
 
 /**
- * backend_simulate_install_packages:
+ * pk_backend_simulate_install_packages:
  */
-static void
-backend_simulate_install_packages (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_simulate_install_packages (PkBackend *backend, gchar **package_ids)
 {
 	pk_backend_thread_create (backend, backend_install_packages_thread);
 }
@@ -1103,10 +1204,10 @@ backend_install_signature_thread (PkBackend *backend)
 }
 
 /**
- * backend_install_signature:
+ * pk_backend_install_signature:
  */
-static void
-backend_install_signature (PkBackend *backend, PkSigTypeEnum type, const gchar *key_id, const gchar *package_id)
+void
+pk_backend_install_signature (PkBackend *backend, PkSigTypeEnum type, const gchar *key_id, const gchar *package_id)
 {
 	pk_backend_thread_create (backend, backend_install_signature_thread);
 }
@@ -1123,6 +1224,10 @@ backend_remove_packages_thread (PkBackend *backend)
 	zypp::Target_Ptr target;
 	zypp::ZYpp::Ptr zypp;
 	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	target = zypp->target ();
 
@@ -1182,16 +1287,16 @@ backend_remove_packages_thread (PkBackend *backend)
 }
 
 /**
- * backend_remove_packages:
+ * pk_backend_remove_packages:
  */
-static void
-backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow_deps, gboolean autoremove)
+void
+pk_backend_remove_packages (PkBackend *backend, gchar **package_ids, gboolean allow_deps, gboolean autoremove)
 {
 	pk_backend_thread_create (backend, backend_remove_packages_thread);
 }
 
-static void
-backend_simulate_remove_packages (PkBackend *backend, gchar **packages, gboolean autoremove)
+void
+pk_backend_simulate_remove_packages (PkBackend *backend, gchar **packages, gboolean autoremove)
 {
 	pk_backend_thread_create (backend, backend_remove_packages_thread);
 }
@@ -1201,22 +1306,36 @@ backend_resolve_thread (PkBackend *backend)
 {
 	gchar **package_ids = pk_backend_get_strv (backend, "package_ids");
 	PkBitfield _filters = (PkBitfield) pk_backend_get_uint (backend, "filters");
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
 	for (uint i = 0; package_ids[i]; i++) {
 		std::vector<zypp::sat::Solvable> *v;
 
-		/* Build a list of packages with this name */
-		v = zypp_get_packages_by_name (backend, package_ids[i], zypp::ResKind::package, TRUE);
+		/* build a list of packages with this name */
+		v = zypp_get_packages_by_name (backend, package_ids[i], zypp::ResKind::package);
 
+		/* add source packages */
 		if (!pk_bitfield_contain (_filters, PK_FILTER_ENUM_NOT_SOURCE)) {
 			std::vector<zypp::sat::Solvable> *src;
-			src = zypp_get_packages_by_name (backend, package_ids[i], zypp::ResKind::srcpackage, TRUE);
+			src = zypp_get_packages_by_name (backend, package_ids[i], zypp::ResKind::srcpackage);
 			v->insert (v->end (), src->begin (), src->end ());
 			delete (src);
 		}
 
+		/* include patches too */
+		std::vector<zypp::sat::Solvable> *v2;
+		v2 = zypp_get_packages_by_name (backend, package_ids[i], zypp::ResKind::patch);
+		v->insert (v->end (), v2->begin (), v2->end ());
+		delete (v2);
+
 		zypp::sat::Solvable newest;
 		std::vector<zypp::sat::Solvable> pkgs;
 
@@ -1258,10 +1377,10 @@ backend_resolve_thread (PkBackend *backend)
 }
 
 /**
- * backend_resolve:
+ * pk_backend_resolve:
  */
-static void
-backend_resolve (PkBackend *backend, PkBitfield filters, gchar **package_ids)
+void
+pk_backend_resolve (PkBackend *backend, PkBitfield filters, gchar **package_ids)
 {
 	pk_backend_thread_create (backend, backend_resolve_thread);
 }
@@ -1272,7 +1391,13 @@ backend_find_packages_thread (PkBackend *backend)
 	gchar **values;
 	const gchar *search;
 	guint mode;
-	//GList *list = NULL;
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	values = pk_backend_get_strv (backend, "search");
 	search = values[0];  //Fixme - support the possible multiple values (logical OR search)
@@ -1308,14 +1433,13 @@ backend_find_packages_thread (PkBackend *backend)
 		// did not search in srcpackages.
 		break;
 	case SEARCH_TYPE_FILE: {
-		// zypp_build_pool (TRUE); called by zypp_get_packages_by_file
-		std::vector<zypp::sat::Solvable> *r;
-		r = zypp_get_packages_by_file (backend, search);
-		v.swap( *r );
-		delete r;
-		// zypp_get_packages_by_file does strange things :)
-		// Maybe it would be sufficient to simply query
-		// zypp::sat::SolvAttr::filelist instead?
+		zypp_build_pool (backend, TRUE);
+		q.addKind( zypp::ResKind::package );
+		q.addAttribute( zypp::sat::SolvAttr::name );
+		q.addAttribute( zypp::sat::SolvAttr::description );
+		q.addAttribute( zypp::sat::SolvAttr::filelist );
+		q.setFilesMatchFullPath(true);
+		q.setMatchExact();
 		break;
 	    }
 	};
@@ -1330,20 +1454,20 @@ backend_find_packages_thread (PkBackend *backend)
 }
 
 /**
- * backend_search_name:
+ * pk_backend_search_name:
  */
-static void
-backend_search_names (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_names (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_set_uint (backend, "mode", SEARCH_TYPE_NAME);
 	pk_backend_thread_create (backend, backend_find_packages_thread);
 }
 
 /**
- * backend_search_details:
+ * pk_backend_search_details:
  */
-static void
-backend_search_details (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_details (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_set_uint (backend, "mode", SEARCH_TYPE_DETAILS);
 	pk_backend_thread_create (backend, backend_find_packages_thread);
@@ -1354,6 +1478,13 @@ backend_search_group_thread (PkBackend *backend)
 {
 	gchar **values;
 	const gchar *group;
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	values = pk_backend_get_strv (backend, "search");
 	group = values[0];  //Fixme - add support for possible multiple values.
@@ -1391,19 +1522,19 @@ backend_search_group_thread (PkBackend *backend)
 }
 
 /**
- * backend_search_group:
+ * pk_backend_search_group:
  */
-static void
-backend_search_groups (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_groups (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_thread_create (backend, backend_search_group_thread);
 }
 
 /**
- * backend_search_file:
+ * pk_backend_search_file:
  */
-static void
-backend_search_files (PkBackend *backend, PkBitfield filters, gchar **values)
+void
+pk_backend_search_files (PkBackend *backend, PkBitfield filters, gchar **values)
 {
 	pk_backend_set_uint (backend, "mode", SEARCH_TYPE_FILE);
 	pk_backend_thread_create (backend, backend_find_packages_thread);
@@ -1412,10 +1543,16 @@ backend_search_files (PkBackend *backend, PkBitfield filters, gchar **values)
 /**
  * backend_get_repo_list:
  */
-static void
-backend_get_repo_list (PkBackend *backend, PkBitfield filters)
+void
+pk_backend_get_repo_list (PkBackend *backend, PkBitfield filters)
 {
-	//FIXME - use the new param - filter
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return;
+	}
 
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
@@ -1435,6 +1572,8 @@ backend_get_repo_list (PkBackend *backend, PkBitfield filters)
 	}
 
 	for (std::list <zypp::RepoInfo>::iterator it = repos.begin(); it != repos.end(); it++) {
+		if (pk_bitfield_contain (filters, PK_FILTER_ENUM_NOT_DEVELOPMENT) && zypp_is_development_repo (backend, *it))
+			continue;
 		// RepoInfo::alias - Unique identifier for this source.
 		// RepoInfo::name - Short label or description of the
 		// repository, to be used on the user interface
@@ -1448,11 +1587,18 @@ backend_get_repo_list (PkBackend *backend, PkBitfield filters)
 }
 
 /**
- * backend_repo_enable:
+ * pk_backend_repo_enable:
  */
-static void
-backend_repo_enable (PkBackend *backend, const gchar *rid, gboolean enabled)
+void
+pk_backend_repo_enable (PkBackend *backend, const gchar *rid, gboolean enabled)
 {
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return;
+	}
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
 	zypp::RepoManager manager;
@@ -1484,6 +1630,13 @@ static gboolean
 backend_get_files_thread (PkBackend *backend)
 {
 	gchar **package_ids;
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 	if (!pk_package_ids_check (package_ids)) {
@@ -1497,8 +1650,8 @@ backend_get_files_thread (PkBackend *backend)
 
 		std::vector<zypp::sat::Solvable> *v;
 		std::vector<zypp::sat::Solvable> *v2;
-		v = zypp_get_packages_by_name (backend, (const gchar *)id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::package, TRUE);
-		v2 = zypp_get_packages_by_name (backend, (const gchar *)id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::srcpackage, TRUE);
+		v = zypp_get_packages_by_name (backend, (const gchar *)id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::package);
+		v2 = zypp_get_packages_by_name (backend, (const gchar *)id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::srcpackage);
 
 		v->insert (v->end (), v2->begin (), v2->end ());
 
@@ -1552,10 +1705,10 @@ backend_get_files_thread (PkBackend *backend)
 }
 
 /**
-  * backend_get_files:
+  * pk_backend_get_files:
   */
-static void
-backend_get_files(PkBackend *backend, gchar **package_ids)
+void
+pk_backend_get_files(PkBackend *backend, gchar **package_ids)
 {
 	pk_backend_thread_create (backend, backend_get_files_thread);
 }
@@ -1563,6 +1716,13 @@ backend_get_files(PkBackend *backend, gchar **package_ids)
 static gboolean
 backend_get_packages_thread (PkBackend *backend)
 {
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 
 	std::vector<zypp::sat::Solvable> v;
@@ -1579,10 +1739,10 @@ backend_get_packages_thread (PkBackend *backend)
 	return TRUE;
 }
 /**
-  * backend_get_packages:
+  * pk_backend_get_packages:
   */
-static void
-backend_get_packages (PkBackend *backend, PkBitfield filter)
+void
+pk_backend_get_packages (PkBackend *backend, PkBitfield filter)
 {
 	pk_backend_thread_create (backend, backend_get_packages_thread);
 }
@@ -1592,48 +1752,67 @@ backend_update_packages_thread (PkBackend *backend)
 {
 	gboolean retval;
 	gchar **package_ids;
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
+	zypp::ResPool pool = zypp_build_pool (backend, TRUE);
 	/* FIXME: support only_trusted */
 	package_ids = pk_backend_get_strv (backend, "package_ids");
 	PkRestartEnum restart = PK_RESTART_ENUM_NONE;
 
-	delete zypp_get_updates (backend); // make sure _updating_self is set
-
-	if (_updating_self) {
-		egg_debug ("updating self and setting restart");
-		pk_backend_require_restart (backend, PK_RESTART_ENUM_SESSION, "Package Management System updated - restart needed");
-		_updating_self = FALSE;
-	}
 	for (guint i = 0; package_ids[i]; i++) {
+		gchar **id_parts = pk_package_id_split (package_ids[i]);
+		std::string name = id_parts[PK_PACKAGE_ID_NAME];
+
+		// Do we have already the latest version.
+		gboolean system = false;
+		for (zypp::ResPool::byName_iterator it = pool.byNameBegin (name);
+				it != pool.byNameEnd (name); it++) {
+			if (!it->satSolvable().isSystem())
+				continue;
+			if (zypp_ver_and_arch_equal (it->satSolvable(), id_parts[PK_PACKAGE_ID_VERSION],
+						id_parts[PK_PACKAGE_ID_ARCH])) {
+				system = true;
+				break;
+			}
+		}
+		if (system == true)
+			continue;
 		zypp::sat::Solvable solvable = zypp_get_package_by_id (backend, package_ids[i]);
 		zypp::PoolItem item = zypp::ResPool::instance ().find (solvable);
 		item.status ().setToBeInstalled (zypp::ResStatus::USER);
 		zypp::Patch::constPtr patch = zypp::asKind<zypp::Patch>(item.resolvable ());
-		zypp_get_restart (restart, patch);
+		zypp_check_restart (&restart, patch);
+		if (restart != PK_RESTART_ENUM_NONE){
+			pk_backend_require_restart (backend, restart, package_ids[i]);
+			restart = PK_RESTART_ENUM_NONE;
+		}
 	}
 
 	retval = zypp_perform_execution (backend, UPDATE, FALSE);
 
-	if (restart != PK_RESTART_ENUM_NONE)
-		pk_backend_require_restart (backend, restart, "A restart is needed");
-
 	pk_backend_finished (backend);
 	return retval;
 }
 
 /**
-  * backend_update_packages
+  * pk_backend_update_packages
   */
-static void
-backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
+void
+pk_backend_update_packages (PkBackend *backend, gboolean only_trusted, gchar **package_ids)
 {
 	pk_backend_thread_create (backend, backend_update_packages_thread);
 }
 
 /**
-  * backend_simulate_update_packages
+  * pk_backend_simulate_update_packages
   */
-static void
-backend_simulate_update_packages (PkBackend *backend, gchar **package_ids)
+void
+pk_backend_simulate_update_packages (PkBackend *backend, gchar **package_ids)
 {
 	pk_backend_thread_create (backend, backend_update_packages_thread);
 }
@@ -1644,6 +1823,13 @@ backend_repo_set_data_thread (PkBackend *backend)
 	const gchar *repo_id;
 	const gchar *parameter;
 	const gchar *value;
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 
 	repo_id = pk_backend_get_string (backend, "repo_id");
 	parameter = pk_backend_get_string (backend, "parameter");
@@ -1764,10 +1950,10 @@ backend_repo_set_data_thread (PkBackend *backend)
 }
 
 /**
-  * backend_repo_set_data
+  * pk_backend_repo_set_data
   */
-static void
-backend_repo_set_data (PkBackend *backend, const gchar *repo_id, const gchar *parameter, const gchar *value)
+void
+pk_backend_repo_set_data (PkBackend *backend, const gchar *repo_id, const gchar *parameter, const gchar *value)
 {
 	pk_backend_thread_create (backend, backend_repo_set_data_thread);
 }
@@ -1775,24 +1961,29 @@ backend_repo_set_data (PkBackend *backend, const gchar *repo_id, const gchar *pa
 static gboolean
 backend_what_provides_thread (PkBackend *backend)
 {
+	zypp::ZYpp::Ptr zypp;
+
+	zypp = get_zypp (backend);
+	if (zypp == NULL){
+		pk_backend_finished (backend);
+		return FALSE;
+	}
 	pk_backend_set_status (backend, PK_STATUS_ENUM_QUERY);
 	gchar **values = pk_backend_get_strv (backend, "search");
 	const gchar *search = values[0]; //Fixme - support possible multiple search values (logical OR)
 	PkProvidesEnum provides = (PkProvidesEnum) pk_backend_get_uint (backend, "provides");
 	PkBitfield _filters = (PkBitfield) pk_backend_get_uint (backend, "filters");
-	zypp::Capability cap (search);
-	zypp::sat::WhatProvides prov (cap);
+	zypp::ResPool pool = zypp_build_pool (backend, true);
 
 	if((provides == PK_PROVIDES_ENUM_HARDWARE_DRIVER) || g_ascii_strcasecmp("drivers_for_attached_hardware", search) == 0) {
 		// solver run
-		zypp::ResPool pool = zypp_build_pool (backend, true);
 		zypp::Resolver solver(pool);
 		solver.setIgnoreAlreadyRecommended (TRUE);
 
 		if (!solver.resolvePool ()) {
 			std::list<zypp::ResolverProblem_Ptr> problems = solver.problems ();
 			for (std::list<zypp::ResolverProblem_Ptr>::iterator it = problems.begin (); it != problems.end (); it++){
-				egg_warning("Solver problem (This should never happen): '%s'", (*it)->description ().c_str ());
+				g_warning("Solver problem (This should never happen): '%s'", (*it)->description ().c_str ());
 			}
 			solver.setIgnoreAlreadyRecommended (FALSE);
 			return zypp_backend_finished_error (
@@ -1819,10 +2010,13 @@ backend_what_provides_thread (PkBackend *backend)
 		}
 		solver.setIgnoreAlreadyRecommended (FALSE);
 	} else {
+		zypp::Capability cap (search);
+		zypp::sat::WhatProvides prov (cap);
+
 		for (zypp::sat::WhatProvides::const_iterator it = prov.begin (); it != prov.end (); it++) {
 			if (zypp_filter_solvable (_filters, *it))
 				continue;
-			
+
 			PkInfoEnum info = it->isSystem () ? PK_INFO_ENUM_INSTALLED : PK_INFO_ENUM_AVAILABLE;
 			zypp_backend_package (backend, info, *it, it->lookupStrAttribute (zypp::sat::SolvAttr::summary).c_str ());
 		}
@@ -1833,62 +2027,59 @@ backend_what_provides_thread (PkBackend *backend)
 }
 
 /**
-  * backend_what_provides
+  * pk_backend_what_provides
   */
-static void
-backend_what_provides (PkBackend *backend, PkBitfield filters, PkProvidesEnum provide, gchar **values)
+void
+pk_backend_what_provides (PkBackend *backend, PkBitfield filters, PkProvidesEnum provide, gchar **values)
 {
 	pk_backend_thread_create (backend, backend_what_provides_thread);
 }
 
-static gchar *
-backend_get_mime_types (PkBackend *backend)
+gchar *
+pk_backend_get_mime_types (PkBackend *backend)
 {
 	return g_strdup ("application/x-rpm");
 }
 
-extern "C" PK_BACKEND_OPTIONS (
-	"Zypp",					/* description */
-	"Boyd Timothy <btimothy@gmail.com>, "
-	"Scott Reeves <sreeves@novell.com>, "
-	"Stefan Haas <shaas@suse.de>",		/* author */
-	backend_initialize,			/* initalize */
-	backend_destroy,			/* destroy */
-	backend_get_groups,			/* get_groups */
-	backend_get_filters,			/* get_filters */
-	NULL,					/* get_roles */
-	backend_get_mime_types,			/* get_mime_types */
-	NULL,					/* cancel */
-	NULL,					/* download_packages */
-	NULL,					/* get_categories */
-	backend_get_depends,			/* get_depends */
-	backend_get_details,			/* get_details */
-	backend_get_distro_upgrades,		/* get_distro_upgrades */
-	backend_get_files,			/* get_files */
-	backend_get_packages,			/* get_packages */
-	backend_get_repo_list,			/* get_repo_list */
-	backend_get_requires,			/* get_requires */
-	backend_get_update_detail,		/* get_update_detail */
-	backend_get_updates,			/* get_updates */
-	backend_install_files,			/* install_files */
-	backend_install_packages,		/* install_packages */
-	backend_install_signature,		/* install_signature */
-	backend_refresh_cache,			/* refresh_cache */
-	backend_remove_packages,		/* remove_packages */
-	backend_repo_enable,			/* repo_enable */
-	backend_repo_set_data,			/* repo_set_data */
-	backend_resolve,			/* resolve */
-	NULL,					/* rollback */
-	backend_search_details,			/* search_details */
-	backend_search_files,			/* search_files */
-	backend_search_groups,			/* search_groups */
-	backend_search_names,			/* search_names */
-	backend_update_packages,		/* update_packages */
-	backend_update_system,			/* update_system */
-	backend_what_provides,			/* what_provides */
-	backend_simulate_install_files,		/* simulate_install_files */
-	backend_simulate_install_packages,	/* simulate_install_packages */
-	backend_simulate_remove_packages,	/* simulate_remove_packages */
-	backend_simulate_update_packages	/* simulate_update_packages */
-);
+/**
+ * pk_backend_transaction_start:
+ */
+void
+pk_backend_transaction_start (PkBackend *backend)
+{
+	gchar *proxy_http;
+	gchar *proxy_ftp;
+	gchar *uri;
+
+	/* http_proxy */
+	proxy_http = pk_backend_get_proxy_http (backend);
+	if (!egg_strzero (proxy_http)) {
+		uri = pk_backend_spawn_convert_uri (proxy_http);
+		g_setenv ("http_proxy", uri, TRUE);
+		g_free (uri);
+	}
+
+	/* ftp_proxy */
+	proxy_ftp = pk_backend_get_proxy_ftp (backend);
+	if (!egg_strzero (proxy_ftp)) {
+		uri = pk_backend_spawn_convert_uri (proxy_ftp);
+		g_setenv ("ftp_proxy", uri, TRUE);
+		g_free (uri);
+	}
+
+	g_free (proxy_http);
+	g_free (proxy_ftp);
+}
+
+/**
+ * pk_backend_transaction_stop:
+ */
+void
+pk_backend_transaction_stop (PkBackend *backend)
+{
+	/* unset proxy info for this transaction */
+	g_unsetenv ("http_proxy");
+	g_unsetenv ("ftp_proxy");
+}
+
 
