@@ -99,8 +99,12 @@ get_zypp (PkBackend *backend)
 
 		        initialized = TRUE;
 	        }
+	} catch (const zypp::ZYppFactoryException &ex) {
+		pk_backend_error_code (backend, PK_ERROR_ENUM_FAILED_INITIALIZATION, ex.asUserString().c_str() );
+		return NULL;
         } catch (const zypp::Exception &ex) {
-		egg_error ("%s", ex.asUserString ().c_str ());
+		pk_backend_error_code (backend, PK_ERROR_ENUM_INTERNAL_ERROR, ex.asUserString().c_str() );
+		return NULL;
         }
 
 	return zypp;
@@ -150,13 +154,42 @@ zypp_is_changeable_media (PkBackend *backend, const zypp::Url &url)
 	return is_cd;
 }
 
+gboolean
+zypp_is_development_repo (PkBackend *backend, zypp::RepoInfo repo)
+{
+	std::string repo_debuginfo("-debuginfo");
+	std::string repo_debug("-debug");
+	std::string repo_development("-development");
+	std::string repo_source ("-source");
+	
+	std::string repo_name(repo.name());
+
+	if (repo_name.length() > repo_debuginfo.length() && 
+	    repo_name.compare(repo_name.length() - repo_debuginfo.length(), repo_debuginfo.length(), repo_debuginfo) == 0)
+		return TRUE;
+
+	if (repo_name.length() > repo_debug.length() && 
+	    repo_name.compare(repo_name.length() - repo_debug.length(), repo_debug.length(), repo_debug) == 0)
+		return TRUE;
+
+	if (repo_name.length() > repo_development.length() && 
+	    repo_name.compare(repo_name.length() - repo_development.length(), repo_development.length(), repo_development) == 0)
+		return TRUE;
+
+	if (repo_name.length() > repo_source.length() && 
+	   repo_name.compare(repo_name.length() - repo_source.length(), repo_source.length(), repo_source) == 0)
+		return TRUE;
+
+	return FALSE;
+}
+
 zypp::ResPool
 zypp_build_pool (PkBackend *backend, gboolean include_local)
 {
 	zypp::ZYpp::Ptr zypp = get_zypp (backend);
 
 	if (include_local) {
-		//FIXME have to wait for fix in zypp (repeated loading of target)
+		// FIXME have to wait for fix in zypp (repeated loading of target)
 		if (zypp::sat::Pool::instance().reposFind( zypp::sat::Pool::systemRepoAlias() ).solvablesEmpty ())
 		{
 			// Add local resolvables
@@ -178,7 +211,7 @@ zypp_build_pool (PkBackend *backend, gboolean include_local)
 				continue;
                         // skip not cached repos
                         if (manager.isCached (repo) == false) {
-                                egg_warning ("%s is not cached! Do a refresh", repo.alias ().c_str ());
+                                g_warning ("%s is not cached! Do a refresh", repo.alias ().c_str ());
                                 continue;
                         }
                         //FIXME see above, skip already cached repos
@@ -186,11 +219,11 @@ zypp_build_pool (PkBackend *backend, gboolean include_local)
                                 manager.loadFromCache (repo);
 		}
 	} catch (const zypp::repo::RepoNoAliasException &ex) {
-                egg_error ("Can't figure an alias to look in cache");
+                g_error ("Can't figure an alias to look in cache");
         } catch (const zypp::repo::RepoNotCachedException &ex) {
-                egg_error ("The repo has to be cached at first: %s", ex.asUserString ().c_str ());
+                g_error ("The repo has to be cached at first: %s", ex.asUserString ().c_str ());
 	} catch (const zypp::Exception &ex) {
-                egg_error ("TODO: Handle exceptions: %s", ex.asUserString ().c_str ());
+                g_error ("TODO: Handle exceptions: %s", ex.asUserString ().c_str ());
 	}
 
 	return zypp->pool ();
@@ -242,7 +275,7 @@ zypp_build_local_pool (PkBackend *backend)
                 }
 
 	} catch (const zypp::Exception &ex) {
-		egg_error ("%s", ex.asUserString ().c_str ());
+		g_error ("%s", ex.asUserString ().c_str ());
 	}
 
         return zypp->pool ();
@@ -391,8 +424,8 @@ zypp_get_package_by_id (PkBackend *backend, const gchar *package_id)
 	}
 
 	gchar **id_parts = pk_package_id_split(package_id);
-	std::vector<zypp::sat::Solvable> *v = zypp_get_packages_by_name (backend, id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::package, TRUE);
-	std::vector<zypp::sat::Solvable> *v2 = zypp_get_packages_by_name (backend, id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::patch, TRUE);
+	std::vector<zypp::sat::Solvable> *v = zypp_get_packages_by_name (backend, id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::package);
+	std::vector<zypp::sat::Solvable> *v2 = zypp_get_packages_by_name (backend, id_parts[PK_PACKAGE_ID_NAME], zypp::ResKind::patch);
 
 	v->insert (v->end (), v2->begin (), v2->end ());
 
@@ -455,12 +488,21 @@ gboolean
 zypp_refresh_meta_and_cache (zypp::RepoManager &manager, zypp::RepoInfo &repo, bool force)
 {
 	try {
+		if (manager.checkIfToRefreshMetadata (repo, repo.url(), 
+					zypp::RepoManager::RefreshIfNeededIgnoreDelay)
+					!= zypp::RepoManager::REFRESH_NEEDED)
+			return TRUE;
+
+		zypp::sat::Pool pool = zypp::sat::Pool::instance ();
+		// Erase old solv file
+		pool.reposErase (repo.alias ());
 		manager.refreshMetadata (repo, force ?
 					 zypp::RepoManager::RefreshForced :
-					 zypp::RepoManager::RefreshIfNeeded);
+					 zypp::RepoManager::RefreshIfNeededIgnoreDelay);
 		manager.buildCache (repo, force ?
 				    zypp::RepoManager::BuildForced :
 				    zypp::RepoManager::BuildIfNeeded);
+		manager.loadFromCache (repo);
 		return TRUE;
 	} catch (const AbortTransactionException &ex) {
 		return FALSE;
@@ -565,6 +607,17 @@ system_and_package_are_x86 (zypp::sat::Solvable item)
 			!strcmp (zypp::ZConfig::defaultSystemArchitecture ().asString().c_str(), "i686"));
 }
 
+static gboolean
+zypp_package_is_devel (const zypp::sat::Solvable &item)
+{
+	const std::string &name = item.name();
+	const char *cstr = name.c_str();
+
+	return ( g_str_has_suffix (cstr, "-debuginfo") ||
+		 g_str_has_suffix (cstr, "-debugsource") ||
+		 g_str_has_suffix (cstr, "-devel") );
+}
+
 /* should we filter out this package ? */
 gboolean
 zypp_filter_solvable (PkBitfield filters, const zypp::sat::Solvable &item)
@@ -573,8 +626,6 @@ zypp_filter_solvable (PkBitfield filters, const zypp::sat::Solvable &item)
 	if (!filters)
 		return FALSE;
 
-	//const gchar * myarch = zypp::ZConfig::defaultSystemArchitecture().asString().c_str();
-
 	for (guint i = 0; i < PK_FILTER_ENUM_LAST; i++) {
 		if ((filters & pk_bitfield_value (i)) == 0)
 			continue;
@@ -593,17 +644,18 @@ zypp_filter_solvable (PkBitfield filters, const zypp::sat::Solvable &item)
 			    system_and_package_are_x86 (item))
 				return TRUE;
 		}
-		if (i == PK_FILTER_ENUM_SOURCE && !(zypp::isKind<zypp::SrcPackage>(item))) {
+		if (i == PK_FILTER_ENUM_SOURCE && !(zypp::isKind<zypp::SrcPackage>(item)))
 			return TRUE;
-		}
-		if (i == PK_FILTER_ENUM_NOT_SOURCE && zypp::isKind<zypp::SrcPackage>(item)) {
+		if (i == PK_FILTER_ENUM_NOT_SOURCE && zypp::isKind<zypp::SrcPackage>(item))
+			return TRUE;
+		if (i == PK_FILTER_ENUM_DEVELOPMENT && !zypp_package_is_devel (item))
+			return TRUE;
+		if (i == PK_FILTER_ENUM_NOT_DEVELOPMENT && zypp_package_is_devel (item))
 			return TRUE;
-		}
-
-		// FIXME: add enums
-		// PK_FILTER_ENUM_DEVELOPMENT,
-		// PK_FILTER_ENUM_NOT_DEVELOPMENT,
 
+		// FIXME: add more enums - cf. libzif logic and pk-enum.h
+		// PK_FILTER_ENUM_SUPPORTED, 
+		// PK_FILTER_ENUM_NOT_SUPPORTED,
 	}
 
 	return FALSE;
@@ -712,6 +764,20 @@ zypp_get_package_updates (std::string repo)
                 zypp::PoolItem candidate =  zypp_find_arch_update_item (pool, *it);
                 if (!candidate.resolvable ())
                         continue;
+
+		gboolean system = false;
+		for (zypp::ResPool::byName_iterator it = pool.byNameBegin (candidate->name());
+				it != pool.byNameEnd (candidate->name()); it++) {
+			if (!it->satSolvable().isSystem())
+				continue;
+			if (zypp_ver_and_arch_equal (it->satSolvable(), candidate->edition ().c_str (),candidate->arch ().c_str ())) {
+				system = true;
+				break;
+			}
+		}
+		if (system == true) 
+			continue;
+
 		if (repo.empty ()) {
 	                pks->insert (candidate);
 		} else {
@@ -812,22 +878,22 @@ zypp_get_updates (PkBackend *backend)
 	return candidates;
 }
 
-gboolean
-zypp_get_restart (PkRestartEnum &restart, zypp::Patch::constPtr patch)
+void
+zypp_check_restart (PkRestartEnum *restart, zypp::Patch::constPtr patch)
 {
-	if (patch == NULL)
-		return false;
+	if (patch == NULL || restart == NULL)
+		return;
 
 	// set the restart flag if a restart is needed
-	if (restart != PK_RESTART_ENUM_SYSTEM && (patch->reloginSuggested () ||
-						  patch->restartSuggested () ||
-						  patch->rebootSuggested ())) {
-			if (patch->reloginSuggested () || patch->restartSuggested ())
-				restart = PK_RESTART_ENUM_SESSION;
-			if (patch->rebootSuggested ())
-				restart = PK_RESTART_ENUM_SYSTEM;
+	if (*restart != PK_RESTART_ENUM_SYSTEM &&
+	    ( patch->reloginSuggested () ||
+	      patch->restartSuggested () ||
+	      patch->rebootSuggested ()) ) {
+		if (patch->reloginSuggested () || patch->restartSuggested ())
+			*restart = PK_RESTART_ENUM_SESSION;
+		if (patch->rebootSuggested ())
+			*restart = PK_RESTART_ENUM_SYSTEM;
 	}
-	return true;
 }
 
 gboolean
@@ -896,7 +962,7 @@ zypp_perform_execution (PkBackend *backend, PerformType type, gboolean force)
 		if (simulate) {
 			ret = TRUE;
 
-			egg_debug ("simulating");
+			g_debug ("simulating");
 
 			for (zypp::ResPool::const_iterator it = pool.begin (); it != pool.end (); it++) {
 				if (!zypp_backend_pool_item_notify (backend, *it, TRUE))
@@ -1044,7 +1110,14 @@ gboolean
 zypp_refresh_cache (PkBackend *backend, gboolean force)
 {
 	// This call is needed as it calls initializeTarget which appears to properly setup the keyring
-	get_zypp (backend);
+	zypp::ZYpp::Ptr zypp = get_zypp (backend);
+        if (zypp == NULL)
+		return  FALSE;
+	zypp::filesystem::Pathname pathname(pk_backend_get_root (backend));
+	// This call is needed to refresh system rpmdb status while refresh cache
+	zypp->finishTarget ();
+	zypp->initializeTarget (pathname);
+
 	if (!pk_backend_is_online (backend)) {
 		pk_backend_error_code (backend, PK_ERROR_ENUM_NO_NETWORK, "Cannot refresh cache whilst offline");
 		return FALSE;
@@ -1089,8 +1162,7 @@ zypp_refresh_cache (PkBackend *backend, gboolean force)
 			// Refreshing metadata
 			g_free (_repoName);
 			_repoName = g_strdup (repo.alias ().c_str ());
-			if (zypp_refresh_meta_and_cache (manager, repo, force))
-				break;
+			zypp_refresh_meta_and_cache (manager, repo, force);
 		} catch (const zypp::Exception &ex) {
 			if (repo_messages == NULL) {
 				repo_messages = g_strdup_printf ("%s: %s%s", repo.alias ().c_str (), ex.asUserString ().c_str (), "\n");
