@@ -32,7 +32,6 @@
 #include <packagekit-glib2/packagekit.h>
 #include <packagekit-glib2/packagekit-private.h>
 
-#include "egg-debug.h"
 #include "egg-string.h"
 
 #define PK_MAX_PATH_LEN 1023
@@ -394,7 +393,7 @@ pk_cnf_progress_cb (PkProgress *progress, PkProgressType type, gpointer data)
 static gboolean
 pk_cnf_cancel_cb (GCancellable *_cancellable)
 {
-	egg_warning ("Cancelling request");
+	g_warning ("Cancelling request");
 	g_cancellable_cancel (cancellable);
 	return FALSE;
 }
@@ -431,7 +430,7 @@ pk_cnf_find_available (const gchar *cmd, guint max_search_time)
 				   (GSourceFunc) pk_cnf_cancel_cb,
 				   cancellable);
 #if GLIB_CHECK_VERSION(2,25,8)
-	g_source_set_name_by_id (cancel_id, "[PkCommandNotFount] cancel");
+	g_source_set_name_by_id (cancel_id, "[PkCommandNotFound] cancel");
 #endif
 
 	/* do search */
@@ -439,7 +438,7 @@ pk_cnf_find_available (const gchar *cmd, guint max_search_time)
 					  PK_FILTER_ENUM_NEWEST,
 					  PK_FILTER_ENUM_ARCH, -1);
 	results = pk_client_search_files (PK_CLIENT(task), filters, values, cancellable,
-					 (PkProgressCallback) pk_cnf_progress_cb, NULL, &error);
+					  NULL, NULL, &error);
 	if (results == NULL) {
 		/* TRANSLATORS: we failed to find the package, this shouldn't happen */
 		g_printerr ("%s: %s\n", _("Failed to search for file"), error->message);
@@ -450,9 +449,15 @@ pk_cnf_find_available (const gchar *cmd, guint max_search_time)
 	/* check error code */
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
-		/* TRANSLATORS: the transaction failed in a way we could not expect */
-		g_printerr ("%s: %s, %s\n", _("The transaction failed"), pk_error_enum_to_string (pk_error_get_code (error_code)), pk_error_get_details (error_code));
-		goto out;
+		if (pk_error_get_code (error_code) == PK_ERROR_ENUM_TRANSACTION_CANCELLED) {
+			g_debug ("The search was cancelled as it was taking too long");
+		} else {
+			/* TRANSLATORS: the transaction failed in a way we could not expect */
+			g_printerr ("%s: %s, %s\n", _("Getting the list of files failed"),
+				    pk_error_enum_to_string (pk_error_get_code (error_code)),
+				    pk_error_get_details (error_code));
+			goto out;
+		}
 	}
 
 	/* get the packages returned */
@@ -505,7 +510,7 @@ pk_cnf_get_policy_from_file (GKeyFile *file, const gchar *key)
 	/* get from file */
 	policy_text = g_key_file_get_string (file, "CommandNotFound", key, &error);
 	if (policy_text == NULL) {
-		egg_warning ("failed to get key %s: %s", key, error->message);
+		g_warning ("failed to get key %s: %s", key, error->message);
 		g_error_free (error);
 	}
 
@@ -544,7 +549,7 @@ pk_cnf_get_config (void)
 	path = g_build_filename (SYSCONFDIR, "PackageKit", "CommandNotFound.conf", NULL);
 	ret = g_key_file_load_from_file (file, path, G_KEY_FILE_NONE, &error);
 	if (!ret) {
-		egg_warning ("failed to open policy: %s", error->message);
+		g_warning ("failed to open policy: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -561,11 +566,11 @@ pk_cnf_get_config (void)
 
 	/* fallback */
 	if (config->locations == NULL) {
-		egg_warning ("not found SearchLocations, using fallback");
+		g_warning ("not found SearchLocations, using fallback");
 		config->locations = g_strsplit ("/usr/bin;/usr/sbin", ";", -1);
 	}
 	if (config->max_search_time == 0) {
-		egg_warning ("not found MaxSearchTime, using fallback");
+		g_warning ("not found MaxSearchTime, using fallback");
 		config->max_search_time = 2000;
 	}
 out:
@@ -651,7 +656,7 @@ out:
 static void
 pk_cnf_sigint_handler (int sig)
 {
-	egg_debug ("Handling SIGINT");
+	g_debug ("Handling SIGINT");
 
 	/* restore default ASAP, as the cancel might hang */
 	signal (SIGINT, SIG_DFL);
@@ -660,7 +665,7 @@ pk_cnf_sigint_handler (int sig)
 	g_cancellable_cancel (cancellable);
 
 	/* kill ourselves */
-	egg_debug ("Retrying SIGINT");
+	g_debug ("Retrying SIGINT");
 	kill (getpid (), SIGINT);
 }
 
@@ -700,7 +705,7 @@ main (int argc, char *argv[])
 	/* TRANSLATORS: tool that gets called when the command is not found */
 	g_option_context_set_summary (context, _("PackageKit Command Not Found"));
 	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_add_group (context, egg_debug_get_option_group ());
+	g_option_context_add_group (context, pk_debug_get_option_group ());
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
 
@@ -714,6 +719,11 @@ main (int argc, char *argv[])
 	/* get policy config */
 	config = pk_cnf_get_config ();
 	task = PK_TASK(pk_task_text_new ());
+	g_object_set (task,
+		      "cache-age", G_MAXUINT,
+		      "interactive", FALSE,
+		      "background", FALSE,
+		      NULL);
 	cancellable = g_cancellable_new ();
 
 	/* get length */
@@ -723,8 +733,10 @@ main (int argc, char *argv[])
 		goto out;
 	}
 
-	/* TRANSLATORS: the prefix of all the output telling the user why it's not executing */
-	g_printerr ("%s ", _("Command not found."));
+	/* TRANSLATORS: the prefix of all the output telling the user
+	 * why it's not executing. NOTE: this is lowercase to mimic
+	 * the style of bash itself -- apologies */
+	g_printerr ("bash: %s: %s...\n", argv[1], _("command not found"));
 
 	/* user is not allowing CNF to do anything useful */
 	if (!config->software_source_search &&
@@ -744,13 +756,17 @@ main (int argc, char *argv[])
 			/* TRANSLATORS: tell the user what we think the command is */
 			g_printerr ("%s '%s'\n", _("Similar command is:"), possible);
 			retval = EXIT_COMMAND_NOT_FOUND;
+			goto out;
+		}
 
 		/* run */
-		} else if (config->single_match == PK_CNF_POLICY_RUN) {
+		if (config->single_match == PK_CNF_POLICY_RUN) {
 			retval = pk_cnf_spawn_command (possible, &argv[2]);
+			goto out;
+		}
 
 		/* ask */
-		} else if (config->single_match == PK_CNF_POLICY_ASK) {
+		if (config->single_match == PK_CNF_POLICY_ASK) {
 			/* TRANSLATORS: Ask the user if we should run the similar command */
 			text = g_strdup_printf ("%s %s", _("Run similar command:"), possible);
 			ret = pk_console_get_prompt (text, TRUE);
@@ -801,9 +817,11 @@ main (int argc, char *argv[])
 			if (config->single_install == PK_CNF_POLICY_WARN) {
 				/* TRANSLATORS: tell the user what package provides the command */
 				g_printerr ("%s '%s'\n", _("The package providing this file is:"), parts[PK_PACKAGE_ID_NAME]);
+				goto out;
+			}
 
 			/* ask */
-			} else if (config->single_install == PK_CNF_POLICY_ASK) {
+			if (config->single_install == PK_CNF_POLICY_ASK) {
 				/* TRANSLATORS: as the user if we want to install a package to provide the command */
 				text = g_strdup_printf (_("Install package '%s' to provide command '%s'?"), parts[PK_PACKAGE_ID_NAME], argv[1]);
 				ret = pk_console_get_prompt (text, FALSE);
@@ -815,9 +833,12 @@ main (int argc, char *argv[])
 					else
 						retval = EXIT_COMMAND_NOT_FOUND;
 				}
+				g_print ("\n");
+				goto out;
+			}
 
 			/* install */
-			} else if (config->single_install == PK_CNF_POLICY_INSTALL) {
+			if (config->single_install == PK_CNF_POLICY_INSTALL) {
 				ret = pk_cnf_install_package_id (package_ids[0]);
 				if (ret)
 					retval = pk_cnf_spawn_command (argv[1], &argv[2]);
@@ -860,9 +881,6 @@ main (int argc, char *argv[])
 			goto out;
 		}
 	}
-
-	g_printerr ("\n");
-
 out:
 	g_strfreev (package_ids);
 	if (task != NULL)
