@@ -153,9 +153,13 @@ out:
 static void
 queue_install_fonts_tag (const char *tag)
 {
+	guint idle_id;
 	if (tags == NULL) {
 		tags = g_ptr_array_new ();
-		g_idle_add (pk_install_fonts_idle_cb, NULL);
+		idle_id = g_idle_add (pk_install_fonts_idle_cb, NULL);
+#if GLIB_CHECK_VERSION(2,25,8)
+		g_source_set_name_by_id (idle_id, "[PkGtkModule] install fonts");
+#endif
 	}
 
 	g_ptr_array_add (tags, (gpointer) g_strdup (tag));
