@@ -1,22 +1,22 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2007-2008 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2007-2010 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU General Public License Version 2
+ * Licensed under the GNU Lesser General Public License Version 2.1
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
 /**
@@ -31,9 +31,6 @@
 #include <string.h>
 #include <glib.h>
 
-#include "egg-debug.h"
-#include "egg-string.h"
-
 #include <packagekit-glib2/pk-common.h>
 #include <packagekit-glib2/pk-enum.h>
 
@@ -127,6 +124,7 @@ static const PkEnumMatch enum_role[] = {
 	{PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES,	"simulate-install-packages"},
 	{PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES,		"simulate-remove-packages"},
 	{PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES,		"simulate-update-packages"},
+	{PK_ROLE_ENUM_UPGRADE_SYSTEM,			"upgrade-system"},
 	{0, NULL}
 };
 
@@ -193,6 +191,9 @@ static const PkEnumMatch enum_error[] = {
 	{PK_ERROR_ENUM_PACKAGE_FAILED_TO_REMOVE, "package-failed-to-remove"},
 	{PK_ERROR_ENUM_UPDATE_FAILED_DUE_TO_RUNNING_PROCESS, "failed-due-to-running-process"},
 	{PK_ERROR_ENUM_PACKAGE_DATABASE_CHANGED, "package-database-changed"},
+	{PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED, "provide-type-not-supported"},
+	{PK_ERROR_ENUM_INSTALL_ROOT_INVALID,	"install-root-invalid"},
+	{PK_ERROR_ENUM_CANNOT_FETCH_SOURCES,	"cannot-fetch-sources"},
 	{0, NULL}
 };
 
@@ -224,6 +225,7 @@ static const PkEnumMatch enum_message[] = {
 	{PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED, "autoremove-ignored"},
 	{PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED, "repo-metadata-download-failed"},
 	{PK_MESSAGE_ENUM_REPO_FOR_DEVELOPERS_ONLY, "repo-for-developers-only"},
+	{PK_MESSAGE_ENUM_OTHER_UPDATES_HELD_BACK, "other-updates-held-back"},
 	{0, NULL}
 };
 
@@ -375,6 +377,7 @@ static const PkEnumMatch enum_free_licenses[] = {
 	{PK_LICENSE_ENUM_AFL,			"AFL"},
 	{PK_LICENSE_ENUM_AGPLV1,		"AGPLv1"},
 	{PK_LICENSE_ENUM_AMDPLPA,		"AMDPLPA"},
+	{PK_LICENSE_ENUM_AML,			"AML"},
 	{PK_LICENSE_ENUM_AMPAS_BSD,		"AMPAS BSD"},
 	{PK_LICENSE_ENUM_APSL_2_DOT_0,		"APSL 2.0"},
 	{PK_LICENSE_ENUM_ARL,			"ARL"},
@@ -385,6 +388,7 @@ static const PkEnumMatch enum_free_licenses[] = {
 	{PK_LICENSE_ENUM_ASL_1_DOT_1,		"ASL 1.1"},
 	{PK_LICENSE_ENUM_ASL_2_DOT_0,		"ASL 2.0"},
 	{PK_LICENSE_ENUM_BAEKMUK,		"Baekmuk"},
+	{PK_LICENSE_ENUM_BEOPEN,		"BeOpen"},
 	{PK_LICENSE_ENUM_BITTORRENT,		"BitTorrent"},
 	{PK_LICENSE_ENUM_BOOST,			"Boost"},
 	{PK_LICENSE_ENUM_BSD,			"BSD"},
@@ -457,6 +461,7 @@ static const PkEnumMatch enum_free_licenses[] = {
 	{PK_LICENSE_ENUM_JPYTHON,		"JPython"},
 	{PK_LICENSE_ENUM_KNUTH,			"Knuth"},
 	{PK_LICENSE_ENUM_LBNL_BSD,		"LBNL BSD"},
+	{PK_LICENSE_ENUM_LDPL,			"LDPL"},
 	{PK_LICENSE_ENUM_LGPLV2,		"LGPLv2"},
 	{PK_LICENSE_ENUM_LGPLV2_PLUS,		"LGPLv2+"},
 	{PK_LICENSE_ENUM_LGPLV2_PLUS_OR_ARTISTIC, "LGPLv2+ or Artistic"},
@@ -482,6 +487,7 @@ static const PkEnumMatch enum_free_licenses[] = {
 	{PK_LICENSE_ENUM_MPLV1_DOT_0,		"MPLv1.0"},
 	{PK_LICENSE_ENUM_MPLV1_DOT_1,		"MPLv1.1"},
 	{PK_LICENSE_ENUM_MS_PL,			"MS-PL"},
+	{PK_LICENSE_ENUM_MS_RL,			"MS-RL"},
 	{PK_LICENSE_ENUM_NAUMEN,		"Naumen"},
 	{PK_LICENSE_ENUM_NCSA,			"NCSA"},
 	{PK_LICENSE_ENUM_NETCDF,		"NetCDF"},
@@ -494,6 +500,7 @@ static const PkEnumMatch enum_free_licenses[] = {
 	{PK_LICENSE_ENUM_OAL,			"OAL"},
 	{PK_LICENSE_ENUM_OFL,			"OFL"},
 	{PK_LICENSE_ENUM_OFSFDL,		"OFSFDL"},
+	{PK_LICENSE_ENUM_OML,			"OML"},
 	{PK_LICENSE_ENUM_OPENLDAP,		"OpenLDAP"},
 	{PK_LICENSE_ENUM_OPENPBS,		"OpenPBS"},
 	{PK_LICENSE_ENUM_OPENSSL,		"OpenSSL"},
@@ -506,6 +513,7 @@ static const PkEnumMatch enum_free_licenses[] = {
 	{PK_LICENSE_ENUM_PHORUM,		"Phorum"},
 	{PK_LICENSE_ENUM_PHP,			"PHP"},
 	{PK_LICENSE_ENUM_PLEXUS,		"Plexus"},
+	{PK_LICENSE_ENUM_POSTGRESQL,		"PostgreSQL"},
 	{PK_LICENSE_ENUM_PSUTILS,		"psutils"},
 	{PK_LICENSE_ENUM_PTFL,			"PTFL"},
 	{PK_LICENSE_ENUM_PUBLIC_DOMAIN,		"Public Domain"},
@@ -515,6 +523,7 @@ static const PkEnumMatch enum_free_licenses[] = {
 	{PK_LICENSE_ENUM_QPL,			"QPL"},
 	{PK_LICENSE_ENUM_RDISC,			"Rdisc"},
 	{PK_LICENSE_ENUM_RICEBSD,		"RiceBSD"},
+	{PK_LICENSE_ENUM_ROMIO,			"Romio"},
 	{PK_LICENSE_ENUM_RPSL,			"RPSL"},
 	{PK_LICENSE_ENUM_RUBY,			"Ruby"},
 	{PK_LICENSE_ENUM_SAXPATH,		"Saxpath"},
@@ -528,6 +537,7 @@ static const PkEnumMatch enum_free_licenses[] = {
 	{PK_LICENSE_ENUM_SPL,			"SPL"},
 	{PK_LICENSE_ENUM_STIX,			"STIX"},
 	{PK_LICENSE_ENUM_TCL,			"TCL"},
+	{PK_LICENSE_ENUM_TEEWORLDS,		"Teeworlds"},
 	{PK_LICENSE_ENUM_TMATE,			"TMate"},
 	{PK_LICENSE_ENUM_TOSL,			"TOSL"},
 	{PK_LICENSE_ENUM_TPL,			"TPL"},
@@ -571,6 +581,14 @@ static const PkEnumMatch enum_authorize_type[] = {
 	{0, NULL}
 };
 
+static const PkEnumMatch enum_upgrade_kind[] = {
+	{PK_UPGRADE_KIND_ENUM_UNKNOWN,		"unknown"},	/* fall though value */
+	{PK_UPGRADE_KIND_ENUM_MINIMAL,		"minimal"},
+	{PK_UPGRADE_KIND_ENUM_DEFAULT,		"default"},
+	{PK_UPGRADE_KIND_ENUM_COMPLETE,		"complete"},
+	{0, NULL}
+};
+
 /**
  * pk_enum_find_value:
  * @table: A #PkEnumMatch enum table of values
@@ -629,7 +647,7 @@ pk_enum_find_string (const PkEnumMatch *table, guint value)
 }
 
 /**
- * pk_sig_type_enum_from_text:
+ * pk_sig_type_enum_from_string:
  * @sig_type: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
@@ -637,655 +655,567 @@ pk_enum_find_string (const PkEnumMatch *table, guint value)
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
  */
 PkSigTypeEnum
-pk_sig_type_enum_from_text (const gchar *sig_type)
+pk_sig_type_enum_from_string (const gchar *sig_type)
 {
 	return pk_enum_find_value (enum_sig_type, sig_type);
 }
 
 /**
- * pk_sig_type_enum_to_text:
+ * pk_sig_type_enum_to_string:
  * @sig_type: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_sig_type_enum_to_text (PkSigTypeEnum sig_type)
+pk_sig_type_enum_to_string (PkSigTypeEnum sig_type)
 {
 	return pk_enum_find_string (enum_sig_type, sig_type);
 }
 
 /**
- * pk_distro_upgrade_enum_from_text:
+ * pk_distro_upgrade_enum_from_string:
  * @upgrade: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_DISTRO_UPGRADE_ENUM_STABLE
- */
+ *
+ * Since: 0.5.0
+ **/
 PkDistroUpgradeEnum
-pk_distro_upgrade_enum_from_text (const gchar *upgrade)
+pk_distro_upgrade_enum_from_string (const gchar *upgrade)
 {
 	return pk_enum_find_value (enum_upgrade, upgrade);
 }
 
 /**
- * pk_distro_upgrade_enum_to_text:
+ * pk_distro_upgrade_enum_to_string:
  * @upgrade: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "stable"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_distro_upgrade_enum_to_text (PkDistroUpgradeEnum upgrade)
+pk_distro_upgrade_enum_to_string (PkDistroUpgradeEnum upgrade)
 {
 	return pk_enum_find_string (enum_upgrade, upgrade);
 }
 
 /**
- * pk_provides_enum_from_text:
+ * pk_provides_enum_from_string:
  * @provides: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_PROVIDES_ENUM_MODALIAS
- */
+ *
+ * Since: 0.5.0
+ **/
 PkProvidesEnum
-pk_provides_enum_from_text (const gchar *provides)
+pk_provides_enum_from_string (const gchar *provides)
 {
 	return pk_enum_find_value (enum_provides, provides);
 }
 
 /**
- * pk_provides_enum_to_text:
+ * pk_provides_enum_to_string:
  * @provides: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "codec"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_provides_enum_to_text (PkProvidesEnum provides)
+pk_provides_enum_to_string (PkProvidesEnum provides)
 {
 	return pk_enum_find_string (enum_provides, provides);
 }
 
 /**
- * pk_info_enum_from_text:
+ * pk_info_enum_from_string:
  * @info: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
- */
+ *
+ * Since: 0.5.0
+ **/
 PkInfoEnum
-pk_info_enum_from_text (const gchar *info)
+pk_info_enum_from_string (const gchar *info)
 {
 	return pk_enum_find_value (enum_info, info);
 }
 
 /**
- * pk_info_enum_to_text:
+ * pk_info_enum_to_string:
  * @info: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_info_enum_to_text (PkInfoEnum info)
+pk_info_enum_to_string (PkInfoEnum info)
 {
 	return pk_enum_find_string (enum_info, info);
 }
 
 /**
- * pk_exit_enum_from_text:
+ * pk_exit_enum_from_string:
  * @exit: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
- */
+ *
+ * Since: 0.5.0
+ **/
 PkExitEnum
-pk_exit_enum_from_text (const gchar *exit_text)
+pk_exit_enum_from_string (const gchar *exit_text)
 {
 	return pk_enum_find_value (enum_exit, exit_text);
 }
 
 /**
- * pk_exit_enum_to_text:
+ * pk_exit_enum_to_string:
  * @exit: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_exit_enum_to_text (PkExitEnum exit_enum)
+pk_exit_enum_to_string (PkExitEnum exit_enum)
 {
 	return pk_enum_find_string (enum_exit, exit_enum);
 }
 
 /**
- * pk_network_enum_from_text:
+ * pk_network_enum_from_string:
  * @network: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
- */
+ *
+ * Since: 0.5.0
+ **/
 PkNetworkEnum
-pk_network_enum_from_text (const gchar *network)
+pk_network_enum_from_string (const gchar *network)
 {
 	return pk_enum_find_value (enum_network, network);
 }
 
 /**
- * pk_network_enum_to_text:
+ * pk_network_enum_to_string:
  * @network: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_network_enum_to_text (PkNetworkEnum network)
+pk_network_enum_to_string (PkNetworkEnum network)
 {
 	return pk_enum_find_string (enum_network, network);
 }
 
 /**
- * pk_status_enum_from_text:
+ * pk_status_enum_from_string:
  * @status: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
+ *
+ * Since: 0.5.0
  **/
 PkStatusEnum
-pk_status_enum_from_text (const gchar *status)
+pk_status_enum_from_string (const gchar *status)
 {
 	return pk_enum_find_value (enum_status, status);
 }
 
 /**
- * pk_status_enum_to_text:
+ * pk_status_enum_to_string:
  * @status: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_status_enum_to_text (PkStatusEnum status)
+pk_status_enum_to_string (PkStatusEnum status)
 {
 	return pk_enum_find_string (enum_status, status);
 }
 
 /**
- * pk_role_enum_from_text:
+ * pk_role_enum_from_string:
  * @role: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
+ *
+ * Since: 0.5.0
  **/
 PkRoleEnum
-pk_role_enum_from_text (const gchar *role)
+pk_role_enum_from_string (const gchar *role)
 {
 	return pk_enum_find_value (enum_role, role);
 }
 
 /**
- * pk_role_enum_to_text:
+ * pk_role_enum_to_string:
  * @role: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_role_enum_to_text (PkRoleEnum role)
+pk_role_enum_to_string (PkRoleEnum role)
 {
 	return pk_enum_find_string (enum_role, role);
 }
 
 /**
- * pk_error_enum_from_text:
+ * pk_error_enum_from_string:
  * @code: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
+ *
+ * Since: 0.5.0
  **/
 PkErrorEnum
-pk_error_enum_from_text (const gchar *code)
+pk_error_enum_from_string (const gchar *code)
 {
 	return pk_enum_find_value (enum_error, code);
 }
 
 /**
- * pk_error_enum_to_text:
+ * pk_error_enum_to_string:
  * @code: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_error_enum_to_text (PkErrorEnum code)
+pk_error_enum_to_string (PkErrorEnum code)
 {
 	return pk_enum_find_string (enum_error, code);
 }
 
 /**
- * pk_restart_enum_from_text:
+ * pk_restart_enum_from_string:
  * @restart: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
+ *
+ * Since: 0.5.0
  **/
 PkRestartEnum
-pk_restart_enum_from_text (const gchar *restart)
+pk_restart_enum_from_string (const gchar *restart)
 {
 	return pk_enum_find_value (enum_restart, restart);
 }
 
 /**
- * pk_restart_enum_to_text:
+ * pk_restart_enum_to_string:
  * @restart: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_restart_enum_to_text (PkRestartEnum restart)
+pk_restart_enum_to_string (PkRestartEnum restart)
 {
 	return pk_enum_find_string (enum_restart, restart);
 }
 
 /**
- * pk_message_enum_from_text:
+ * pk_message_enum_from_string:
  * @message: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
+ *
+ * Since: 0.5.0
  **/
 PkMessageEnum
-pk_message_enum_from_text (const gchar *message)
+pk_message_enum_from_string (const gchar *message)
 {
 	return pk_enum_find_value (enum_message, message);
 }
 
 /**
- * pk_message_enum_to_text:
+ * pk_message_enum_to_string:
  * @message: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_message_enum_to_text (PkMessageEnum message)
+pk_message_enum_to_string (PkMessageEnum message)
 {
 	return pk_enum_find_string (enum_message, message);
 }
 
 /**
- * pk_group_enum_from_text:
+ * pk_group_enum_from_string:
  * @group: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
+ *
+ * Since: 0.5.0
  **/
 PkGroupEnum
-pk_group_enum_from_text (const gchar *group)
+pk_group_enum_from_string (const gchar *group)
 {
 	return pk_enum_find_value (enum_group, group);
 }
 
 /**
- * pk_group_enum_to_text:
+ * pk_group_enum_to_string:
  * @group: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_group_enum_to_text (PkGroupEnum group)
+pk_group_enum_to_string (PkGroupEnum group)
 {
 	return pk_enum_find_string (enum_group, group);
 }
 
 /**
- * pk_update_state_enum_from_text:
+ * pk_update_state_enum_from_string:
  * @update_state: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. %PK_UPDATE_STATE_ENUM_STABLE
+ *
+ * Since: 0.5.0
  **/
 PkUpdateStateEnum
-pk_update_state_enum_from_text (const gchar *update_state)
+pk_update_state_enum_from_string (const gchar *update_state)
 {
 	return pk_enum_find_value (enum_update_state, update_state);
 }
 
 /**
- * pk_update_state_enum_to_text:
+ * pk_update_state_enum_to_string:
  * @update_state: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "testing"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_update_state_enum_to_text (PkUpdateStateEnum update_state)
+pk_update_state_enum_to_string (PkUpdateStateEnum update_state)
 {
 	return pk_enum_find_string (enum_update_state, update_state);
 }
 
 /**
- * pk_filter_enum_from_text:
+ * pk_filter_enum_from_string:
  * @filter: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
+ *
+ * Since: 0.5.0
  **/
 PkFilterEnum
-pk_filter_enum_from_text (const gchar *filter)
+pk_filter_enum_from_string (const gchar *filter)
 {
 	return pk_enum_find_value (enum_filter, filter);
 }
 
 /**
- * pk_filter_enum_to_text:
+ * pk_filter_enum_to_string:
  * @filter: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_filter_enum_to_text (PkFilterEnum filter)
+pk_filter_enum_to_string (PkFilterEnum filter)
 {
 	return pk_enum_find_string (enum_filter, filter);
 }
 
 /**
- * pk_license_enum_from_text:
+ * pk_license_enum_from_string:
  * @license: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_SIGTYPE_ENUM_GPG
+ *
+ * Since: 0.5.0
  **/
 PkLicenseEnum
-pk_license_enum_from_text (const gchar *license)
+pk_license_enum_from_string (const gchar *license)
 {
 	return pk_enum_find_value (enum_free_licenses, license);
 }
 
 /**
- * pk_license_enum_to_text:
+ * pk_license_enum_to_string:
  * @license: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "available"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_license_enum_to_text (PkLicenseEnum license)
+pk_license_enum_to_string (PkLicenseEnum license)
 {
 	return pk_enum_find_string (enum_free_licenses, license);
 }
 
 /**
- * pk_media_type_enum_from_text:
- * @code: Text describing the enumerated type
+ * pk_media_type_enum_from_string:
+ * @media_type: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
  * Return value: the enumerated constant value, e.g. PK_MEDIA_TYPE_ENUM_CD
+ *
+ * Since: 0.5.0
  **/
 PkMediaTypeEnum
-pk_media_type_enum_from_text (const gchar *media_type)
+pk_media_type_enum_from_string (const gchar *media_type)
 {
 	return pk_enum_find_value (enum_media_type, media_type);
 }
 
 /**
- * pk_media_type_enum_to_text:
- * @code: The enumerated type value
+ * pk_media_type_enum_to_string:
+ * @media_type: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "dvd"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_media_type_enum_to_text (PkMediaTypeEnum media_type)
+pk_media_type_enum_to_string (PkMediaTypeEnum media_type)
 {
 	return pk_enum_find_string (enum_media_type, media_type);
 }
 
 /**
- * pk_authorize_type_enum_from_text:
- * @code: Text describing the enumerated type
+ * pk_authorize_type_enum_from_string:
+ * @authorize_type: Text describing the enumerated type
  *
  * Converts a text enumerated type to its unsigned integer representation
  *
- * Return value: the enumerated constant value, e.g. PK_AUTHORIZE_ENUM_YES
+ * Return value: the enumerated constant value, e.g. %PK_AUTHORIZE_ENUM_YES
+ *
+ * Since: 0.5.0
  **/
 PkAuthorizeEnum
-pk_authorize_type_enum_from_text (const gchar *authorize_type)
+pk_authorize_type_enum_from_string (const gchar *authorize_type)
 {
 	return pk_enum_find_value (enum_authorize_type, authorize_type);
 }
 
 /**
- * pk_authorize_type_enum_to_text:
- * @code: The enumerated type value
+ * pk_authorize_type_enum_to_string:
+ * @authorize_type: The enumerated type value
  *
  * Converts a enumerated type to its text representation
  *
  * Return value: the enumerated constant value, e.g. "yes"
+ *
+ * Since: 0.5.0
  **/
 const gchar *
-pk_authorize_type_enum_to_text (PkAuthorizeEnum authorize_type)
+pk_authorize_type_enum_to_string (PkAuthorizeEnum authorize_type)
 {
 	return pk_enum_find_string (enum_authorize_type, authorize_type);
 }
 
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-pk_enum_test (gpointer user_data)
+/**
+ * pk_upgrade_kind_enum_from_string:
+ * @upgrade_kind: Text describing the enumerated type
+ *
+ * Converts a text enumerated type to its unsigned integer representation
+ *
+ * Return value: the enumerated constant value, e.g. %PK_UPGRADE_KIND_ENUM_MINIMAL
+ *
+ * Since: 0.6.11
+ **/
+PkUpgradeKindEnum
+pk_upgrade_kind_enum_from_string (const gchar *upgrade_kind)
 {
-	EggTest *test = (EggTest *) user_data;
-	const gchar *string;
-	PkRoleEnum role_value;
-	guint i;
-
-	if (!egg_test_start (test, "PkEnum"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "find role_value");
-	role_value = pk_enum_find_value (enum_role, "search-file");
-	if (role_value == PK_ROLE_ENUM_SEARCH_FILE)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "find string");
-	string = pk_enum_find_string (enum_role, PK_ROLE_ENUM_SEARCH_FILE);
-	if (g_strcmp0 (string, "search-file") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "find value");
-	role_value = pk_role_enum_from_text ("search-file");
-	if (role_value == PK_ROLE_ENUM_SEARCH_FILE)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "find string");
-	string = pk_role_enum_to_text (PK_ROLE_ENUM_SEARCH_FILE);
-	if (g_strcmp0 (string, "search-file") == 0)
-		egg_test_success (test, NULL);
-	else
-		egg_test_failed (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the role bitfield");
-	for (i=1; i<PK_ROLE_ENUM_LAST; i++) {
-		string = pk_role_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the status bitfield");
-	for (i=1; i<PK_STATUS_ENUM_LAST; i++) {
-		string = pk_status_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the exit bitfield");
-	for (i=0; i<PK_EXIT_ENUM_LAST; i++) {
-		string = pk_exit_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the filter bitfield");
-	for (i=0; i<PK_FILTER_ENUM_LAST; i++) {
-		string = pk_filter_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the restart bitfield");
-	for (i=0; i<PK_RESTART_ENUM_LAST; i++) {
-		string = pk_restart_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the error_code bitfield");
-	for (i=0; i<PK_ERROR_ENUM_LAST; i++) {
-		string = pk_error_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the group bitfield");
-	for (i=1; i<PK_GROUP_ENUM_LAST; i++) {
-		string = pk_group_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the info bitfield");
-	for (i=1; i<PK_INFO_ENUM_LAST; i++) {
-		string = pk_info_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the sig_type bitfield");
-	for (i=0; i<PK_SIGTYPE_ENUM_LAST; i++) {
-		string = pk_sig_type_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the upgrade bitfield");
-	for (i=0; i<PK_DISTRO_UPGRADE_ENUM_LAST; i++) {
-		string = pk_distro_upgrade_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the license bitfield");
-	for (i=0; i<PK_LICENSE_ENUM_LAST; i++) {
-		string = pk_license_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	/************************************************************/
-	egg_test_title (test, "check we convert all the media type bitfield");
-	for (i=0; i<PK_MEDIA_TYPE_ENUM_LAST; i++) {
-		string = pk_media_type_enum_to_text (i);
-		if (string == NULL) {
-			egg_test_failed (test, "failed to get %i", i);
-			break;
-		}
-	}
-	egg_test_success (test, NULL);
-
-	egg_test_end (test);
+	return pk_enum_find_value (enum_upgrade_kind, upgrade_kind);
 }
-#endif
 
+/**
+ * pk_upgrade_kind_enum_to_string:
+ * @upgrade_kind: The enumerated type value
+ *
+ * Converts a enumerated type to its text representation
+ *
+ * Return value: the enumerated constant value, e.g. "minimal"
+ *
+ * Since: 0.6.11
+ **/
+const gchar *
+pk_upgrade_kind_enum_to_string (PkUpgradeKindEnum upgrade_kind)
+{
+	return pk_enum_find_string (enum_upgrade_kind, upgrade_kind);
+}
