@@ -2,21 +2,21 @@
  *
  * Copyright (C) 2009 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU General Public License Version 2
+ * Licensed under the GNU Lesser General Public License Version 2.1
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
 /**
@@ -36,8 +36,6 @@
 #include <packagekit-glib2/pk-results.h>
 #include <packagekit-glib2/pk-enum.h>
 
-#include "egg-debug.h"
-
 static void     pk_results_finalize	(GObject     *object);
 
 #define PK_RESULTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_RESULTS, PkResultsPrivate))
@@ -67,6 +65,7 @@ struct _PkResultsPrivate
 	GPtrArray		*media_change_required_array;
 	GPtrArray		*repo_detail_array;
 	GPtrArray		*message_array;
+	PkPackageSack		*package_sack;
 };
 
 enum {
@@ -139,6 +138,8 @@ pk_results_set_property (GObject *object, guint prop_id, const GValue *value, GP
  * Sets the results object to have the given exit code.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_set_exit_code (PkResults *results, PkExitEnum exit_enum)
@@ -159,6 +160,8 @@ pk_results_set_exit_code (PkResults *results, PkExitEnum exit_enum)
  * Adds a package to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.3
  **/
 gboolean
 pk_results_add_package (PkResults *results, PkPackage *item)
@@ -173,11 +176,12 @@ pk_results_add_package (PkResults *results, PkPackage *item)
 		      "info", &info,
 		      NULL);
 	if (info == PK_INFO_ENUM_FINISHED) {
-		egg_warning ("internal error: finished packages cannot be added to a PkResults object");
+		g_warning ("internal error: finished packages cannot be added to a PkResults object");
 		return FALSE;
 	}
 
 	/* copy and add to array */
+	pk_package_sack_add_package (results->priv->package_sack, item);
 	g_ptr_array_add (results->priv->package_array, g_object_ref (item));
 
 	return TRUE;
@@ -191,6 +195,8 @@ pk_results_add_package (PkResults *results, PkPackage *item)
  * Adds some package details to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_details (PkResults *results, PkDetails *item)
@@ -212,6 +218,8 @@ pk_results_add_details (PkResults *results, PkDetails *item)
  * Adds some update details to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_update_detail (PkResults *results, PkUpdateDetail *item)
@@ -233,6 +241,8 @@ pk_results_add_update_detail (PkResults *results, PkUpdateDetail *item)
  * Adds a category item to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_category (PkResults *results, PkCategory *item)
@@ -254,6 +264,8 @@ pk_results_add_category (PkResults *results, PkCategory *item)
  * Adds a distribution upgrade item to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_distro_upgrade (PkResults *results, PkDistroUpgrade *item)
@@ -275,6 +287,8 @@ pk_results_add_distro_upgrade (PkResults *results, PkDistroUpgrade *item)
  * Adds a require restart item to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_require_restart (PkResults *results, PkRequireRestart *item)
@@ -296,6 +310,8 @@ pk_results_add_require_restart (PkResults *results, PkRequireRestart *item)
  * Adds a transaction item to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_transaction (PkResults *results, PkTransactionPast *item)
@@ -317,6 +333,8 @@ pk_results_add_transaction (PkResults *results, PkTransactionPast *item)
  * Adds some files details to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_files (PkResults *results, PkFiles *item)
@@ -338,6 +356,8 @@ pk_results_add_files (PkResults *results, PkFiles *item)
  * Adds some repository signature details to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_repo_signature_required (PkResults *results, PkRepoSignatureRequired *item)
@@ -359,6 +379,8 @@ pk_results_add_repo_signature_required (PkResults *results, PkRepoSignatureRequi
  * Adds some EULA details to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_eula_required (PkResults *results, PkEulaRequired *item)
@@ -380,6 +402,8 @@ pk_results_add_eula_required (PkResults *results, PkEulaRequired *item)
  * Adds some media change details to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_media_change_required (PkResults *results, PkMediaChangeRequired *item)
@@ -401,6 +425,8 @@ pk_results_add_media_change_required (PkResults *results, PkMediaChangeRequired
  * Adds some repository details to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_repo_detail (PkResults *results, PkRepoDetail *item)
@@ -422,6 +448,8 @@ pk_results_add_repo_detail (PkResults *results, PkRepoDetail *item)
  * Adds some error details to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_set_error_code (PkResults *results, PkError *item)
@@ -445,6 +473,8 @@ pk_results_set_error_code (PkResults *results, PkError *item)
  * Adds some message details to the results set.
  *
  * Return value: %TRUE if the value was set
+ *
+ * Since: 0.5.2
  **/
 gboolean
 pk_results_add_message (PkResults *results, PkMessage *item)
@@ -466,6 +496,8 @@ pk_results_add_message (PkResults *results, PkMessage *item)
  * instead using the much more useful pk_results_get_error_code() function.
  *
  * Return value: The #PkExitEnum or %PK_EXIT_ENUM_UNKNOWN for error or if it was not set
+ *
+ * Since: 0.5.2
  **/
 PkExitEnum
 pk_results_get_exit_code (PkResults *results)
@@ -480,7 +512,9 @@ pk_results_get_exit_code (PkResults *results)
  *
  * Gets the last error code from the transaction.
  *
- * Return value: A #PkError, or %NULL, free with g_object_unref()
+ * Return value: (transfer full): A #PkError, or %NULL, free with g_object_unref()
+ *
+ * Since: 0.5.2
  **/
 PkError *
 pk_results_get_error_code (PkResults *results)
@@ -489,7 +523,7 @@ pk_results_get_error_code (PkResults *results)
 
 	/* failed, but no exit code? */
 	if (results->priv->error_code == NULL && results->priv->exit_enum != PK_EXIT_ENUM_SUCCESS)
-		egg_warning ("internal error: failed, but no exit code: %s", pk_exit_enum_to_text (results->priv->exit_enum));
+		g_warning ("internal error: failed, but no exit code: %s", pk_exit_enum_to_string (results->priv->exit_enum));
 
 	if (results->priv->error_code == NULL)
 		return NULL;
@@ -502,7 +536,9 @@ pk_results_get_error_code (PkResults *results)
  *
  * Gets the packages from the transaction.
  *
- * Return value: A #GPtrArray array of #PkDetails's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkDetails's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_package_array (PkResults *results)
@@ -517,30 +553,15 @@ pk_results_get_package_array (PkResults *results)
  *
  * Gets a package sack from the transaction.
  *
- * Return value: A #PkPackageSack of data.
+ * Return value: (transfer full): A #PkPackageSack of data, g_object_unref() to free.
+ *
+ * Since: 0.5.2
  **/
 PkPackageSack *
 pk_results_get_package_sack (PkResults *results)
 {
-	PkPackage *package;
-	PkPackageSack *sack;
-	GPtrArray *array;
-	guint i;
-
 	g_return_val_if_fail (PK_IS_RESULTS (results), NULL);
-
-	/* create a new sack */
-	sack = pk_package_sack_new ();
-
-	/* go through each of the bare packages */
-	array = results->priv->package_array;
-	for (i=0; i<array->len; i++) {
-		package = g_ptr_array_index (array, i);
-		pk_package_sack_add_package (sack, g_object_ref (package));
-		g_object_unref (package);
-	}
-
-	return sack;
+	return g_object_ref (results->priv->package_sack);
 }
 
 /**
@@ -549,7 +570,9 @@ pk_results_get_package_sack (PkResults *results)
  *
  * Gets the package details from the transaction.
  *
- * Return value: A #GPtrArray array of #PkPackage's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkPackage's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_details_array (PkResults *results)
@@ -564,7 +587,9 @@ pk_results_get_details_array (PkResults *results)
  *
  * Gets the update details from the transaction.
  *
- * Return value: A #GPtrArray array of #PkUpdateDetail's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkUpdateDetail's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_update_detail_array (PkResults *results)
@@ -579,7 +604,9 @@ pk_results_get_update_detail_array (PkResults *results)
  *
  * Gets the categories from the transaction.
  *
- * Return value: A #GPtrArray array of #PkCategory's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkCategory's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_category_array (PkResults *results)
@@ -594,7 +621,9 @@ pk_results_get_category_array (PkResults *results)
  *
  * Gets the distribution upgrades from the transaction.
  *
- * Return value: A #GPtrArray array of #PkDistroUpgrade's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkDistroUpgrade's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_distro_upgrade_array (PkResults *results)
@@ -609,7 +638,9 @@ pk_results_get_distro_upgrade_array (PkResults *results)
  *
  * Gets the require restarts from the transaction.
  *
- * Return value: A #GPtrArray array of #PkRequireRestart's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkRequireRestart's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_require_restart_array (PkResults *results)
@@ -631,6 +662,8 @@ pk_results_get_require_restart_array (PkResults *results)
  * system as a session restart is implied with a system restart.
  *
  * Return value: a #PkRestartEnum value, e.g. PK_RESTART_ENUM_SYSTEM
+ *
+ * Since: 0.5.2
  **/
 PkRestartEnum
 pk_results_get_require_restart_worst (PkResults *results)
@@ -662,7 +695,9 @@ pk_results_get_require_restart_worst (PkResults *results)
  *
  * Gets the transactions from the transaction.
  *
- * Return value: A #GPtrArray array of #PkTransactionPast's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkTransactionPast's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_transaction_array (PkResults *results)
@@ -677,7 +712,9 @@ pk_results_get_transaction_array (PkResults *results)
  *
  * Gets the files from the transaction.
  *
- * Return value: A #GPtrArray array of #PkFiles's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkFiles's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_files_array (PkResults *results)
@@ -692,7 +729,9 @@ pk_results_get_files_array (PkResults *results)
  *
  * Gets the repository signatures required from the transaction.
  *
- * Return value: A #GPtrArray array of #PkRepoSignatureRequired's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkRepoSignatureRequired's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_repo_signature_required_array (PkResults *results)
@@ -707,7 +746,9 @@ pk_results_get_repo_signature_required_array (PkResults *results)
  *
  * Gets the eulas required from the transaction.
  *
- * Return value: A #GPtrArray array of #PkEulaRequired's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkEulaRequired's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_eula_required_array (PkResults *results)
@@ -722,7 +763,9 @@ pk_results_get_eula_required_array (PkResults *results)
  *
  * Gets the media changes required from the transaction.
  *
- * Return value: A #GPtrArray array of #PkMediaChangeRequired's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkMediaChangeRequired's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_media_change_required_array (PkResults *results)
@@ -737,7 +780,9 @@ pk_results_get_media_change_required_array (PkResults *results)
  *
  * Gets the repository details from the transaction.
  *
- * Return value: A #GPtrArray array of #PkRepoDetail's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkRepoDetail's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_repo_detail_array (PkResults *results)
@@ -752,7 +797,9 @@ pk_results_get_repo_detail_array (PkResults *results)
  *
  * Gets the messages from the transaction.
  *
- * Return value: A #GPtrArray array of #PkMessage's, free with g_ptr_array_unref().
+ * Return value: (transfer full): A #GPtrArray array of #PkMessage's, free with g_ptr_array_unref().
+ *
+ * Since: 0.5.2
  **/
 GPtrArray *
 pk_results_get_message_array (PkResults *results)
@@ -775,6 +822,8 @@ pk_results_class_init (PkResultsClass *klass)
 
 	/**
 	 * PkResults:role:
+	 *
+	 * Since: 0.5.2
 	 */
 	pspec = g_param_spec_uint ("role", NULL, NULL,
 				   0, PK_ROLE_ENUM_LAST, PK_ROLE_ENUM_UNKNOWN,
@@ -783,6 +832,8 @@ pk_results_class_init (PkResultsClass *klass)
 
 	/**
 	 * PkResults:inputs:
+	 *
+	 * Since: 0.5.3
 	 */
 	pspec = g_param_spec_uint ("inputs", NULL, NULL,
 				   0, G_MAXUINT, 0,
@@ -793,6 +844,8 @@ pk_results_class_init (PkResultsClass *klass)
 
 	/**
 	 * PkResults:progress:
+	 *
+	 * Since: 0.5.3
 	 */
 	pspec = g_param_spec_object ("progress", NULL,
 				     "The progress instance",
@@ -814,6 +867,7 @@ pk_results_init (PkResults *results)
 	results->priv->progress = NULL;
 	results->priv->error_code = NULL;
 	results->priv->package_array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
+	results->priv->package_sack = pk_package_sack_new ();
 	results->priv->details_array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	results->priv->update_detail_array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	results->priv->category_array = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
@@ -850,6 +904,7 @@ pk_results_finalize (GObject *object)
 	g_ptr_array_unref (priv->media_change_required_array);
 	g_ptr_array_unref (priv->repo_detail_array);
 	g_ptr_array_unref (priv->message_array);
+	g_object_unref (priv->package_sack);
 	if (results->priv->progress != NULL)
 		g_object_unref (results->priv->progress);
 	if (results->priv->error_code != NULL)
@@ -862,6 +917,8 @@ pk_results_finalize (GObject *object)
  * pk_results_new:
  *
  * Return value: a new PkResults object.
+ *
+ * Since: 0.5.2
  **/
 PkResults *
 pk_results_new (void)
@@ -870,104 +927,3 @@ pk_results_new (void)
 	results = g_object_new (PK_TYPE_RESULTS, NULL);
 	return PK_RESULTS (results);
 }
-
-/***************************************************************************
- ***                          MAKE CHECK TESTS                           ***
- ***************************************************************************/
-#ifdef EGG_TEST
-#include "egg-test.h"
-
-void
-pk_results_test (gpointer user_data)
-{
-	EggTest *test = (EggTest *) user_data;
-	gboolean ret;
-	PkResults *results;
-	PkExitEnum exit_enum;
-	GPtrArray *packages;
-	PkPackage *item;
-	PkInfoEnum info;
-	gchar *package_id;
-	gchar *summary;
-
-	if (!egg_test_start (test, "PkResults"))
-		return;
-
-	/************************************************************/
-	egg_test_title (test, "get results");
-	results = pk_results_new ();
-	egg_test_assert (test, results != NULL);
-
-	/************************************************************/
-	egg_test_title (test, "get exit code of unset results");
-	exit_enum = pk_results_get_exit_code (results);
-	egg_test_assert (test, (exit_enum == PK_EXIT_ENUM_UNKNOWN));
-
-	/************************************************************/
-	egg_test_title (test, "get package list of unset results");
-	packages = pk_results_get_package_array (results);
-	egg_test_assert (test, (packages->len == 0));
-	g_ptr_array_unref (packages);
-
-	/************************************************************/
-	egg_test_title (test, "set valid exit code");
-	ret = pk_results_set_exit_code (results, PK_EXIT_ENUM_CANCELLED);
-	egg_test_assert (test, ret);
-
-	/************************************************************/
-	egg_test_title (test, "get exit code of set results");
-	exit_enum = pk_results_get_exit_code (results);
-	egg_test_assert (test, (exit_enum == PK_EXIT_ENUM_CANCELLED));
-
-	/************************************************************/
-	egg_test_title (test, "add package");
-	item = pk_package_new ();
-	g_object_set (item,
-		      "info", PK_INFO_ENUM_AVAILABLE,
-		      "package-id", "gnome-power-manager;0.1.2;i386;fedora",
-		      "summary", "Power manager for GNOME",
-		      NULL);
-	ret = pk_results_add_package (results, item);
-	g_object_unref (item);
-	egg_test_assert (test, ret);
-
-	/************************************************************/
-	egg_test_title (test, "get package list of set results");
-	packages = pk_results_get_package_array (results);
-	egg_test_assert (test, (packages->len == 1));
-
-	/************************************************************/
-	egg_test_title (test, "check data");
-	item = g_ptr_array_index (packages, 0);
-	g_object_get (item,
-		      "info", &info,
-		      "package-id", &package_id,
-		      "summary", &summary,
-		      NULL);
-	egg_test_assert (test, (info == PK_INFO_ENUM_AVAILABLE &&
-				g_strcmp0 ("gnome-power-manager;0.1.2;i386;fedora", package_id) == 0 &&
-				g_strcmp0 ("Power manager for GNOME", summary) == 0));
-	g_object_ref (item);
-	g_ptr_array_unref (packages);
-	g_free (package_id);
-	g_free (summary);
-
-	/************************************************************/
-	egg_test_title (test, "check ref");
-	g_object_get (item,
-		      "info", &info,
-		      "package-id", &package_id,
-		      "summary", &summary,
-		      NULL);
-	egg_test_assert (test, (info == PK_INFO_ENUM_AVAILABLE &&
-				g_strcmp0 ("gnome-power-manager;0.1.2;i386;fedora", package_id) == 0 &&
-				g_strcmp0 ("Power manager for GNOME", summary) == 0));
-	g_object_unref (item);
-	g_free (package_id);
-	g_free (summary);
-
-	g_object_unref (results);
-	egg_test_end (test);
-}
-#endif
-
