@@ -22,12 +22,10 @@
 #define CLIENT_H
 
 #include <QtCore>
-#include <QDBusReply>
-#include <bitfield.h>
+#include "enum.h"
 
 namespace PackageKit {
 
-class ClientPrivate;
 class Package;
 class Transaction;
 
@@ -47,21 +45,12 @@ class Transaction;
  * \note This class is a singleton, its constructor is private. Call Client::instance() to get
  * an instance of the Client object
  */
+class ClientPrivate;
 class Client : public QObject
 {
 
 	Q_OBJECT
-	Q_ENUMS(Action)
-	Q_ENUMS(Filter)
-	Q_ENUMS(Group)
-	Q_ENUMS(NetworkState)
-	Q_ENUMS(SignatureType)
-	Q_ENUMS(ProvidesType)
-	Q_ENUMS(ErrorType)
-	Q_ENUMS(MessageType)
-	Q_ENUMS(RestartType)
-	Q_ENUMS(UpdateState)
-	Q_ENUMS(DistroUpgradeType)
+	Q_ENUMS(DaemonError)
 
 public:
 	/**
@@ -79,78 +68,10 @@ public:
 
 	// Daemon functions
 
-	/**
-	 * Lists all the available actions
-	 * \sa getActions
-	 */
-	typedef enum {
-		UnknownAction,
-		ActionCancel,
-		ActionGetDepends,
-		ActionGetDetails,
-		ActionGetFiles,
-		ActionGetPackages,
-		ActionGetRepoList,
-		ActionGetRequires,
-		ActionGetUpdateDetail,
-		ActionGetUpdates,
-		ActionInstallFiles,
-		ActionInstallPackages,
-		ActionInstallSignature,
-		ActionRefreshCache,
-		ActionRemovePackages,
-		ActionRepoEnable,
-		ActionRepoSetData,
-		ActionResolve,
-		ActionRollback,
-		ActionSearchDetails,
-		ActionSearchFile,
-		ActionSearchGroup,
-		ActionSearchName,
-		ActionUpdatePackages,
-		ActionUpdateSystem,
-		ActionWhatProvides,
-		ActionAcceptEula,
-		ActionDownloadPackages,
-		ActionGetDistroUpgrades,
-		ActionGetCategories,
-		ActionGetOldTransactions,
-		ActionSimulateInstallFiles,
-		ActionSimulateInstallPackages,
-		ActionSimulateRemovePackages,
-		ActionSimulateUpdatePackages
-	} Action;
-	typedef Bitfield Actions;
-
-	/**
-	 * Returns all the actions supported by the current backend
-	 * This function is DEPRECATED and will be removed in a
-	 * future release, use \sa actions() instead.
-	 */
-	Actions Q_DECL_DEPRECATED getActions() const;
-
 	/**
 	 * Returns all the actions supported by the current backend
 	 */
-	Actions actions() const;
-
-	/**
-	 * Holds a backend's detail
-	 * \li \c name is the name of the backend
-	 * \li \c author is the name of the person who wrote the backend
-	 */
-	typedef struct {
-		QString name;
-		QString author;
-	} BackendDetail;
-
-	/**
-	 * Gets the current backend's details
-	 * \return a BackendDetail struct holding the backend's details. You have to free this structure.
-	 * This method is DEPRECATED use backendAuthor(), backendName()
-	 * and backendDescription() instead.
-	 */
-	BackendDetail Q_DECL_DEPRECATED getBackendDetail() const;
+	Enum::Roles actions() const;
 
 	/**
 	 * The backend name, e.g. "yum".
@@ -167,142 +88,30 @@ public:
 	 */
 	QString backendAuthor() const;
 
-	/**
-	 * Describes the different filters
-	 */
-	typedef enum {
-		UnknownFilter		 = 0x0000001,
-		NoFilter		 = 0x0000002,
-		FilterInstalled		 = 0x0000004,
-		FilterNotInstalled	 = 0x0000008,
-		FilterDevelopment	 = 0x0000010,
-		FilterNotDevelopment	 = 0x0000020,
-		FilterGui		 = 0x0000040,
-		FilterNotGui		 = 0x0000080,
-		FilterFree		 = 0x0000100,
-		FilterNotFree		 = 0x0000200,
-		FilterVisible		 = 0x0000400,
-		FilterNotVisible	 = 0x0000800,
-		FilterSupported		 = 0x0001000,
-		FilterNotSupported	 = 0x0002000,
-		FilterBasename		 = 0x0004000,
-		FilterNotBasename	 = 0x0008000,
-		FilterNewest		 = 0x0010000,
-		FilterNotNewest		 = 0x0020000,
-		FilterArch		 = 0x0040000,
-		FilterNotArch		 = 0x0080000,
-		FilterSource		 = 0x0100000,
-		FilterNotSource		 = 0x0200000,
-		FilterCollections	 = 0x0400000,
-		FilterNotCollections	 = 0x0800000,
-		FilterApplication	 = 0x1000000,
-		FilterNotApplication	 = 0x2000000,
-		FilterLast		 = 0x4000000
-	} Filter;
-	Q_DECLARE_FLAGS(Filters, Filter)
-
-	/**
-	 * Returns the filters supported by the current backend
-	 * This method is DEPRECATED use \sa filters() instead.
-	 */
-	Filters Q_DECL_DEPRECATED getFilters() const;
-
 	/**
 	 * Returns the filters supported by the current backend
 	 */
-	Filters filters() const;
-
-	/**
-	 * Describes the different groups
-	 */
-	typedef enum {
-		UnknownGroup,
-		GroupAccessibility,
-		GroupAccessories,
-		GroupAdminTools,
-		GroupCommunication,
-		GroupDesktopGnome,
-		GroupDesktopKde,
-		GroupDesktopOther,
-		GroupDesktopXfce,
-		GroupEducation,
-		GroupFonts,
-		GroupGames,
-		GroupGraphics,
-		GroupInternet,
-		GroupLegacy,
-		GroupLocalization,
-		GroupMaps,
-		GroupMultimedia,
-		GroupNetwork,
-		GroupOffice,
-		GroupOther,
-		GroupPowerManagement,
-		GroupProgramming,
-		GroupPublishing,
-		GroupRepos,
-		GroupSecurity,
-		GroupServers,
-		GroupSystem,
-		GroupVirtualization,
-		GroupScience,
-		GroupDocumentation,
-		GroupElectronics,
-		GroupCollections,
-		GroupVendor,
-		GroupNewest
-	} Group;
-	typedef QSet<Group> Groups;
-
-	/**
-	 * Returns the groups supported by the current backend
-	 * This method is DEPRECATED use \sa groups() instead.
-	 */
-	Groups Q_DECL_DEPRECATED getGroups() const;
+	Enum::Filters filters() const;
 
 	/**
 	 * Returns the groups supported by the current backend
 	 */
-	Groups groups() const;
+	Enum::Groups groups() const;
 
 	/**
 	 * Set when the backend is locked and native tools would fail.
 	 */
 	bool locked() const;
 
-	/**
-	 * Returns a list containing the MIME types supported by the current backend
-	 * This method is DEPRECATED use \sa mimeTypes() instead.
-	 */
-	QStringList Q_DECL_DEPRECATED getMimeTypes() const;
-
 	/**
 	 * Returns a list containing the MIME types supported by the current backend
 	 */
 	QStringList mimeTypes() const;
 
-	/**
-	 * Describes the current network state
-	 */
-	typedef enum {
-		UnknownNetworkState,
-		NetworkOffline,
-		NetworkOnline,
-		NetworkWired,
-		NetworkWifi,
-		NetworkMobile
-	} NetworkState;
-
-	/**
-	 * Returns the current network state
-	 * This method is DEPRECATED use \sa networkState() instead.
-	 */
-	NetworkState Q_DECL_DEPRECATED getNetworkState() const;
-
 	/**
 	 * Returns the current network state
 	 */
-	NetworkState networkState() const;
+	Enum::Network networkState() const;
 
 	/**
 	 * The distribution identifier in the
@@ -311,22 +120,40 @@ public:
 	 */
 	QString distroId() const;
 
+	/**
+	 * Allows a client to find out if it would be allowed to authorize an action.
+	 * The action ID, e.g. org.freedesktop.packagekit.system-network-proxy-configure
+	 * specified in \p actionId
+	 * Returm might be either yes, no or interactive.
+	 */
+	Enum::Authorize canAuthorize(const QString &actionId) const;
+
 	/**
 	 * Returns the time (in seconds) since the specified \p action
 	 */
-	uint getTimeSinceAction(Action action) const;
+	uint getTimeSinceAction(Enum::Role action) const;
 
-	/**
-	 * Returns the list of current transactions
-	 */
-	QList<Transaction*> getTransactions();
+    /**
+     * Returns the list of current transactions
+     */
+    QStringList getTransactionList() const;
 
-	/**
-	 * Sets a global locale for all the transactions to be created
-	 * \warning THIS FUNCTION IS DEPRECATED. It will be removed in a future release.
-	 * Use SetHints("locale=$code") instead.
-	 */
-	void Q_DECL_DEPRECATED setLocale(const QString& locale);
+    /**
+     * Convenience function
+     * Returns the list of current transactions objects
+     *
+     * You must delete these yourself or pass a
+     * \p parent for these comming transactions
+     */
+    QList<Transaction*> getTransactionObjectList(QObject *parent = 0);
+
+    /**
+     * DEPRECATED
+     * Returns the list of current transactions
+     * You must delete these yourself or pass a
+     * \p parent for these comming transactions
+     */
+    QList<Transaction*> Q_DECL_DEPRECATED getTransactions();
 
 	/**
 	 * \brief Sets a global hints for all the transactions to be created
@@ -366,15 +193,6 @@ public:
 	 */
 	void suggestDaemonQuit();
 
-	// Other enums
-	/**
-	 * Describes a signature type
-	 */
-	typedef enum {
-		UnknownSignatureType,
-		SignatureGpg
-	} SignatureType;
-
 	/**
 	 * Describes a package signature
 	 * \li \c package is a pointer to the signed package
@@ -383,118 +201,16 @@ public:
 	 * \li \c type is the signature type
 	 */
 	typedef struct {
-		Package* package;
+		QSharedPointer<Package> package;
 		QString repoId;
 		QString keyUrl;
 		QString keyUserid;
 		QString keyId;
 		QString keyFingerprint;
 		QString keyTimestamp;
-		SignatureType type;
+		Enum::SigType type;
 	} SignatureInfo;
 
-	/**
-	 * Enum used to describe a "provides" request
-	 * \sa whatProvides
-	 */
-	typedef enum {
-		UnknownProvidesType,
-		ProvidesAny,
-		ProvidesModalias,
-		ProvidesCodec,
-		ProvidesMimetype,
-		ProvidesFont,
-		ProvidesHardwareDriver,
-		ProvidesPostscriptDriver
-	} ProvidesType;
-
-	/**
-	 * Lists the different types of error
-	 */
-	typedef enum {
-		UnknownErrorType,
-		ErrorOom,
-		ErrorNoNetwork,
-		ErrorNotSupported,
-		ErrorInternalError,
-		ErrorGpgFailure,
-		ErrorPackageIdInvalid,
-		ErrorPackageNotInstalled,
-		ErrorPackageNotFound,
-		ErrorPackageAlreadyInstalled,
-		ErrorPackageDownloadFailed,
-		ErrorGroupNotFound,
-		ErrorGroupListInvalid,
-		ErrorDepResolutionFailed,
-		ErrorFilterInvalid,
-		ErrorCreateThreadFailed,
-		ErrorTransactionError,
-		ErrorTransactionCancelled,
-		ErrorNoCache,
-		ErrorRepoNotFound,
-		ErrorCannotRemoveSystemPackage,
-		ErrorProcessKill,
-		ErrorFailedInitialization,
-		ErrorFailedFinalise,
-		ErrorFailedConfigParsing,
-		ErrorCannotCancel,
-		ErrorCannotGetLock,
-		ErrorNoPackagesToUpdate,
-		ErrorCannotWriteRepoConfig,
-		ErrorLocalInstallFailed,
-		ErrorBadGpgSignature,
-		ErrorMissingGpgSignature,
-		ErrorCannotInstallSourcePackage,
-		ErrorRepoConfigurationError,
-		ErrorNoLicenseAgreement,
-		ErrorFileConflicts,
-		ErrorPackageConflicts,
-		ErrorRepoNotAvailable,
-		ErrorInvalidPackageFile,
-		ErrorPackageInstallBlocked,
-		ErrorPackageCorrupt,
-		ErrorAllPackagesAlreadyInstalled,
-		ErrorFileNotFound,
-		ErrorNoMoreMirrorsToTry,
-		ErrorNoDistroUpgradeData,
-		ErrorIncompatibleArchitecture,
-		ErrorNoSpaceOnDevice,
-		ErrorMediaChangeRequired,
-		ErrorNotAuthorized,
-		ErrorUpdateNotFound,
-		ErrorCannotInstallRepoUnsigned,
-		ErrorCannotUpdateRepoUnsigned,
-		ErrorCannotGetFilelist,
-		ErrorCannotGetRequires,
-		ErrorCannotDisableRepository,
-		ErrorRestrictedDownload,
-		ErrorPackageFailedToConfigure,
-		ErrorPackageFailedToBuild,
-		ErrorPackageFailedToInstall,
-		ErrorPackageFailedToRemove
-	} ErrorType;
-
-	/**
-	 * Describes a message's type
-	 */
-	typedef enum {
-		UnknownMessageType,
-		MessageBrokenMirror,
-		MessageConnectionRefused,
-		MessageParameterInvalid,
-		MessagePriorityInvalid,
-		MessageBackendError,
-		MessageDaemonError,
-		MessageCacheBeingRebuilt,
-		MessageUntrustedPackage,
-		MessageNewerPackageExists,
-		MessageCouldNotFindPackage,
-		MessageConfigFilesChanged,
-		MessagePackageAlreadyInstalled,
-		MessageAutoremoveIgnored,
-		MessageRepoMetadataDownloadFailed,
-	} MessageType;
-
 	/**
 	 * Describes an EULA
 	 * \li \c id is the EULA identifier
@@ -504,43 +220,11 @@ public:
 	 */
 	typedef struct {
 		QString id;
-		Package* package;
+		QSharedPointer<Package> package;
 		QString vendorName;
 		QString licenseAgreement;
 	} EulaInfo;
 
-	/**
-	 * Describes a restart type
-	 */
-	typedef enum {
-		UnknownRestartType,
-		RestartNone,
-		RestartApplication,
-		RestartSession,
-		RestartSystem,
-		RestartSecuritySession,
-		RestartSecuritySystem,
-	} RestartType;
-
-	/**
-	 * Describes an update's state
-	 */
-	typedef enum {
-		UnknownUpdateState,
-		UpdateStable,
-		UpdateUnstable,
-		UpdateTesting
-	} UpdateState;
-
-	/**
-	 * Describes an distro upgrade state
-	 */
-	typedef enum {
-		UnknownDistroUpgrade,
-		DistroUpgradeStable,
-		DistroUpgradeUnstable
-	} DistroUpgradeType;
-
 	/**
 	 * Describes an error at the daemon level (for example, PackageKit crashes or is unreachable)
 	 *
@@ -559,7 +243,9 @@ public:
 		ErrorInvalidInput,
 		ErrorInvalidFile,
 		ErrorFunctionNotSupported,
-		ErrorDaemonUnreachable
+		ErrorDaemonUnreachable,
+		/* this always has to be at the end of the list */
+		LastDaemonError
 	} DaemonError;
 
 	/**
@@ -580,16 +266,16 @@ public:
 	 * \li \c issued and \c updated indicate the dates at which the update was issued and updated
 	 */
 	typedef struct {
-		Package* package;
-		QList<Package*> updates;
-		QList<Package*> obsoletes;
+		QSharedPointer<Package> package;
+		QList<QSharedPointer<Package> > updates;
+		QList<QSharedPointer<Package> > obsoletes;
 		QString vendorUrl;
 		QString bugzillaUrl;
 		QString cveUrl;
-		RestartType restart;
+		Enum::Restart restart;
 		QString updateText;
 		QString changelog;
-		UpdateState state;
+		Enum::UpdateState state;
 		QDateTime issued;
 		QDateTime updated;
 	} UpdateInfo;
@@ -612,6 +298,7 @@ public:
 	// Transaction functions
 
 	/**
+     * DEPRECATED
 	 * \brief Accepts an EULA
 	 *
 	 * The EULA is identified by the EulaInfo structure \p info
@@ -620,26 +307,30 @@ public:
 	 *
 	 * \sa Transaction::eulaRequired
 	 */
-	Transaction* acceptEula(EulaInfo info);
+	Transaction* Q_DECL_DEPRECATED acceptEula(EulaInfo info);
 
 	/**
+     * DEPRECATED
 	 * Download the given \p packages to a temp dir
 	 */
-	Transaction* downloadPackages(const QList<Package*>& packages);
+	Transaction* Q_DECL_DEPRECATED downloadPackages(const QList<QSharedPointer<Package> >& packages);
 
 	/**
+     * DEPRECATED
 	 * This is a convenience function
 	 */
-	Transaction* downloadPackage(Package* package);
+	Transaction* Q_DECL_DEPRECATED downloadPackages(QSharedPointer<Package> package);
 
 	/**
+     * DEPRECATED
 	 * Returns the collection categories
 	 *
 	 * \sa Transaction::category
 	 */
-	Transaction* getCategories();
+	Transaction* Q_DECL_DEPRECATED getCategories();
 
 	/**
+     * DEPRECATED
 	 * \brief Gets the list of dependencies for the given \p packages
 	 *
 	 * You can use the \p filters to limit the results to certain packages. The
@@ -649,162 +340,188 @@ public:
 	 * \sa Transaction::package
 	 *
 	 */
-	Transaction* getDepends(const QList<Package*>& packages, Filters filters, bool recursive);
-	Transaction* getDepends(Package* package, Filters filters , bool recursive);
+	Transaction* Q_DECL_DEPRECATED getDepends(const QList<QSharedPointer<Package> >& packages, Enum::Filters filters, bool recursive);
+	Transaction* Q_DECL_DEPRECATED getDepends(QSharedPointer<Package> package, Enum::Filters filters , bool recursive);
 
 	/**
+     * DEPRECATED
 	 * Gets more details about the given \p packages
 	 *
 	 * \sa Transaction::details
 	 */
-	Transaction* getDetails(const QList<Package*>& packages);
-	Transaction* getDetails(Package* package);
+	Transaction* Q_DECL_DEPRECATED getDetails(const QList<QSharedPointer<Package> >& packages);
+	Transaction* Q_DECL_DEPRECATED getDetails(QSharedPointer<Package> package);
 
 	/**
+     * DEPRECATED
 	 * Gets the files contained in the given \p packages
 	 *
 	 * \sa Transaction::files
 	 */
-	Transaction* getFiles(const QList<Package*>& packages);
-	Transaction* getFiles(Package* packages);
+	Transaction* Q_DECL_DEPRECATED getFiles(const QList<QSharedPointer<Package> >& packages);
+	Transaction* Q_DECL_DEPRECATED getFiles(QSharedPointer<Package> packages);
 
 	/**
+     * DEPRECATED
 	 * \brief Gets the last \p number finished transactions
 	 *
 	 * \note You must delete these transactions yourself
 	 */
-	Transaction* getOldTransactions(uint number);
+	Transaction* Q_DECL_DEPRECATED getOldTransactions(uint number);
 
 	/**
+     * DEPRECATED
 	 * Gets all the packages matching the given \p filters
 	 *
 	 * \sa Transaction::package
 	 */
-	Transaction* getPackages(Filters filters = NoFilter);
+	Transaction* Q_DECL_DEPRECATED getPackages(Enum::Filters filters = Enum::NoFilter);
 
 	/**
+     * DEPRECATED
 	 * Gets the list of software repositories matching the given \p filters
 	 */
-	Transaction* getRepoList(Filters filter = NoFilter);
+	Transaction* Q_DECL_DEPRECATED getRepoList(Enum::Filters filter = Enum::NoFilter);
 
 	/**
+     * DEPRECATED
 	 * \brief Searches for the packages requiring the given \p packages
 	 *
 	 * The search can be limited using the \p filters parameter. The recursive flag is used to tell
 	 * if the package manager should also search for the package requiring the resulting packages.
 	 */
-	Transaction* getRequires(const QList<Package*>& packages, Filters filters, bool recursive);
-	Transaction* getRequires(Package* package, Filters filters, bool recursive);
+	Transaction* Q_DECL_DEPRECATED getRequires(const QList<QSharedPointer<Package> >& packages, Enum::Filters filters, bool recursive);
+	Transaction* Q_DECL_DEPRECATED getRequires(QSharedPointer<Package> package, Enum::Filters filters, bool recursive);
 
 	/**
+     * DEPRECATED
 	 * Retrieves more details about the update for the given \p packages
 	 */
-	Transaction* getUpdateDetail(const QList<Package*>& packages);
-	Transaction* getUpdateDetail(Package* package);
+	Transaction* Q_DECL_DEPRECATED getUpdateDetail(const QList<QSharedPointer<Package> >& packages);
+	Transaction* Q_DECL_DEPRECATED getUpdateDetail(QSharedPointer<Package> package);
 
 	/**
+     * DEPRECATED
 	 * \p Gets the available updates
 	 *
 	 * The \p filters parameters can be used to restrict the updates returned
 	 */
-	Transaction* getUpdates(Filters filters = NoFilter);
+	Transaction* Q_DECL_DEPRECATED getUpdates(Enum::Filters filters = Enum::NoFilter);
 
 	/**
+     * DEPRECATED
 	 * Retrieves the available distribution upgrades
 	 */
-	Transaction* getDistroUpgrades();
+	Transaction* Q_DECL_DEPRECATED getDistroUpgrades();
 
 	/**
+     * DEPRECATED
 	 * \brief Installs the local packages \p files
 	 *
 	 * \p only_trusted indicate if the packages are signed by a trusted authority
 	 */
-	Transaction* installFiles(const QStringList& files, bool only_trusted);
-	Transaction* installFile(const QString& file, bool only_trusted);
+	Transaction* Q_DECL_DEPRECATED installFiles(const QStringList& files, bool only_trusted);
+	Transaction* Q_DECL_DEPRECATED installFiles(const QString& file, bool only_trusted);
 
 	/**
+     * DEPRECATED
 	 * Install the given \p packages
 	 *
 	 * \p only_trusted indicates if we should allow installation of untrusted packages (requires a different authorization)
 	 */
-	Transaction* installPackages(bool only_trusted, const QList<Package*>& packages);
-	Transaction* installPackage(bool only_trusted, Package* p);
+	Transaction* Q_DECL_DEPRECATED installPackages(bool only_trusted, const QList<QSharedPointer<Package> >& packages);
+	Transaction* Q_DECL_DEPRECATED installPackages(bool only_trusted, QSharedPointer<Package> p);
 
 	/**
+     * DEPRECATED
 	 * \brief Installs a signature
 	 *
 	 * \p type, \p key_id and \p p generally come from the Transaction::repoSignatureRequired
 	 */
-	Transaction* installSignature(SignatureType type, const QString& key_id, Package* p);
+	Transaction* Q_DECL_DEPRECATED installSignature(Enum::SigType type, const QString& key_id, QSharedPointer<Package> p);
 
 	/**
+     * DEPRECATED
 	 * Refreshes the package manager's cache
 	 */
-	Transaction* refreshCache(bool force);
+	Transaction* Q_DECL_DEPRECATED refreshCache(bool force);
 
 	/**
+     * DEPRECATED
 	 * \brief Removes the given \p packages
 	 *
 	 * \p allow_deps if the package manager has the right to remove other packages which depend on the
 	 * packages to be removed. \p autoremove tells the package manager to remove all the package which
 	 * won't be needed anymore after the packages are uninstalled.
 	 */
-	Transaction* removePackages(const QList<Package*>& packages, bool allow_deps, bool autoremove);
-	Transaction* removePackage(Package* p, bool allow_deps, bool autoremove);
+	Transaction* Q_DECL_DEPRECATED removePackages(const QList<QSharedPointer<Package> >& packages, bool allow_deps, bool autoremove);
+	Transaction* Q_DECL_DEPRECATED removePackages(QSharedPointer<Package> p, bool allow_deps, bool autoremove);
 
 	/**
+     * DEPRECATED
 	 * Activates or disables a repository
 	 */
-	Transaction* repoEnable(const QString& repo_id, bool enable);
+	Transaction* Q_DECL_DEPRECATED repoEnable(const QString& repo_id, bool enable);
 
 	/**
+     * DEPRECATED
 	 * Sets a repository's parameter
 	 */
-	Transaction* repoSetData(const QString& repo_id, const QString& parameter, const QString& value);
+	Transaction* Q_DECL_DEPRECATED repoSetData(const QString& repo_id, const QString& parameter, const QString& value);
 
 	/**
+     * DEPRECATED
 	 * \brief Tries to create a Package object from the package's name
 	 *
 	 * The \p filters can be used to restrict the search
 	 */
-	Transaction* resolve(const QStringList& packageNames, Filters filters = NoFilter);
-	Transaction* resolve(const QString& packageName, Filters filters = NoFilter);
+	Transaction* Q_DECL_DEPRECATED resolve(const QStringList& packageNames, Enum::Filters filters = Enum::NoFilter);
+	Transaction* Q_DECL_DEPRECATED resolve(const QString& packageName, Enum::Filters filters = Enum::NoFilter);
 
 	/**
+     * DEPRECATED
 	 * Rolls back the given \p transactions
 	 */
-	Transaction* rollback(Transaction* oldtrans);
+	Transaction* Q_DECL_DEPRECATED rollback(Transaction* oldtrans);
 
 	/**
+     * DEPRECATED
 	 * \brief Search in the packages files
 	 *
 	 * \p filters can be used to restrict the returned packages
 	 */
-	Transaction* searchFile(const QString& search, Filters filters = NoFilter);
-	Transaction* searchFile(const QStringList& search, Filters filters = NoFilter);
+	Transaction* Q_DECL_DEPRECATED searchFiles(const QStringList& search, Enum::Filters filters = Enum::NoFilter);
+	Transaction* Q_DECL_DEPRECATED searchFiles(const QString& search, Enum::Filters filters = Enum::NoFilter);
 
 	/**
+     * DEPRECATED
 	 * \brief Search in the packages details
 	 *
 	 * \p filters can be used to restrict the returned packages
 	 */
-	Transaction* searchDetails(const QString& search, Filters filters = NoFilter);
+	Transaction* Q_DECL_DEPRECATED searchDetails(const QStringList& search, Enum::Filters filters = Enum::NoFilter);
+	Transaction* Q_DECL_DEPRECATED searchDetails(const QString& search, Enum::Filters filters = Enum::NoFilter);
 
 	/**
+     * DEPRECATED
 	 * \brief Lists all the packages in the given \p group
 	 *
 	 * \p filters can be used to restrict the returned packages
 	 */
-	Transaction* searchGroup(Client::Group group, Filters filters = NoFilter);
+	Transaction* Q_DECL_DEPRECATED searchGroups(Enum::Groups group, Enum::Filters filters = Enum::NoFilter);
+	Transaction* Q_DECL_DEPRECATED searchGroups(Enum::Group group, Enum::Filters filters = Enum::NoFilter);
 
 	/**
+     * DEPRECATED
 	 * \brief Search in the packages names
 	 *
 	 * \p filters can be used to restrict the returned packages
 	 */
-	Transaction* searchName(const QString& search, Filters filters = NoFilter);
+	Transaction* Q_DECL_DEPRECATED searchNames(const QStringList& search, Enum::Filters filters = Enum::NoFilter);
+	Transaction* Q_DECL_DEPRECATED searchNames(const QString& search, Enum::Filters filters = Enum::NoFilter);
 
 	/**
+     * DEPRECATED
 	 * \brief Tries to find a package name from a desktop file
 	 *
 	 * This function looks into /var/lib/PackageKit/desktop-files.db and searches for the associated package name.
@@ -812,66 +529,73 @@ public:
 	 * \p path the path to the desktop file (as shipped by the package)
 	 * \return The associated package, or NULL if there's no result
 	 */
-	Package* searchFromDesktopFile(const QString& path);
+	QSharedPointer<Package> searchFromDesktopFile(const QString& path);
 
 	/**
+     * DEPRECATED
 	 * \brief Simulates an installation of \p files.
 	 *
 	 * You should call this method before installing \p files
 	 * \note: This method might emit packages with INSTALLING, REMOVING, UPDATING,
 	 *        REINSTALLING or OBSOLETING status.
 	 */
-	Transaction* simulateInstallFiles(const QStringList& files);
-	Transaction* simulateInstallFile(const QString& file);
+	Transaction* Q_DECL_DEPRECATED simulateInstallFiles(const QStringList& files);
+	Transaction* Q_DECL_DEPRECATED simulateInstallFiles(const QString& file);
 
 	/**
+     * DEPRECATED
 	 * \brief Simulates an installation of \p packages.
 	 *
 	 * You should call this method before installing \p packages
 	 * \note: This method might emit packages with INSTALLING, REMOVING, UPDATING,
 	 *        REINSTALLING or OBSOLETING status.
 	 */
-	Transaction* simulateInstallPackages(const QList<Package*>& packages);
-	Transaction* simulateInstallPackage(Package* package);
+	Transaction* Q_DECL_DEPRECATED simulateInstallPackages(const QList<QSharedPointer<Package> >& packages);
+	Transaction* Q_DECL_DEPRECATED simulateInstallPackages(QSharedPointer<Package> package);
 
 	/**
+     * DEPRECATED
 	 * \brief Simulates a removal of \p packages.
 	 *
 	 * You should call this method before removing \p packages
 	 * \note: This method might emit packages with INSTALLING, REMOVING, UPDATING,
 	 *        REINSTALLING or OBSOLETING status.
 	 */
-	Transaction* simulateRemovePackages(const QList<Package*>& packages);
-	Transaction* simulateRemovePackage(Package* package);
+	Transaction* Q_DECL_DEPRECATED simulateRemovePackages(const QList<QSharedPointer<Package> >& packages, bool autoremove);
+	Transaction* Q_DECL_DEPRECATED simulateRemovePackages(QSharedPointer<Package> package, bool autoremove);
 
 	/**
+     * DEPRECATED
 	 * \brief Simulates an update of \p packages.
 	 *
 	 * You should call this method before updating \p packages
 	 * \note: This method might emit packages with INSTALLING, REMOVING, UPDATING,
 	 *        REINSTALLING or OBSOLETING status.
 	 */
-	Transaction* simulateUpdatePackages(const QList<Package*>& packages);
-	Transaction* simulateUpdatePackage(Package* package);
+	Transaction* Q_DECL_DEPRECATED simulateUpdatePackages(const QList<QSharedPointer<Package> >& packages);
+	Transaction* Q_DECL_DEPRECATED simulateUpdatePackages(QSharedPointer<Package> package);
 
 	/**
+     * DEPRECATED
 	 * Update the given \p packages
 	 */
-	Transaction* updatePackages(bool only_trusted, const QList<Package*>& packages);
-	Transaction* updatePackage(bool only_trusted, Package* package);
+	Transaction* Q_DECL_DEPRECATED updatePackages(bool only_trusted, const QList<QSharedPointer<Package> >& packages);
+	Transaction* Q_DECL_DEPRECATED updatePackages(bool only_trusted, QSharedPointer<Package> package);
 
 	/**
+     * DEPRECATED
 	 * Updates the whole system
 	 *
 	 * \p only_trusted indicates if this transaction is only allowed to install trusted packages
 	 */
-	Transaction* updateSystem(bool only_trusted);
+	Transaction* Q_DECL_DEPRECATED updateSystem(bool only_trusted);
 
 	/**
+     * DEPRECATED
 	 * Searchs for a package providing a file/a mimetype
 	 */
-	Transaction* whatProvides(ProvidesType type, const QString& search, Filters filters = NoFilter);
-	Transaction* whatProvides(ProvidesType type, const QStringList& search, Filters filters = NoFilter);
+	Transaction* Q_DECL_DEPRECATED whatProvides(Enum::Provides type, const QStringList& search, Enum::Filters filters = Enum::NoFilter);
+	Transaction* Q_DECL_DEPRECATED whatProvides(Enum::Provides type, const QString& search, Enum::Filters filters = Enum::NoFilter);
 
 Q_SIGNALS:
 	/**
@@ -884,18 +608,6 @@ Q_SIGNALS:
 	 */
 	void error(PackageKit::Client::DaemonError e);
 
-	/**
-	 * Emitted when the daemon's locked state changes
-	 * This signal is DEPRECATED use \sa changed() and \sa locked() instead.
-	 */
-	void locked(bool locked);
-
-	/**
-	 * Emitted when the network state changes
-	 * This signal is DEPRECATED use \sa changed() and \sa networkState() instead.
-	 */
-	void networkStateChanged(PackageKit::Client::NetworkState state);
-
 	/**
 	 * Emitted when the list of repositories changes
 	 */
@@ -918,16 +630,31 @@ Q_SIGNALS:
 	 */
 	void updatesChanged();
 
+protected:
+    /**
+     * \brief creates a new transaction path
+     * This function register a new DBus path on PackageKit
+     * allowing a \c Transaction object to be created,
+     * unless you want to know the transaction id
+     * before creating the \c Transaction this function
+     * is not useful since passing a NULL string (QString())
+     * when contructing the \c Transaction object will
+     * automatically create this path.
+     */
+    QString getTid() const;
+	ClientPrivate * const d_ptr;
+
 private:
+	Q_DECLARE_PRIVATE(Client);
 	Client(QObject* parent = 0);
 	static Client* m_instance;
-	friend class ClientPrivate;
-	ClientPrivate* d;
+	friend class TransactionPrivate;
+    friend class Transaction;
 
-	void setLastError (DaemonError e);
-	void setTransactionError (Transaction* t, DaemonError e);
+	void setLastError(DaemonError e);
+
+	void destroyTransaction(const QString &tid);
 };
-Q_DECLARE_OPERATORS_FOR_FLAGS(Client::Filters)
 
 } // End namespace PackageKit
 
