@@ -15,7 +15,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 # Copyright (C) 2007 Tim Lauridsen <timlau@fedoraproject.org>
-
+# Copyright (C) 2007-2010 Richard Hughes <richard@hughsie.com>
 #
 # This file contain the base classes to implement a PackageKit python backend
 #
@@ -57,6 +57,7 @@ class PackageKitBaseBackend:
         self.has_network = False
         self.background = False
         self.interactive = False
+        self.cache_age = 0
         self.percentage_old = 0
         self.sub_percentage_old = 0
 
@@ -87,6 +88,12 @@ class PackageKitBaseBackend:
         except KeyError, e:
             print "Error: No INTERACTIVE envp"
 
+        # try to get CACHE_AGE state
+        try:
+            self.cache_age = int(os.environ['CACHE_AGE'])
+        except KeyError, e:
+            pass
+
     def doLock(self):
         ''' Generic locking, overide and extend in child class'''
         self._locked = True
@@ -389,6 +396,13 @@ class PackageKitBaseBackend:
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
+    def upgrade_system(self, distro_id):
+        '''
+        Implement the {backend}-update-system functionality
+        Needed to be implemented in a sub class
+        '''
+        self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
+
     def refresh_cache(self, force):
         '''
         Implement the {backend}-refresh_cache functionality
@@ -713,6 +727,9 @@ class PackageKitBaseBackend:
             package_ids = args[0].split(PACKAGE_IDS_DELIM)
             self.simulate_update_packages(package_ids)
             self.finished()
+        elif cmd == 'upgrade-system':
+            self.upgrade_system(args[0])
+            self.finished()
         else:
             errmsg = "command '%s' is not known" % cmd
             self.error(ERROR_INTERNAL_ERROR, errmsg, exit=False)
