@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2007-2008 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2007-2010 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -23,6 +23,7 @@
 #define __PK_BACKEND_H
 
 #include <glib.h>
+#include <glib-object.h>
 #include <gmodule.h>
 
 /* these include the includes the backends should be using */
@@ -31,12 +32,35 @@
 #include <packagekit-glib2/pk-bitfield.h>
 #include <packagekit-glib2/pk-package-id.h>
 #include <packagekit-glib2/pk-package-ids.h>
+#include <packagekit-glib2/pk-bitfield.h>
+
+#include "pk-store.h"
+#include "pk-backend.h"
 
-#include "egg-debug.h"
 #include "egg-string.h"
 
 G_BEGIN_DECLS
 
+#define PK_TYPE_BACKEND		(pk_backend_get_type ())
+#define PK_BACKEND(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), PK_TYPE_BACKEND, PkBackend))
+#define PK_BACKEND_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), PK_TYPE_BACKEND, PkBackendClass))
+#define PK_IS_BACKEND(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), PK_TYPE_BACKEND))
+#define PK_IS_BACKEND_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), PK_TYPE_BACKEND))
+#define PK_BACKEND_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), PK_TYPE_BACKEND, PkBackendClass))
+
+typedef struct PkBackendPrivate PkBackendPrivate;
+
+typedef struct
+{
+	 GObject		 parent;
+	 PkBackendPrivate	*priv;
+} PkBackend;
+
+typedef struct
+{
+	GObjectClass		 parent_class;
+} PkBackendClass;
+
 /**
  * PK_BACKEND_PERCENTAGE_INVALID:
  *
@@ -44,7 +68,130 @@ G_BEGIN_DECLS
  */
 #define PK_BACKEND_PERCENTAGE_INVALID		101
 
-typedef struct _PkBackend PkBackend;
+GType		 pk_backend_get_type			(void);
+PkBackend	*pk_backend_new				(void);
+gboolean	 pk_backend_lock			(PkBackend	*backend)
+							 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 pk_backend_unlock			(PkBackend	*backend)
+							 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 pk_backend_reset			(PkBackend	*backend);
+gboolean	 pk_backend_set_name			(PkBackend	*backend,
+							 const gchar	*name,
+							 GError		**error)
+							 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 pk_backend_set_proxy			(PkBackend	*backend,
+							 const gchar	*proxy_http,
+							 const gchar	*proxy_ftp);
+gboolean	 pk_backend_set_root			(PkBackend	*backend,
+							 const gchar	*root);
+gchar		*pk_backend_get_name			(PkBackend	*backend)
+							 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 pk_backend_get_is_finished		(PkBackend	*backend);
+
+gchar		*pk_backend_get_description		(PkBackend	*backend)
+							 G_GNUC_WARN_UNUSED_RESULT;
+gchar		*pk_backend_get_author			(PkBackend	*backend)
+							 G_GNUC_WARN_UNUSED_RESULT;
+typedef gchar	*(*PkBackendGetCompatStringFunc)	(PkBackend	*backend);
+PkBitfield	 pk_backend_get_groups			(PkBackend	*backend);
+PkBitfield	 pk_backend_get_filters			(PkBackend	*backend);
+PkBitfield	 pk_backend_get_roles			(PkBackend	*backend);
+gchar		*pk_backend_get_mime_types		(PkBackend	*backend);
+gboolean	 pk_backend_has_set_error_code		(PkBackend	*backend);
+gboolean	 pk_backend_is_implemented		(PkBackend	*backend,
+							 PkRoleEnum	 role);
+gchar		*pk_backend_get_accepted_eula_string	(PkBackend	*backend);
+void		pk_backend_cancel			(PkBackend	*backend);
+void		pk_backend_download_packages		(PkBackend	*backend,
+							 gchar		**package_ids,
+							 const gchar	*directory);
+void		pk_backend_initialize			(PkBackend	*backend);
+void		pk_backend_destroy			(PkBackend	*backend);
+void		pk_backend_transaction_start		(PkBackend	*backend);
+void		pk_backend_transaction_stop		(PkBackend	*backend);
+void		pk_backend_get_categories		(PkBackend	*backend);
+void		pk_backend_get_depends			(PkBackend	*backend,
+							 PkBitfield	 filters,
+							 gchar		**package_ids,
+							 gboolean	 recursive);
+void		pk_backend_get_details			(PkBackend	*backend,
+							 gchar		**package_ids);
+void		pk_backend_get_distro_upgrades		(PkBackend	*backend);
+void		pk_backend_get_files			(PkBackend	*backend,
+							 gchar		**package_ids);
+void		pk_backend_get_requires			(PkBackend	*backend,
+							 PkBitfield	 filters,
+							 gchar		**package_ids,
+							 gboolean	 recursive);
+void		pk_backend_get_update_detail		(PkBackend	*backend,
+							 gchar		**package_ids);
+void		pk_backend_get_updates			(PkBackend	*backend,
+							 PkBitfield	 filters);
+void		pk_backend_install_packages		(PkBackend	*backend,
+							 gboolean	 only_trusted,
+							 gchar		**package_ids);
+void		pk_backend_install_signature		(PkBackend	*backend,
+							 PkSigTypeEnum	 type,
+							 const gchar	*key_id,
+							 const gchar	*package_id);
+void		pk_backend_install_files		(PkBackend	*backend,
+							 gboolean	 only_trusted,
+							 gchar		**full_paths);
+void		pk_backend_refresh_cache		(PkBackend	*backend,
+							 gboolean	 force);
+void		pk_backend_remove_packages		(PkBackend	*backend,
+							 gchar		**package_ids,
+							 gboolean	 allow_deps,
+							 gboolean	 autoremove);
+void		pk_backend_resolve			(PkBackend	*backend,
+							 PkBitfield	 filters,
+							 gchar		**packages);
+void		pk_backend_rollback			(PkBackend	*backend,
+							 const gchar	*transaction_id);
+void		pk_backend_search_details		(PkBackend	*backend,
+							 PkBitfield	 filters,
+							 gchar		**search);
+void		pk_backend_search_files			(PkBackend	*backend,
+							 PkBitfield	 filters,
+							 gchar		**search);
+void		pk_backend_search_groups		(PkBackend	*backend,
+							 PkBitfield	 filters,
+							 gchar		**search);
+void		pk_backend_search_names			(PkBackend	*backend,
+							 PkBitfield	 filters,
+							 gchar		**search);
+void		pk_backend_update_packages		(PkBackend	*backend,
+							 gboolean	 only_trusted,
+							 gchar		**package_ids);
+void		pk_backend_update_system		(PkBackend	*backend,
+							 gboolean	 only_trusted);
+void		pk_backend_get_repo_list		(PkBackend	*backend,
+							 PkBitfield	 filters);
+void		pk_backend_repo_enable			(PkBackend	*backend,
+							 const gchar	*repo_id,
+							 gboolean	 enabled);
+void		pk_backend_repo_set_data		(PkBackend	*backend,
+							 const gchar	*repo_id,
+							 const gchar	*parameter,
+							 const gchar	*value);
+void		pk_backend_what_provides		(PkBackend	*backend,
+							 PkBitfield	 filters,
+							 PkProvidesEnum provides,
+							 gchar		**search);
+void		pk_backend_get_packages			(PkBackend	*backend,
+							 PkBitfield	 filters);
+void		pk_backend_simulate_install_files	(PkBackend	*backend,
+							 gchar		**full_paths);
+void		pk_backend_simulate_install_packages	(PkBackend	*backend,
+							 gchar		**package_ids);
+void		pk_backend_simulate_remove_packages	(PkBackend	*backend,
+							 gchar		**package_ids,
+							 gboolean	 autoremove);
+void		pk_backend_simulate_update_packages	(PkBackend	*backend,
+							 gchar		**package_ids);
+void		pk_backend_upgrade_system		(PkBackend	*backend,
+							 const gchar	*distro_id,
+							 PkUpgradeKindEnum upgrade_kind);
 
 /* set the state */
 gboolean	 pk_backend_accept_eula			(PkBackend	*backend,
@@ -74,6 +221,8 @@ gboolean	 pk_backend_set_locale			(PkBackend	*backend,
 							 const gchar	*code);
 gboolean	 pk_backend_set_frontend_socket		(PkBackend	*backend,
 							 const gchar	*frontend_socket);
+void		 pk_backend_set_cache_age		(PkBackend	*backend,
+							 guint		 cache_age);
 
 /* get the state */
 gboolean	 pk_backend_get_allow_cancel		(PkBackend	*backend);
@@ -89,6 +238,7 @@ gchar		*pk_backend_get_proxy_http		(PkBackend	*backend);
 const gchar	*pk_backend_get_root			(PkBackend	*backend);
 gchar		*pk_backend_get_locale			(PkBackend	*backend);
 gchar		*pk_backend_get_frontend_socket		(PkBackend	*backend);
+guint		 pk_backend_get_cache_age		(PkBackend	*backend);
 
 /* signal helpers */
 gboolean	 pk_backend_finished			(PkBackend	*backend);
@@ -312,9 +462,15 @@ typedef struct {
 							 gboolean	 autoremove);
 	void		(*simulate_update_packages)	(PkBackend	*backend,
 							 gchar		**package_ids);
-	gpointer	padding[10];
+	void		(*transaction_start)		(PkBackend	*backend);
+	void		(*transaction_stop)		(PkBackend	*backend);
+	void		(*upgrade_system)		(PkBackend	*backend,
+							 const gchar	*distro_id,
+							 PkUpgradeKindEnum upgrade_kind);
+	gpointer	padding[7];
 } PkBackendDesc;
 
+/* this is deprecated */
 #define PK_BACKEND_OPTIONS(description, author, initialize, destroy, get_groups, get_filters, get_roles, \
 			   get_mime_types, cancel, download_packages, get_categories, get_depends,	\
 			   get_details, get_distro_upgrades, get_files, get_packages, get_repo_list,	\
@@ -323,7 +479,7 @@ typedef struct {
 			   repo_enable, repo_set_data, resolve, rollback, search_details, search_file,	\
 			   search_group, search_name, update_packages, update_system, what_provides,	\
 			   simulate_install_files, simulate_install_packages, simulate_remove_packages,	\
-			   simulate_update_packages )							\
+			   simulate_update_packages, upgrade_system, transaction_start, transaction_stop ) \
 	G_MODULE_EXPORT const PkBackendDesc pk_backend_desc = { 					\
 		description,			\
 		author,				\
@@ -365,6 +521,9 @@ typedef struct {
 		simulate_install_packages,	\
 		simulate_remove_packages,	\
 		simulate_update_packages,	\
+		upgrade_system,			\
+		transaction_start,		\
+		transaction_stop,		\
 		{0} 				\
 	}
 
