@@ -29,8 +29,6 @@
 
 #include "pk-dbus.h"
 
-#include "egg-debug.h"
-
 #define PK_DBUS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_DBUS, PkDbusPrivate))
 
 struct PkDbusPrivate
@@ -63,11 +61,18 @@ pk_dbus_get_uid (PkDbus *dbus, const gchar *sender)
 	g_return_val_if_fail (PK_IS_DBUS (dbus), G_MAXUINT);
 	g_return_val_if_fail (sender != NULL, G_MAXUINT);
 
+	/* set in the test suite */
+	if (g_strcmp0 (sender, ":org.freedesktop.PackageKit") == 0) {
+		g_debug ("using self-check shortcut");
+		uid = 500;
+		goto out;
+	}
+
 	dbus_error_init (&error);
 	con = dbus_g_connection_get_connection (dbus->priv->connection);
 	uid = dbus_bus_get_unix_user (con, sender, &error);
 	if (dbus_error_is_set (&error)) {
-		egg_warning ("Could not get uid for connection: %s %s", error.name, error.message);
+		g_warning ("Could not get uid for connection: %s %s", error.name, error.message);
 		uid = G_MAXUINT;
 		goto out;
 	}
@@ -94,6 +99,13 @@ pk_dbus_get_pid (PkDbus *dbus, const gchar *sender)
 	g_return_val_if_fail (PK_IS_DBUS (dbus), G_MAXUINT);
 	g_return_val_if_fail (sender != NULL, G_MAXUINT);
 
+	/* set in the test suite */
+	if (g_strcmp0 (sender, ":org.freedesktop.PackageKit") == 0) {
+		g_debug ("using self-check shortcut");
+		pid = G_MAXUINT - 1;
+		goto out;
+	}
+
 	/* no connection to DBus */
 	if (dbus->priv->proxy_pid == NULL)
 		goto out;
@@ -106,7 +118,7 @@ pk_dbus_get_pid (PkDbus *dbus, const gchar *sender)
 				 G_TYPE_UINT, &pid,
 				 G_TYPE_INVALID);
 	if (!ret) {
-		egg_warning ("failed to get pid: %s", error->message);
+		g_warning ("failed to get pid: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -135,10 +147,17 @@ pk_dbus_get_cmdline (PkDbus *dbus, const gchar *sender)
 	g_return_val_if_fail (PK_IS_DBUS (dbus), NULL);
 	g_return_val_if_fail (sender != NULL, NULL);
 
+	/* set in the test suite */
+	if (g_strcmp0 (sender, ":org.freedesktop.PackageKit") == 0) {
+		g_debug ("using self-check shortcut");
+		cmdline = g_strdup ("/usr/sbin/packagekit");
+		goto out;
+	}
+
 	/* get pid */
 	pid = pk_dbus_get_pid (dbus, sender);
 	if (pid == G_MAXUINT) {
-		egg_warning ("failed to get PID");
+		g_warning ("failed to get PID");
 		goto out;
 	}
 
@@ -146,7 +165,7 @@ pk_dbus_get_cmdline (PkDbus *dbus, const gchar *sender)
 	filename = g_strdup_printf ("/proc/%i/cmdline", pid);
 	ret = g_file_get_contents (filename, &cmdline, NULL, &error);
 	if (!ret) {
-		egg_warning ("failed to get cmdline: %s", error->message);
+		g_warning ("failed to get cmdline: %s", error->message);
 		g_error_free (error);
 	}
 out:
@@ -174,16 +193,23 @@ pk_dbus_get_session (PkDbus *dbus, const gchar *sender)
 	g_return_val_if_fail (PK_IS_DBUS (dbus), NULL);
 	g_return_val_if_fail (sender != NULL, NULL);
 
+	/* set in the test suite */
+	if (g_strcmp0 (sender, ":org.freedesktop.PackageKit") == 0) {
+		g_debug ("using self-check shortcut");
+		session = g_strdup ("xxx");
+		goto out;
+	}
+
 	/* no ConsoleKit? */
 	if (dbus->priv->proxy_session == NULL) {
-		egg_warning ("no ConsoleKit, so cannot get session");
+		g_warning ("no ConsoleKit, so cannot get session");
 		goto out;
 	}
 
 	/* get pid */
 	pid = pk_dbus_get_pid (dbus, sender);
 	if (pid == G_MAXUINT) {
-		egg_warning ("failed to get PID");
+		g_warning ("failed to get PID");
 		goto out;
 	}
 
@@ -195,7 +221,7 @@ pk_dbus_get_session (PkDbus *dbus, const gchar *sender)
 				 DBUS_TYPE_G_OBJECT_PATH, &session,
 				 G_TYPE_INVALID);
 	if (!ret) {
-		egg_warning ("failed to get session for %i: %s", pid, error->message);
+		g_warning ("failed to get session for %i: %s", pid, error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -258,7 +284,7 @@ pk_dbus_init (PkDbus *dbus)
 						 "/org/freedesktop/DBus/Bus",
 						 "org.freedesktop.DBus", &error);
 	if (dbus->priv->proxy_pid == NULL) {
-		egg_warning ("cannot connect to DBus: %s", error->message);
+		g_warning ("cannot connect to DBus: %s", error->message);
 		g_error_free (error);
 	}
 
@@ -269,7 +295,7 @@ pk_dbus_init (PkDbus *dbus)
 						 "/org/freedesktop/ConsoleKit/Manager",
 						 "org.freedesktop.ConsoleKit.Manager", &error);
 	if (dbus->priv->proxy_session == NULL) {
-		egg_warning ("cannot connect to DBus: %s", error->message);
+		g_warning ("cannot connect to DBus: %s", error->message);
 		g_error_free (error);
 	}
 }
