@@ -59,6 +59,7 @@ typedef enum
 	PK_ENGINE_ERROR_INVALID_STATE,
 	PK_ENGINE_ERROR_REFUSED_BY_POLICY,
 	PK_ENGINE_ERROR_CANNOT_SET_PROXY,
+	PK_ENGINE_ERROR_CANNOT_SET_ROOT,
 	PK_ENGINE_ERROR_NOT_SUPPORTED,
 	PK_ENGINE_ERROR_CANNOT_ALLOCATE_TID,
 	PK_ENGINE_ERROR_CANNOT_CHECK_AUTH,
@@ -75,27 +76,8 @@ PkEngine	*pk_engine_new				(void);
 guint		 pk_engine_get_seconds_idle		(PkEngine	*engine);
 
 /* dbus methods */
-gboolean	 pk_engine_get_actions			(PkEngine	*engine,
-							 gchar		**roles,
-							 GError		**error);
-gboolean	 pk_engine_get_backend_detail		(PkEngine	*engine,
-							 gchar		**name,
-							 gchar		**author,
-							 GError		**error);
-gboolean	 pk_engine_get_filters			(PkEngine	*engine,
-							 gchar		**filters,
-							 GError		**error);
-gboolean	 pk_engine_get_groups			(PkEngine	*engine,
-							 gchar		**groups,
-							 GError		**error);
-gboolean	 pk_engine_get_mime_types		(PkEngine	*engine,
-							 gchar		**types,
-							 GError		**error);
 void		 pk_engine_get_tid			(PkEngine	*engine,
 							 DBusGMethodInvocation *context);
-gboolean	 pk_engine_get_network_state		(PkEngine	*engine,
-							 gchar		**state,
-							 GError		**error);
 gboolean	 pk_engine_get_daemon_state		(PkEngine	*engine,
 							 gchar		**state,
 							 GError		**error);
@@ -115,6 +97,9 @@ void		 pk_engine_set_proxy			(PkEngine	*engine,
 							 const gchar	*proxy_http,
 							 const gchar	*proxy_ftp,
 							 DBusGMethodInvocation *context);
+void		 pk_engine_set_root			(PkEngine	*engine,
+							 const gchar	*root,
+							 DBusGMethodInvocation *context);
 void		 pk_engine_can_authorize		(PkEngine	*engine,
 							 const gchar	*action_id,
 							 DBusGMethodInvocation *context);
