@@ -27,7 +27,6 @@
 #include <stdlib.h>
 #include <glib.h>
 
-#include "egg-debug.h"
 #include "egg-string.h"
 
 #include "pk-lsof.h"
@@ -142,6 +141,8 @@ pk_lsof_refresh (PkLsof *lsof)
 	GError *error = NULL;
 	gchar *stdout = NULL;
 	gchar *stderr = NULL;
+	const gchar *lsof_name;
+	gchar *lsof_cmd = NULL;
 	PkLsofData *data;
 	gchar **lines = NULL;
 	guint i;
@@ -152,10 +153,23 @@ pk_lsof_refresh (PkLsof *lsof)
 
 	g_return_val_if_fail (PK_IS_LSOF (lsof), FALSE);
 
-	/* run lsof to get all data */
-	ret = g_spawn_command_line_sync ("/usr/sbin/lsof -Fpfn", &stdout, &stderr, NULL, &error);
+	/* try to find lsof */
+	lsof_name = "/usr/sbin/lsof";
+	ret = g_file_test (lsof_name, G_FILE_TEST_EXISTS);
 	if (!ret) {
-		egg_warning ("failed to get pids: %s", error->message);
+		lsof_name = "/usr/bin/lsof";
+		ret = g_file_test (lsof_name, G_FILE_TEST_EXISTS);
+		if (!ret) {
+			g_warning ("lsof not found, cannot continue");
+			goto out;
+		}
+	}
+
+	/* run lsof to get all data */
+	lsof_cmd = g_strconcat (lsof_name, " ", "-Fpfn", NULL);
+	ret = g_spawn_command_line_sync (lsof_cmd, &stdout, &stderr, NULL, &error);
+	if (!ret) {
+		g_warning ("failed to get pids: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -179,7 +193,7 @@ pk_lsof_refresh (PkLsof *lsof)
 			/* parse PID */
 			ret = egg_strtoint (value, &pid);
 			if (!ret) {
-				egg_warning ("failed to parse pid: '%s'", value);
+				g_warning ("failed to parse pid: '%s'", value);
 				pid = -1;
 				goto out;
 			}
@@ -209,13 +223,14 @@ pk_lsof_refresh (PkLsof *lsof)
 			}
 			break;
 		default:
-			egg_debug ("ignoring %c=%s (type=%s)", mode, value, pk_lsof_type_to_string (type));
+			g_debug ("ignoring %c=%s (type=%s)", mode, value, pk_lsof_type_to_string (type));
 			break;
 		}
 	}
 	ret = TRUE;
 out:
 	g_strfreev (lines);
+	g_free (lsof_cmd);
 	g_free (stdout);
 	g_free (stderr);
 	return ret;
@@ -241,7 +256,7 @@ pk_lsof_get_pids_for_filenames (PkLsof *lsof, gchar **filenames)
 	if (list_data->len == 0) {
 		ret = pk_lsof_refresh (lsof);
 		if (!ret) {
-			egg_warning ("failed to refresh");
+			g_warning ("failed to refresh");
 			goto out;
 		}
 	}
@@ -251,7 +266,7 @@ pk_lsof_get_pids_for_filenames (PkLsof *lsof, gchar **filenames)
 	for (i=0; filenames[i] != NULL; i++) {
 		for (j=0; j < list_data->len; j++) {
 			data = g_ptr_array_index (list_data, j);
-			egg_debug ("got %s", data->filename);
+			g_debug ("got %s", data->filename);
 			if (g_strcmp0 (filenames[i], data->filename) == 0) {
 				pk_lsof_add_pid (pids, data->pid);
 			}
