@@ -33,7 +33,6 @@
 #include <glib.h>
 #include <dbus/dbus-glib.h>
 
-#include "egg-debug.h"
 #include "pk-notify.h"
 #include "pk-marshal.h"
 
@@ -64,7 +63,7 @@ pk_notify_repo_list_changed (PkNotify *notify)
 {
 	g_return_val_if_fail (PK_IS_NOTIFY (notify), FALSE);
 
-	egg_debug ("emitting repo-list-changed");
+	g_debug ("emitting repo-list-changed");
 	g_signal_emit (notify, signals [PK_NOTIFY_REPO_LIST_CHANGED], 0);
 	return TRUE;
 }
@@ -77,7 +76,7 @@ pk_notify_updates_changed (PkNotify *notify)
 {
 	g_return_val_if_fail (PK_IS_NOTIFY (notify), FALSE);
 
-	egg_debug ("emitting updates-changed");
+	g_debug ("emitting updates-changed");
 	g_signal_emit (notify, signals [PK_NOTIFY_UPDATES_CHANGED], 0);
 	return TRUE;
 }
@@ -94,7 +93,6 @@ pk_notify_finished_updates_changed_cb (gpointer data)
 	return FALSE;
 }
 
-
 /**
  * pk_notify_wait_updates_changed:
  **/
@@ -105,7 +103,7 @@ pk_notify_wait_updates_changed (PkNotify *notify, guint timeout)
 
 	/* check if we did this more than once */
 	if (notify->priv->timeout_id != 0) {
-		egg_warning ("already scheduled");
+		g_warning ("already scheduled");
 		return FALSE;
 	}
 
