@@ -26,7 +26,6 @@
 #include <glib/gstdio.h>
 
 #include "pk-backend.h"
-#include "pk-backend-internal.h"
 #include "pk-backend-spawn.h"
 #include "pk-cache.h"
 #include "pk-conf.h"
@@ -120,7 +119,7 @@ static guint number_packages = 0;
 static void
 pk_test_backend_message_cb (PkBackend *backend, PkMessageEnum message, const gchar *details, gpointer data)
 {
-	egg_debug ("details=%s", details);
+	g_debug ("details=%s", details);
 	number_messages++;
 }
 
@@ -166,7 +165,7 @@ pk_test_backend_func_immediate_false (PkBackend *backend)
 static void
 pk_test_backend_package_cb (PkBackend *backend, PkPackage *package, gpointer user_data)
 {
-	egg_debug ("package:%s", pk_package_get_id (package));
+	g_debug ("package:%s", pk_package_get_id (package));
 	number_packages++;
 }
 
@@ -229,15 +228,15 @@ pk_test_backend_func (void)
 	g_assert (!ret);
 
 	/* load an invalid backend */
-	ret = pk_backend_set_name (backend, "invalid");
+	ret = pk_backend_set_name (backend, "invalid", NULL);
 	g_assert (!ret);
 
 	/* try to load a valid backend */
-	ret = pk_backend_set_name (backend, "dummy");
+	ret = pk_backend_set_name (backend, "dummy", NULL);
 	g_assert (ret);
 
 	/* load an valid backend again */
-	ret = pk_backend_set_name (backend, "dummy");
+	ret = pk_backend_set_name (backend, "dummy", NULL);
 	g_assert (!ret);
 
 	/* lock an valid backend */
@@ -388,65 +387,65 @@ pk_test_backend_spawn_func (void)
 	g_assert_cmpstr (text, ==, "test_spawn");
 
 	/* needed to avoid an error */
-	ret = pk_backend_set_name (backend, "test_spawn");
+	ret = pk_backend_set_name (backend, "test_spawn", NULL);
 	g_assert (ret);
 	ret = pk_backend_lock (backend);
 	g_assert (ret);
 
 	/* test pk_backend_spawn_inject_data Percentage1 */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "percentage\t0");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "percentage\t0", NULL);
 	g_assert (ret);
 
 	/* test pk_backend_spawn_inject_data Percentage2 */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "percentage\tbrian");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "percentage\tbrian", NULL);
 	g_assert (!ret);
 
 	/* test pk_backend_spawn_inject_data Percentage3 */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "percentage\t12345");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "percentage\t12345", NULL);
 	g_assert (!ret);
 
 	/* test pk_backend_spawn_inject_data Percentage4 */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "percentage\t");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "percentage\t", NULL);
 	g_assert (!ret);
 
 	/* test pk_backend_spawn_inject_data Percentage5 */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "percentage");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "percentage", NULL);
 	g_assert (!ret);
 
 	/* test pk_backend_spawn_inject_data Subpercentage */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "subpercentage\t17");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "subpercentage\t17", NULL);
 	g_assert (ret);
 
 	/* test pk_backend_spawn_inject_data NoPercentageUpdates");
-	ret = pk_backend_spawn_inject_data (backend_spawn, "no-percentage-updates");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "no-percentage-updates", NULL);
 	g_assert (ret);
 
 	/* test pk_backend_spawn_inject_data failure */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "error\tnot-present-woohoo\tdescription text");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "error\tnot-present-woohoo\tdescription text", NULL);
 	g_assert (!ret);
 
 	/* test pk_backend_spawn_inject_data Status */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "status\tquery");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "status\tquery", NULL);
 	g_assert (ret);
 
 	/* test pk_backend_spawn_inject_data RequireRestart */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "requirerestart\tsystem\tgnome-power-manager;0.0.1;i386;data");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "requirerestart\tsystem\tgnome-power-manager;0.0.1;i386;data", NULL);
 	g_assert (ret);
 
 	/* test pk_backend_spawn_inject_data RequireRestart invalid enum */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "requirerestart\tmooville\tgnome-power-manager;0.0.1;i386;data");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "requirerestart\tmooville\tgnome-power-manager;0.0.1;i386;data", NULL);
 	g_assert (!ret);
 
 	/* test pk_backend_spawn_inject_data RequireRestart invalid PackageId */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "requirerestart\tsystem\tdetails about the restart");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "requirerestart\tsystem\tdetails about the restart", NULL);
 	g_assert (!ret);
 
 	/* test pk_backend_spawn_inject_data AllowUpdate1 */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "allow-cancel\ttrue");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "allow-cancel\ttrue", NULL);
 	g_assert (ret);
 
 	/* test pk_backend_spawn_inject_data AllowUpdate2 */
-	ret = pk_backend_spawn_inject_data (backend_spawn, "allow-cancel\tbrian");
+	ret = pk_backend_spawn_inject_data (backend_spawn, "allow-cancel\tbrian", NULL);
 	g_assert (!ret);
 
 	/* convert proxy uri (bare) */
@@ -466,7 +465,7 @@ pk_test_backend_spawn_func (void)
 
 	/* test pk_backend_spawn_parse_common_out Package */
 	ret = pk_backend_spawn_inject_data (backend_spawn,
-		"package\tinstalled\tgnome-power-manager;0.0.1;i386;data\tMore useless software");
+		"package\tinstalled\tgnome-power-manager;0.0.1;i386;data\tMore useless software", NULL);
 	g_assert (ret);
 
 	/* manually unlock as we have no engine */
@@ -673,7 +672,7 @@ pk_test_engine_func (void)
 
 	/* set the type, as we have no pk-main doing this for us */
 	/* set the backend name */
-	ret = pk_backend_set_name (backend, "dummy");
+	ret = pk_backend_set_name (backend, "dummy", NULL);
 	g_assert (ret);
 
 	/* get an engine instance */
@@ -879,7 +878,7 @@ guint finished_count = 0;
 static void
 pk_test_exit_cb (PkSpawn *spawn, PkSpawnExitType exit, gpointer user_data)
 {
-	egg_debug ("spawn exit=%i", exit);
+	g_debug ("spawn exit=%i", exit);
 	mexit = exit;
 	finished_count++;
 	_g_test_loop_quit ();
@@ -891,7 +890,7 @@ pk_test_exit_cb (PkSpawn *spawn, PkSpawnExitType exit, gpointer user_data)
 static void
 pk_test_stdout_cb (PkSpawn *spawn, const gchar *line, gpointer user_data)
 {
-	egg_debug ("stdout '%s'", line);
+	g_debug ("stdout '%s'", line);
 	stdout_count++;
 }
 
@@ -1352,7 +1351,7 @@ pk_test_transaction_db_func (void)
 	ret = g_file_test (PK_TRANSACTION_DB_FILE, G_FILE_TEST_EXISTS);
 	if (ret) {
 		/* remove old local database */
-		egg_warning ("Removing %s", PK_TRANSACTION_DB_FILE);
+		g_debug ("Removing %s", PK_TRANSACTION_DB_FILE);
 		value = g_unlink (PK_TRANSACTION_DB_FILE);
 		g_assert (value == 0);
 	}
@@ -1490,7 +1489,7 @@ pk_test_transaction_list_create_transaction (PkTransactionList *tlist)
 	tid = pk_transaction_db_generate_id (db);
 
 	/* create PkTransaction instance */
-	pk_transaction_list_create (tlist, tid, ":0", NULL);
+	pk_transaction_list_create (tlist, tid, ":org.freedesktop.PackageKit", NULL);
 
 	return tid;
 }
@@ -1508,14 +1507,13 @@ pk_test_transaction_list_func (void)
 	gchar *tid_item1;
 	gchar *tid_item2;
 	gchar *tid_item3;
-	gboolean running, committed, finished;
 
 	/* remove the self check file */
 #if PK_BUILD_LOCAL
 	ret = g_file_test ("./transactions.db", G_FILE_TEST_EXISTS);
 	if (ret) {
 		/* remove old local database */
-		egg_warning ("Removing %s", "./transactions.db");
+		g_debug ("Removing %s", "./transactions.db");
 		size = g_unlink ("./transactions.db");
 		g_assert (size == 0);
 	}
@@ -1534,15 +1532,13 @@ pk_test_transaction_list_func (void)
 	g_assert (tid != NULL);
 
 	/* create a transaction object */
-	ret = pk_transaction_list_create (tlist, tid, ":0", NULL);
+	ret = pk_transaction_list_create (tlist, tid, ":org.freedesktop.PackageKit", NULL);
 	g_assert (ret);
 
 	/* make sure we get the right object back */
-	transaction = pk_transaction_list_get_transaction (tlist, tid, &running, &committed, &finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid);
 	g_assert (transaction != NULL);
-	g_assert (!running);
-	g_assert (!committed);
-	g_assert (!finished);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_NEW);
 
 	/* get size one we have in queue */
 	size = pk_transaction_list_get_size (tlist);
@@ -1555,7 +1551,7 @@ pk_test_transaction_list_func (void)
 	g_strfreev (array);
 
 	/* add again the same tid (should fail) */
-	ret = pk_transaction_list_create (tlist, tid, ":0", NULL);
+	ret = pk_transaction_list_create (tlist, tid, ":org.freedesktop.PackageKit", NULL);
 	g_assert (!ret);
 
 	/* remove without ever committing */
@@ -1571,13 +1567,13 @@ pk_test_transaction_list_func (void)
 	tid = pk_transaction_db_generate_id (db);
 
 	/* create another transaction */
-	ret = pk_transaction_list_create (tlist, tid, ":0", NULL);
+	ret = pk_transaction_list_create (tlist, tid, ":org.freedesktop.PackageKit", NULL);
 	g_assert (ret);
 
 	PkBackend *backend;
 	backend = pk_backend_new ();
 	/* try to load a valid backend */
-	ret = pk_backend_set_name (backend, "dummy");
+	ret = pk_backend_set_name (backend, "dummy", NULL);
 	g_assert (ret);
 
 	/* lock an valid backend */
@@ -1585,7 +1581,7 @@ pk_test_transaction_list_func (void)
 	g_assert (ret);
 
 	/* get from db */
-	transaction = pk_transaction_list_get_transaction (tlist, tid, NULL, NULL, NULL);
+	transaction = pk_transaction_list_get_transaction (tlist, tid);
 	g_assert (transaction != NULL);
 	g_signal_connect (transaction, "finished",
 			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
@@ -1594,10 +1590,8 @@ pk_test_transaction_list_func (void)
 	pk_transaction_get_updates (transaction, "none", NULL);
 
 	/* make sure transaction has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid, &running, &committed, &finished);
-	g_assert (running);
-	g_assert (committed);
-	g_assert (!finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_RUNNING);
 
 	/* get present role */
 	ret = pk_transaction_list_role_present (tlist, PK_ROLE_ENUM_GET_UPDATES);
@@ -1644,7 +1638,7 @@ pk_test_transaction_list_func (void)
 	g_free (tid);
 
 	tid = pk_test_transaction_list_create_transaction (tlist);
-	transaction = pk_transaction_list_get_transaction (tlist, tid, NULL, NULL, NULL);
+	transaction = pk_transaction_list_get_transaction (tlist, tid);
 	g_signal_connect (transaction, "finished",
 			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
 
@@ -1654,10 +1648,7 @@ pk_test_transaction_list_func (void)
 	_g_test_loop_run_with_timeout (1000);
 
 	/* make sure transaction has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid, &running, &committed, &finished);
-	g_assert (!running);
-	g_assert (committed);
-	g_assert (finished);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* get transactions (committed, not finished) in progress (none, as cached) */
 	array = pk_transaction_list_get_array (tlist);
@@ -1697,31 +1688,31 @@ pk_test_transaction_list_func (void)
 	g_assert_cmpint (size, ==, 0);
 	g_strfreev (array);
 
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item1, NULL, NULL, NULL);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
 	g_signal_connect (transaction, "finished",
 			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item2, NULL, NULL, NULL);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
 	g_signal_connect (transaction, "finished",
 			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item3, NULL, NULL, NULL);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
 	g_signal_connect (transaction, "finished",
 			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
 
 	/* this starts one action */
 	array = g_strsplit ("dave", " ", -1);
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item1, NULL, NULL, NULL);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
 	pk_transaction_search_details (transaction, "none", array, NULL);
 	g_strfreev (array);
 
 	/* this should be chained after the first action completes */
 	array = g_strsplit ("power", " ", -1);
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item2, NULL, NULL, NULL);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
 	pk_transaction_search_names (transaction, "none", array, NULL);
 	g_strfreev (array);
 
 	/* this starts be chained after the second action completes */
 	array = g_strsplit ("paul", " ", -1);
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item3, NULL, NULL, NULL);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
 	pk_transaction_search_details (transaction, "none", array, NULL);
 	g_strfreev (array);
 
@@ -1745,22 +1736,16 @@ pk_test_transaction_list_func (void)
 	g_strfreev (array);
 
 	/* make sure transaction1 has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid_item1, &running, &committed, &finished);
-	g_assert (!running);
-	g_assert (committed);
-	g_assert (finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction2 has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid_item2, &running, &committed, &finished);
-	g_assert (running);
-	g_assert (committed);
-	g_assert (!finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_RUNNING);
 
 	/* make sure transaction3 has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid_item3, &running, &committed, &finished);
-	g_assert (!running);
-	g_assert (committed);
-	g_assert (!finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_READY);
 
 	/* wait for second action */
 	_g_test_loop_run_with_timeout (10000);
@@ -1776,22 +1761,16 @@ pk_test_transaction_list_func (void)
 	g_strfreev (array);
 
 	/* make sure transaction1 has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid_item1, &running, &committed, &finished);
-	g_assert (!running);
-	g_assert (committed);
-	g_assert (finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction2 has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid_item2, &running, &committed, &finished);
-	g_assert (!running);
-	g_assert (committed);
-	g_assert (finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction3 has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid_item3, &running, &committed, &finished);
-	g_assert (running);
-	g_assert (committed);
-	g_assert (!finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_RUNNING);
 
 	/* wait for third action */
 	_g_test_loop_run_with_timeout (10000);
@@ -1807,29 +1786,23 @@ pk_test_transaction_list_func (void)
 	g_strfreev (array);
 
 	/* make sure transaction1 has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid_item1, &running, &committed, &finished);
-	g_assert (!running);
-	g_assert (committed);
-	g_assert (finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction2 has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid_item2, &running, &committed, &finished);
-	g_assert (!running);
-	g_assert (committed);
-	g_assert (finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction3 has correct flags */
-	pk_transaction_list_get_transaction (tlist, tid_item3, &running, &committed, &finished);
-	g_assert (!running);
-	g_assert (committed);
-	g_assert (finished);
+	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
+	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* wait for Cleanup */
 	_g_test_loop_wait (5000);
 
-	/* get both transactions in queue */
+	/* get transactions in queue */
 	size = pk_transaction_list_get_size (tlist);
-	g_assert_cmpint (size, ==, 0);
+	g_assert_cmpint (size, <, 3); /* at least one should have timed out */
 
 	/* get transactions (committed, not finished) in progress (neither - again) */
 	array = pk_transaction_list_get_array (tlist);
@@ -1849,7 +1822,6 @@ main (int argc, char **argv)
 	if (! g_thread_supported ())
 		g_thread_init (NULL);
 	g_type_init ();
-	egg_debug_init (&argc, &argv);
 	g_test_init (&argc, &argv, NULL);
 
 	/* components */
