@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2008 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2008-2010 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -77,6 +77,17 @@ typedef enum
 	PK_TRANSACTION_ERROR_LAST
 } PkTransactionError;
 
+/* these have to be kept in order */
+typedef enum {
+	PK_TRANSACTION_STATE_NEW,
+	PK_TRANSACTION_STATE_WAITING_FOR_AUTH,
+	PK_TRANSACTION_STATE_COMMITTED,
+	PK_TRANSACTION_STATE_READY,
+	PK_TRANSACTION_STATE_RUNNING,
+	PK_TRANSACTION_STATE_FINISHED,
+	PK_TRANSACTION_STATE_UNKNOWN
+} PkTransactionState;
+
 GQuark		 pk_transaction_error_quark			(void);
 GType		 pk_transaction_error_get_type			(void);
 GType		 pk_transaction_get_type			(void);
@@ -87,6 +98,10 @@ gboolean	 pk_transaction_run				(PkTransaction      *transaction)
 								 G_GNUC_WARN_UNUSED_RESULT;
 /* internal status */
 PkRoleEnum	 pk_transaction_priv_get_role			(PkTransaction	*transaction);
+PkTransactionState pk_transaction_get_state			(PkTransaction	*transaction);
+gboolean	 pk_transaction_set_state			(PkTransaction	*transaction,
+								 PkTransactionState state);
+const gchar	*pk_transaction_state_to_string			(PkTransactionState state);
 
 /* set and retrieve tid */
 const gchar	*pk_transaction_get_tid				(PkTransaction	*transaction);
@@ -222,6 +237,10 @@ void		 pk_transaction_what_provides			(PkTransaction	*transaction,
 								 const gchar	*type,
 								 gchar		**values,
 								 DBusGMethodInvocation *context);
+void		 pk_transaction_upgrade_system			(PkTransaction	*transaction,
+								 const gchar	*distro_id,
+								 const gchar	*upgrade_kind_str,
+								 DBusGMethodInvocation *context);
 gboolean	 pk_transaction_filter_check			(const gchar	*filter,
 								 GError		**error);
 gboolean	 pk_transaction_strvalidate			(const gchar	*textr,
